@@ -83,8 +83,8 @@ static BoardPlugin menu_bp =
   {
     NULL,
     NULL,
-    N_("Advanced colors"),
-    N_("Click on the right color"),
+    "Advanced colors",
+    "Click on the right color",
     "Pascal Georges pascal.georges1@free.fr>",
     NULL,
     NULL,
@@ -98,15 +98,15 @@ static BoardPlugin menu_bp =
     NULL,
     set_level,
     NULL,
+    NULL,
+    NULL,
     NULL
   };
 
 /* =====================================================================
  *
  * =====================================================================*/
-BoardPlugin *get_bplugin_info(void) {
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(advanced_colors)
 
 /* =====================================================================
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -530,10 +530,10 @@ static gboolean read_xml_file(char *fname)
   /* if the file doesn't exist */
   if(!g_file_test(fname, G_FILE_TEST_EXISTS))
     {
-      g_warning(_("Couldn't find file %s !"), fname);
+      g_warning("Couldn't find file %s !", fname);
       return FALSE;
     }
-  g_warning(_("find file %s !"), fname);
+  g_warning("found file %s !", fname);
 
   /* parse the new file and put the result into newdoc */
   doc = xmlParseFile(fname);
