@@ -1,6 +1,6 @@
 /* gcompris - algebra.c
  *
- * Time-stamp: <2005/03/30 22:01:14 bruno>
+ * Time-stamp: <2005/10/12 23:24:20 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -72,7 +72,7 @@ static void		 pause_board (gboolean pause);
 static void		 end_board (void);
 static gboolean		 is_our_board (GcomprisBoard *gcomprisBoard);
 static void		 set_level (guint level);
-static gint		 key_press(guint keyval);
+static gint		 key_press(guint keyval, gchar *commit_str, gchar *preedit_str);
 static void		 process_ok(void);
 
 static GnomeCanvasItem	*algebra_create_item(GnomeCanvasGroup *parent);
@@ -94,8 +94,8 @@ static BoardPlugin menu_bp =
 {
    NULL,
    NULL,
-   N_("Learning Clock"),
-   N_("Learn how to tell time"),
+   "Practice the math operation",
+   "Answer some algebra questions",
    "Bruno Coudoin <bruno.coudoin@free.fr>",
    NULL,
    NULL,
@@ -109,6 +109,8 @@ static BoardPlugin menu_bp =
    process_ok,
    set_level,
    NULL,
+   NULL,
+   NULL,
    NULL
 };
 
@@ -118,11 +120,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin 
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(algebra)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -154,6 +152,9 @@ static void start_board (GcomprisBoard *agcomprisBoard)
     {
       gcomprisBoard=agcomprisBoard;
 
+      /* disable im_context */
+      gcomprisBoard->disable_im_context = TRUE;
+
       gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery2_background.png");
 
       /* set initial values for this level */
@@ -217,12 +218,12 @@ set_level (guint level)
     }
 }
 
-static gint key_press(guint keyval)
+static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
 {
   guint c;
   gboolean stop = FALSE;
 
-  if(!gcomprisBoard)
+  if(!boardRootItem)
     return FALSE;
 
   /* Add some filter for control and shift key */
@@ -249,46 +250,6 @@ static gint key_press(guint keyval)
     case GDK_Return:
       process_ok();
       return TRUE;
-    case GDK_KP_0:
-    case GDK_KP_Insert:
-      keyval=GDK_0;
-      break;
-    case GDK_KP_1:
-    case GDK_KP_End:
-      keyval=GDK_1;
-      break;
-    case GDK_KP_2:
-    case GDK_KP_Down:
-      keyval=GDK_2;
-      break;
-    case GDK_KP_3:
-    case GDK_KP_Page_Down:
-      keyval=GDK_3;
-      break;
-    case GDK_KP_4:
-    case GDK_KP_Left:
-      keyval=GDK_4;
-      break;
-    case GDK_KP_5:
-    case GDK_KP_Begin:
-      keyval=GDK_5;
-      break;
-    case GDK_KP_6:
-    case GDK_KP_Right:
-      keyval=GDK_6;
-      break;
-    case GDK_KP_7:
-    case GDK_KP_Home:
-      keyval=GDK_7;
-      break;
-    case GDK_KP_8:
-    case GDK_KP_Up:
-      keyval=GDK_8;
-      break;
-    case GDK_KP_9:
-    case GDK_KP_Page_Up:
-      keyval=GDK_9;
-      break;
     case GDK_Right:
       if(currentToBeFoundItem->previous!=NULL)
 	{
