@@ -140,8 +140,8 @@ static BoardPlugin menu_bp =
   {
     NULL,
     NULL,
-    N_("Guess operations"),
-    N_("Guess operations"),
+    "Guess operations",
+    "Guess operations",
     "Pascal Georges pascal.georges1@free.fr>",
     NULL,
     NULL,
@@ -155,6 +155,8 @@ static BoardPlugin menu_bp =
     process_ok,
     set_level,
     NULL,
+    NULL,
+    NULL,
     NULL
   };
 
@@ -163,9 +165,7 @@ static BoardPlugin menu_bp =
  * Main entry point mandatory for each Gcompris's game
  * ---------------------------------------------------
  */
-BoardPlugin * get_bplugin_info(void){
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(algebra_guesscount)
 
 /* ==================================== */
 // in : boolean TRUE = PAUSE : FALSE = CONTINUE
