@@ -32,12 +32,17 @@
 
 #include "gcompris/gcompris.h"
 
+#if defined _WIN32 || defined __WIN32__
+# undef WIN32   /* avoid warning on mingw32 */
+# define WIN32
+#endif
 
 #define SOUNDLISTFILE PACKAGE
 
 static GcomprisBoard *gcomprisBoard = NULL;
 static gboolean board_paused = TRUE;
 
+static GPid	 gnuchess_pid;
 static void	 start_board (GcomprisBoard *agcomprisBoard);
 static void	 pause_board (gboolean pause);
 static void	 end_board (void);
@@ -46,7 +51,7 @@ static void	 set_level (guint level);
 static int	 gamewon;
 static void	 game_won(void);
 
-static void	 engine_local_destroy ();
+static void	 engine_local_destroy (GPid gnuchess_pid);
 
 static gboolean  engine_local_cb     (GIOChannel *source,
 				      GIOCondition condition,
@@ -86,8 +91,6 @@ static GnomeCanvasGroup *boardRootItem = NULL;
 static GIOChannel *read_chan;
 static GIOChannel *write_chan;
 
-static pid_t childpid;
-
 static gint read_cb;
 static gint err_cb;
 
@@ -115,11 +118,10 @@ static void		 chess_destroy_all_items(void);
 static void		 chess_next_level(void);
 static gint		 item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data);
 static gint		 item_event_black(GnomeCanvasItem *item, GdkEvent *event, gpointer data);
-static int		 start_child (char        *cmd,
-				      char       **arg,
+static gboolean		 start_child (char        *cmd,
 				      GIOChannel **read_chan,
 				      GIOChannel **write_chan,
-				      pid_t       *childpid);
+				      GPid	 *gnuchess_pid);
 
 static void		 write_child (GIOChannel  *write_chan,
 				      char        *format,
@@ -131,8 +133,8 @@ static BoardPlugin menu_bp =
   {
     NULL,
     NULL,
-    N_("Learning Chess"),
-    N_("Play chess against tux in a learning mode"),
+    "Learning Chess",
+    "Play chess against tux in a learning mode",
     "Bruno Coudoin <bruno.coudoin@free.fr>",
     NULL,
     NULL,
@@ -146,6 +148,8 @@ static BoardPlugin menu_bp =
     NULL,
     set_level,
     NULL,
+    NULL,
+    NULL,
     NULL
   };
 
@@ -155,11 +159,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(chess)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -183,26 +183,17 @@ static void pause_board (gboolean pause)
 static void start_board (GcomprisBoard *agcomprisBoard)
 {
   
-  if (g_file_test ("/usr/bin/gnuchessx", G_FILE_TEST_EXISTS)) {
-    
-    gcompris_dialog(_("Error: /usr/bin/gnuchessx is installed\nwhich means you have an old version\nof gnuchess.\nPlease upgrade to gnuchess 5 or above."), gcompris_end_board);
-    
-    return;
-  }
-  
+#ifndef WIN32  
   if (!g_file_test (GNUCHESS, G_FILE_TEST_EXISTS)) {
     
-    gcompris_dialog(_("Error: The external program gnuchess is mandatory\nto play chess in gcompris.\nFind this program on http://www.rpmfind.net or in your\nGNU/Linux distribution\nAnd check it is in "GNUCHESS), gcompris_end_board);
+    gcompris_dialog(_("Error: The external program gnuchess is mandatory\nto play chess in gcompris.\nFind this program on http://www.rpmfind.net or in your\nGNU/Linux distribution\nAnd check it is located here: "GNUCHESS), gcompris_end_board);
     
     return;
   }
-  
+#endif
+
   if(agcomprisBoard!=NULL)
     {
-      char *param[2];
-
-      param[0] = "xboard";
-      param[1] = NULL;
 
       gcomprisBoard=agcomprisBoard;
       
@@ -231,9 +222,9 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 	default:
 	  gcompris_bar_set(0);
 	}
-      
-      if(start_child (GNUCHESS, param, &read_chan,
-		      &write_chan, &childpid)==-1) {
+
+      if(start_child (GNUCHESS, &read_chan,
+		      &write_chan, &gnuchess_pid)==FALSE) {
 	gcompris_dialog(_("Error: The external program gnuchess is mandatory\nto play chess in gcompris.\nFind this program on http://www.rpmfind.net or in your\nGNU/Linux distribution\nAnd check it is in "GNUCHESS), gcompris_end_board);
 	return;
       }
@@ -271,7 +262,7 @@ static void end_board ()
   info_item     = NULL;
 
 
-  engine_local_destroy();
+  engine_local_destroy(gnuchess_pid);
 }
 
 /* ======================================= */
@@ -307,7 +298,6 @@ static gboolean is_our_board (GcomprisBoard *gcomprisBoard)
 static void chess_next_level()
 {
   register Square square;
-  register Piece piece;
   register gshort rank;
 
   gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), 
@@ -356,7 +346,6 @@ static void chess_next_level()
 static void chess_destroy_all_items()
 {
   register Square square;
-  register Piece piece;
   register gshort rank;
 
   if(boardRootItem!=NULL)
@@ -470,8 +459,8 @@ static GnomeCanvasItem *chess_create_item(GnomeCanvasGroup *parent)
 	if(piece!=NONE)
 	  {
 
-	    if(white_side && BPIECE(piece) ||
-	       !white_side && WPIECE(piece)) 
+	    if( (white_side && BPIECE(piece)) ||
+		(!white_side && WPIECE(piece)) ) 
 	      {
 		white_side = !white_side;
 		//		write_child (write_chan, "c\n");
@@ -505,7 +494,10 @@ static GnomeCanvasItem *chess_create_item(GnomeCanvasGroup *parent)
 	//	printf("square=%d piece=%d x=%d y=%d\n", square, piece, x, y);
 	if(piece != EMPTY)
 	  {
-	    str = g_strdup_printf("chess/%c.png", piece_to_ascii(piece));
+	    if(BPIECE(piece))
+	      str = g_strdup_printf("chess/B%c.png", piece_to_ascii(piece));
+	    else
+	      str = g_strdup_printf("chess/W%c.png", piece_to_ascii(piece));
 	    
 	    pixmap = gcompris_load_pixmap(str);
 	    //	    g_warning("loading piece %s\n",   str);
@@ -574,7 +566,7 @@ static void display_white_turn(gboolean whiteturn)
 					 NULL);
     }
 
-  gnome_canvas_item_set(turn_item, "text", (whiteturn ? _("White Turn") : _("Black Turn")),
+  gnome_canvas_item_set(turn_item, "text", (whiteturn ? _("White's Turn") : _("Black's Turn")),
 			NULL);
 }
 
@@ -702,7 +694,10 @@ static void move_piece_to(Square from, Square to)
       g_warning("  WARNING promoting a pawn from=%d to=%d piece=%d\n", from, to, piece);
       g_warning("  piece_to_ascii returns %c\n", piece_to_ascii(piece));
 
-      str = g_strdup_printf("chess/%c.png", piece_to_ascii(piece));
+      if(BPIECE(piece))
+	str = g_strdup_printf("chess/B%c.png", piece_to_ascii(piece));
+      else
+	str = g_strdup_printf("chess/W%c.png", piece_to_ascii(piece));
 	      
       pixmap = gcompris_load_pixmap(str);
       g_free(str);
@@ -715,9 +710,9 @@ static void move_piece_to(Square from, Square to)
 
   /* Display check info */
   if(position_white_king_attack(position))
-    display_info(_("White check"));
+    display_info(_("White checks"));
   else if(position_black_king_attack(position))
-    display_info(_("Black check"));
+    display_info(_("Black checks"));
   else
     display_info(" ");
 
@@ -752,7 +747,6 @@ void hightlight_possible_moves(GSquare *gsquare)
   Square square_test;
   guint color;
   register Square square;
-  register Piece piece;
   register gshort rank;
   short    current_color;
 
@@ -949,7 +943,10 @@ item_event_black(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	hightlight_possible_moves(gsquare);
       }
       break;
+    default:
+      break;
     }
+  return(FALSE);
 }
 
 /*======================================================================*/
@@ -957,7 +954,7 @@ item_event_black(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 /*======================================================================*/
 /*======================================================================*/
 static void
-engine_local_destroy () 
+engine_local_destroy (GPid gnuchess_pid) 
 {
 
   g_warning("engine_local_destroy () \n");
@@ -971,7 +968,9 @@ engine_local_destroy ()
   
   g_io_channel_close (write_chan);
   g_io_channel_unref (write_chan);
-  
+
+  if(gnuchess_pid)
+    g_spawn_close_pid(gnuchess_pid);
 }
 
 static gboolean
@@ -998,33 +997,35 @@ engine_local_cb (GIOChannel *source,
     q = strchr (buf,'\n');
     if (q == NULL) break;
     tmp = *(q+1);
-    *(q+1) = 0;
+    *(q+1) = '\0';
     
-    *q=0;
+    *q='\0';
     *(q+1) = tmp;
     
-    g_warning("engine_local_cb read=%s\n", &buf);
+    g_warning("engine_local_cb read=%s\n", buf);
     
     /* parse for  NUMBER ... MOVE */
     if (isdigit (*buf))
-      if ((p = strstr (buf, "...")))
-	{
-	  Square from, to;
+      {
+	if ((p = strstr (buf, "...")))
+	  {
+	    Square from, to;
 	  
-	  g_warning("computer number moves to %s\n", p+4);
+	    g_warning("computer number moves to %s\n", p+4);
 	  
-	  if (san_to_move (position, p+4, &from, &to))
-	    ascii_to_move (position, p+4, &from, &to);
+	    if (san_to_move (position, p+4, &from, &to))
+	      ascii_to_move (position, p+4, &from, &to);
 	  
-	  position_move (position, from, to);
-	  move_piece_to(from , to);
-	}
-      else if ((p = strstr (buf, " ")))
-	{
-	  /* It's a legal move case */
-	  g_warning("Legal move to %s\n", p+1);
-	}
-    
+	    position_move (position, from, to);
+	    move_piece_to(from , to);
+	  }
+	else if ((p = strstr (buf, " ")))
+	  {
+	    /* It's a legal move case */
+	    g_warning("Legal move to %s\n", p+1);
+	  }
+      }
+
     /* parse for move MOVE */
     if (!strncmp ("My move is : ",buf,13))
       {
@@ -1092,30 +1093,32 @@ engine_local_err_cb (GIOChannel *source,
 
 /*----------------------------------------
  * Subprocess creation
+ * Return TRUE if gnuchess is started, false instead
  *----------------------------------------*/
 
-static int 
+static gboolean
 start_child (char *cmd, 
-	     char **arg, 
 	     GIOChannel **read_chan, 
-	     GIOChannel **write_chan, 
-	     pid_t *childpid)
+	     GIOChannel **write_chan,
+	     GPid *Child_Process)
 {
-  /*spawn program*/
-  gint Child_Process=0;
-  gint Child_In=0, Child_Out=0, Child_Err=0;
+  gint   Child_In, Child_Out, Child_Err;
+  GError *gerror = NULL;
 
-  gchar *Child_Argv[]={ "gnuchess" };
+  gchar *Child_Argv[]={ cmd, NULL };
 
-  gint Bytes_Read=0;
-  gchar Read_Data[300];
+  g_warning("Ready to start child");
 
   if (!g_spawn_async_with_pipes(NULL, Child_Argv, NULL,
 				G_SPAWN_SEARCH_PATH,
-				NULL, NULL, &Child_Process, &Child_In, &Child_Out,
-				&Child_Err, NULL)) {
+				NULL, NULL, Child_Process, &Child_In, &Child_Out,
+				&Child_Err, &gerror)) {
+    
+    g_warning("Error message '%s'", gerror->message);
+    g_warning("Error code    '%d'", gerror->code);
+    g_error_free (gerror);
     g_warning("In order to play chess, you need to have gnuchess installed as " GNUCHESS);
-    return(-1);
+    return(FALSE);
 
   }
 
@@ -1124,7 +1127,7 @@ start_child (char *cmd,
   *read_chan = g_io_channel_unix_new (Child_Out);
   *write_chan = g_io_channel_unix_new (Child_In);
 
-  return(0);
+  return(TRUE);
 }
 
 
