@@ -37,6 +37,9 @@ static void		 process_ok(void);
 static void		 highlight_selected(int);
 static void		 game_won(void);
 static void		 repeat(void);
+static void		 colors_config_start(GcomprisBoard *agcomprisBoard,
+					     GcomprisProfile *aProfile);
+static void		 colors_config_stop(void);
 
 /* ================================================================ */
 static GnomeCanvasGroup *boardRootItem = NULL;
@@ -51,29 +54,32 @@ static GList * listColors = NULL;
 
 #define LAST_COLOR 10
 static gchar *colors[LAST_COLOR*2] = {
-  "blue", 	N_("Click on the blue toon"),
-  "brown",	N_("Click on the brown toon"),
-  "green",	N_("Click on the green toon"),
-  "grey",	N_("Click on the grey toon"),
-  "orange",	N_("Click on the orange toon"),
-  "purple",	N_("Click on the purple toon"),
-  "red",	N_("Click on the red toon"),
-  "yellow",	N_("Click on the yellow toon"),
-  "black",	N_("Click on the black toon"),
-  "white",	N_("Click on the white toon")
+  "blue", 	N_("Click on the blue duck"),
+  "brown",	N_("Click on the brown duck"),
+  "green",	N_("Click on the green duck"),
+  "grey",	N_("Click on the grey duck"),
+  "orange",	N_("Click on the orange duck"),
+  "purple",	N_("Click on the purple duck"),
+  "red",	N_("Click on the red duck"),
+  "yellow",	N_("Click on the yellow duck"),
+  "black",	N_("Click on the black duck"),
+  "white",	N_("Click on the white duck")
 };
 
 static int X[] = {75,212,242,368,414,533,578,709};
 static int Y[] = {25,170,180,335,337,500};
 
+/* if board has alternate locale */
+static gchar *locale_sound = NULL;
+
 /* Description of this plugin */
 static BoardPlugin menu_bp =
   {
     NULL,
     NULL,
-    N_("Colors"),
-    N_("Click on the right color"),
-    "Pascal Georges pascal.georges1@free.fr>",
+    "Colors",
+    "Click on the right color",
+    "Pascal Georges <pascal.georges1@free.fr>",
     NULL,
     NULL,
     NULL,
@@ -86,16 +92,83 @@ static BoardPlugin menu_bp =
     process_ok,
     NULL,//set_level,
     NULL,
-    repeat
+    repeat,
+    colors_config_start,
+    colors_config_stop
   };
 
 /* =====================================================================
  *
  * =====================================================================*/
-BoardPlugin *get_bplugin_info(void) {
-  return &menu_bp;
+GET_BPLUGIN_INFO(colors)
+     
+
+/* ======================= */
+/* = config_start        = */
+/* ======================= */
+
+static GcomprisProfile *profile_conf;
+static GcomprisBoard   *board_conf;
+
+static GHFunc save_table (gpointer key,
+		    gpointer value,
+		    gpointer user_data)
+{
+  gcompris_set_board_conf ( profile_conf,
+			    board_conf,
+			    (gchar *) key, 
+			    (gchar *) value);
 }
 
+static GcomprisConfCallback conf_ok(GHashTable *table)
+{
+  g_hash_table_foreach(table, (GHFunc) save_table, NULL);
+  
+  board_conf = NULL;
+  profile_conf = NULL;
+}
+
+static gboolean check_text(gchar *key, gchar *text, GtkLabel *label){
+  gtk_label_set_markup(label, text);
+
+  return TRUE;
+}
+
+static void
+colors_config_start(GcomprisBoard *agcomprisBoard,
+		    GcomprisProfile *aProfile)
+{
+  board_conf = agcomprisBoard;
+  profile_conf = aProfile;
+
+  gchar *label;
+  
+  label = g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
+			  agcomprisBoard->name, aProfile->name);
+
+  gcompris_configuration_window(label, (GcomprisConfCallback )conf_ok);
+
+  g_free(label);
+
+  /* init the combo to previously saved value */
+  GHashTable *config = gcompris_get_conf( profile_conf, board_conf);
+
+  gchar *locale_sound = g_hash_table_lookup( config, "locale_sound");
+  
+  gcompris_combo_locales_asset( "Select sound locale", locale_sound, "gcompris colors", NULL, "audio/x-ogg", "purple.ogg");
+
+}
+
+  
+/* ======================= */
+/* = config_stop        = */
+/* ======================= */
+static void 
+colors_config_stop()
+{
+}
+
+
 /* =====================================================================
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
  * =====================================================================*/
@@ -120,9 +193,13 @@ static void start_board (GcomprisBoard *agcomprisBoard) {
   int * item;
   int i;
 
+  GHashTable *config = gcompris_get_board_conf();
+
+  locale_sound = g_hash_table_lookup( config, "locale_sound");
+
   if(agcomprisBoard!=NULL) {
     gcomprisBoard=agcomprisBoard;
-    gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "colors/colors_bg.jpg");
+    gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "colors/colors_bg.png");
     gcomprisBoard->level=1;
     gcomprisBoard->maxlevel=1;
 
@@ -206,7 +283,7 @@ static void repeat (){
 
       str1 = g_strdup_printf("%s%s", colors[GPOINTER_TO_INT(g_list_nth_data(listColors, 0))*2],
 			     ".ogg");
-      str2 = gcompris_get_asset_file("gcompris colors", NULL, "audio/x-ogg", str1);
+      str2 = gcompris_get_asset_file_locale("gcompris colors", NULL, "audio/x-ogg", str1, locale_sound);
 
       /* If we don't find a sound in our locale or the sounds are disabled */
       if(str2 && properties->fx) {
