@@ -28,7 +28,7 @@
 #include "gcompris/gcompris.h"
 
 #define SOUNDLISTFILE PACKAGE
-#define IMG_DATA_SET PACKAGE_DATA_DIR "/dataset/mrpatate.xml"
+#define IMG_DATA_SET PACKAGE_DATA_DIR "/dataset"
 #define FILE_SELECTOR_ROOT "drawings"
 
 /* Represent the drawing area */
@@ -177,7 +177,7 @@ static guint ext_colorlist [] =
 static void	 start_board (GcomprisBoard *agcomprisBoard);
 static void	 pause_board (gboolean pause);
 static void	 end_board (void);
-static gint	 key_press(guint keyval);
+static gint	 key_press(guint keyval, gchar *commit_str, gchar *preedit_str);
 static gboolean	 is_our_board (GcomprisBoard *gcomprisBoard);
 static void	 config(void);
 
@@ -212,8 +212,8 @@ static BoardPlugin menu_bp =
   {
     NULL,
     NULL,
-    N_("A simple vector drawing tool"),
-    N_("Creative board where you can draw freely"),
+    "A simple vector drawing tool",
+    "Creative board where you can draw freely",
     "Bruno Coudoin <bruno.coudoin@free.fr>",
     NULL,
     NULL,
@@ -227,6 +227,8 @@ static BoardPlugin menu_bp =
     NULL,
     NULL,
     config,
+    NULL,
+    NULL,
     NULL
   };
 
@@ -236,11 +238,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(draw)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -264,6 +262,9 @@ static void start_board (GcomprisBoard *agcomprisBoard)
     {
       gcomprisBoard=agcomprisBoard;
 
+      /* disable im_context */
+      gcomprisBoard->disable_im_context = TRUE;
+
       gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), 
 			      gcompris_image_to_skin("gcompris-bg.jpg"));
 
@@ -309,7 +310,7 @@ end_board ()
 }
 
 /* Get the user keys to use with the text tool */
-static gint key_press(guint keyval)
+static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
 {
   char str[2];
   char utf8char[6];
@@ -346,36 +347,6 @@ static gint key_press(guint keyval)
     case GDK_dead_circumflex:
     case GDK_Num_Lock:
       return FALSE;
-    case GDK_KP_0:
-      keyval=GDK_0;
-      break;
-    case GDK_KP_1:
-      keyval=GDK_1;
-      break;
-    case GDK_KP_2:
-      keyval=GDK_2;
-      break;
-    case GDK_KP_3:
-      keyval=GDK_3;
-      break;
-    case GDK_KP_4:
-      keyval=GDK_4;
-      break;
-    case GDK_KP_5:
-      keyval=GDK_5;
-      break;
-    case GDK_KP_6:
-      keyval=GDK_6;
-      break;
-    case GDK_KP_7:
-      keyval=GDK_7;
-      break;
-    case GDK_KP_8:
-      keyval=GDK_8;
-      break;
-    case GDK_KP_9:
-      keyval=GDK_9;
-      break;
     }
 
   if(selected_anchors_item == NULL)
@@ -933,10 +904,10 @@ tool_event(GnomeCanvasItem *item, GdkEvent *event, gint tool)
 	  switch(tool)
 	    {
 	    case TOOL_LOAD:
-	      gcompris_file_selector_load(gcomprisBoard, FILE_SELECTOR_ROOT, "", load_drawing);
+	      //	      gcompris_file_selector_load(gcomprisBoard, FILE_SELECTOR_ROOT, "", load_drawing);
 	      break;
 	    case TOOL_SAVE:
-	      gcompris_file_selector_save(gcomprisBoard, FILE_SELECTOR_ROOT, "", save_drawing);
+	      //	      gcompris_file_selector_save(gcomprisBoard, FILE_SELECTOR_ROOT, "", save_drawing);
 	      break;
 	    case TOOL_GRID:
 	      display_grid((grid_step==0 ? TRUE : FALSE));
@@ -2153,26 +2124,6 @@ static void recreate_item(GnomeCanvasItem *item)
  */
 static void load_drawing(gchar *file)
 {
-  printf("callback in draw, load_drawing got image %s\n", file);
-
-  /* Delete the current drawing */
-  /* WARNING: We should have a YES/NO Dialog box */
-  gtk_object_destroy (GTK_OBJECT(draw_root_item));
-  draw_root_item = \
-    gnome_canvas_item_new (GNOME_CANVAS_GROUP(shape_root_item),
-			   gnome_canvas_group_get_type (),
-			   "x", (double)0,
-			   "y", (double)0,
-			   NULL);
-
-
-  gcompris_svg_restore(FILE_SELECTOR_ROOT, file, GNOME_CANVAS_GROUP(draw_root_item));
-
-  /* For each item we need to recreate the anchors */
-  g_list_foreach(GNOME_CANVAS_GROUP(draw_root_item)->item_list, (GFunc) recreate_item, NULL);
-
-  /* Set current_tool */
-  set_current_tool(selectionToolItem, TOOL_SELECT);
 
 }
 
@@ -2181,8 +2132,7 @@ static void load_drawing(gchar *file)
  */
 static void save_drawing(gchar *file)
 {
-  printf("callback in draw, save_drawing got image %s\n", file);
-  gcompris_svg_save(FILE_SELECTOR_ROOT, file, draw_root_item, BOARDWIDTH, BOARDHEIGHT, 0);
+
 }
 
 /*
