@@ -20,6 +20,7 @@
 #include <ctype.h>
 #include <math.h>
 #include <assert.h>
+#include <string.h>
 
 #include "gcompris/gcompris.h"
 
@@ -29,7 +30,7 @@ static GcomprisBoard *gcomprisBoard = NULL;
 static gboolean board_paused = TRUE;
 
 static void	 start_board (GcomprisBoard *agcomprisBoard);
-static gint	 key_press(guint keyval);
+static gint	 key_press(guint keyval, gchar *commit_str, gchar *preedit_str);
 static void	 pause_board (gboolean pause);
 static void	 end_board (void);
 static void	 process_ok(void);
@@ -74,7 +75,7 @@ static gchar *imageList[] =
   "gcompris/food/bread_slice.png",
   "gcompris/food/round_cookie.png",
 };
-#define NUMBER_OF_IMAGES 17
+#define NUMBER_OF_IMAGES G_N_ELEMENTS(imageList)
 
 static guint		 answer[NUMBER_OF_IMAGES];
 static guint		 answer_to_find[NUMBER_OF_IMAGES];
@@ -103,6 +104,8 @@ static BoardPlugin menu_bp =
     process_ok,
     set_level,
     NULL,
+    NULL,
+    NULL,
     NULL
   };
 
@@ -112,11 +115,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(enumerate)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -143,6 +142,10 @@ static void start_board (GcomprisBoard *agcomprisBoard)
   if(agcomprisBoard!=NULL)
     {
       gcomprisBoard=agcomprisBoard;
+
+      /* disable im_context */
+      gcomprisBoard->disable_im_context = TRUE;
+
       gcomprisBoard->level=1;
       gcomprisBoard->maxlevel=5;
       gcomprisBoard->sublevel=1;
@@ -170,7 +173,7 @@ static void end_board ()
 }
 
 /* Get the user keys to use to get the answer */
-static gint key_press(guint keyval)
+static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
 {
   char str[2];
   GnomeCanvasItem	*item = NULL;
@@ -203,36 +206,6 @@ static gint key_press(guint keyval)
     case GDK_Return:
       process_ok();
       return TRUE;
-    case GDK_KP_0:
-      keyval=GDK_0;
-      break;
-    case GDK_KP_1:
-      keyval=GDK_1;
-      break;
-    case GDK_KP_2:
-      keyval=GDK_2;
-      break;
-    case GDK_KP_3:
-      keyval=GDK_3;
-      break;
-    case GDK_KP_4:
-      keyval=GDK_4;
-      break;
-    case GDK_KP_5:
-      keyval=GDK_5;
-      break;
-    case GDK_KP_6:
-      keyval=GDK_6;
-      break;
-    case GDK_KP_7:
-      keyval=GDK_7;
-      break;
-    case GDK_KP_8:
-      keyval=GDK_8;
-      break;
-    case GDK_KP_9:
-      keyval=GDK_9;
-      break;
     }
 
   sprintf(str, "%c", keyval);
