@@ -20,6 +20,7 @@
 #include <ctype.h>
 #include <math.h>
 #include <assert.h>
+#include <string.h>
 
 #include "gcompris/gcompris.h"
 
@@ -38,10 +39,11 @@ static void	 game_won(void);
 
 static GnomeCanvasGroup *boardRootItem = NULL;
 
-static GnomeCanvasItem	*erase_create_item();
+static GnomeCanvasItem	*erase_create_item(int layer);
 static void		 erase_destroy_all_items(void);
 static void		 erase_next_level(void);
 static gint		 item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data);
+static void		 shuffle_image_list(char *list[], int size);
 
 static int number_of_item = 0;
 static int number_of_item_x = 0;
@@ -49,7 +51,7 @@ static int number_of_item_y = 0;
 
 static gint timer_id = 0;
 
-// Default Double clic distance to restore on exit.
+// Default Double click distance to restore on exit.
 static gint DefaultDoubleClicDistance;
 
 static gint DoubleClicLevel[6]= {  1000, 750, 600, 500, 400, 250};
@@ -63,17 +65,42 @@ static gint board_mode =  NORMAL;
 // List of images to use in the game
 static gchar *imageList[] =
   {
+    "gcompris/animals/bear001.jpg",
+    "gcompris/animals/elephanteauxgc.jpg",
     "gcompris/animals/flamentrosegc.jpg",
     "gcompris/animals/girafegc.jpg",
+    "gcompris/animals/hypogc.jpg",
+    "gcompris/animals/joybear001.jpg",
+    "gcompris/animals/joybear002.jpg",
+    "gcompris/animals/jumentmulassieregc.jpg",
+    "gcompris/animals/malaybear002.jpg",
+    "gcompris/animals/polabear011.jpg",
+    "gcompris/animals/polarbear001.jpg",
+    "gcompris/animals/poolbears001.jpg",
     "gcompris/animals/rhinogc.jpg",
     "gcompris/animals/singegc.jpg",
-    "gcompris/animals/joybear002.jpg",
-    "gcompris/animals/elephanteauxgc.jpg",
-    "gcompris/animals/hypogc.jpg",
-    "gcompris/animals/jumentmulassieregc.jpg",
-    "gcompris/animals/tetegorillegc.jpg"
+    "gcompris/animals/spectbear001.jpg",
+    "gcompris/animals/tetegorillegc.jpg",
+    "gcompris/animals/tiger1_by_Ralf_Schmode.jpg",
+    "gcompris/animals/tigercub003.jpg",
+    "gcompris/animals/tigerdrink001.jpg",
+    "gcompris/animals/tigerplay001.jpg",
+    "gcompris/animals/horses.jpg",
+    "gcompris/animals/squirrel.jpg",
+    "gcompris/animals/sheep_irish.jpg",
+    "gcompris/animals/sheep_irish2.jpg",
+    "gcompris/animals/cow.jpg",
+    "gcompris/animals/maki1.jpg",
+    "gcompris/animals/maki2.jpg",
+    "gcompris/animals/maki3.jpg",
+    "gcompris/animals/maki4.jpg",
+    "gcompris/animals/maki5.jpg",
+    "gcompris/animals/maki6.jpg",
   };
-#define NUMBER_OF_IMAGES 9
+#define NUMBER_OF_IMAGES G_N_ELEMENTS(imageList)
+
+/* Store the image index to use */
+static int current_image;
 
 /* Description of this plugin */
 static BoardPlugin menu_bp =
@@ -95,6 +122,8 @@ static BoardPlugin menu_bp =
     NULL,
     set_level,
     NULL,
+    NULL,
+    NULL,
     NULL
   };
 
@@ -104,11 +133,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(erase)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -157,19 +182,22 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 	GtkSettings *DefaultsGtkSettings = gtk_settings_get_default ();
 
 	if (DefaultsGtkSettings == NULL) {
-	  g_warning(_("Couldn't get GTK settings"));
+	  g_warning("Couldn't get GTK settings");
 	} else {
 	  g_object_get(G_OBJECT(DefaultsGtkSettings), 
 		       "gtk-double-click-time", &DefaultDoubleClicDistance, NULL);
 	  
-	  g_warning(_("Double clic default value %d."),DefaultDoubleClicDistance);
+	  g_warning("Double-click default value %d.",DefaultDoubleClicDistance);
 	}
 
 	gdk_display_set_double_click_time( gdk_display_get_default(),
 					   DoubleClicLevel[gcomprisBoard->level-1]);
-	g_warning(_("Double clic value is now %d."),DoubleClicLevel[gcomprisBoard->level-1]);
+	g_warning("Double-click value is now %d.",DoubleClicLevel[gcomprisBoard->level-1]);
       }
 
+      current_image = 0;
+      shuffle_image_list(imageList, NUMBER_OF_IMAGES);
+
       erase_next_level();
 
       gamewon = FALSE;
@@ -182,7 +210,7 @@ static void end_board ()
   if (board_mode == DOUBLECLIC){
     gdk_display_set_double_click_time( gdk_display_get_default(),
 					   DefaultDoubleClicDistance);
-    g_warning(_("Double clic value is now %d."),DefaultDoubleClicDistance);
+    g_warning("Double click value is now %d.",DefaultDoubleClicDistance);
   }
   if(gcomprisBoard!=NULL)
     {
@@ -205,7 +233,7 @@ static void set_level (guint level)
   if (board_mode == DOUBLECLIC){
     gdk_display_set_double_click_time( gdk_display_get_default(),
 				       DoubleClicLevel[gcomprisBoard->level-1]);
-    g_warning(_("Double clic value is now %d."),DoubleClicLevel[gcomprisBoard->level-1]);
+    g_warning("Double click value is now %d.",DoubleClicLevel[gcomprisBoard->level-1]);
   }
   
 }
@@ -230,9 +258,13 @@ static gboolean is_our_board (GcomprisBoard *gcomprisBoard)
 /* set initial values for the next level */
 static void erase_next_level()
 {
+  int layers = 1;
 
   gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
-			  imageList[RAND(0, NUMBER_OF_IMAGES-1)]);
+			  imageList[current_image++]);
+
+  if(current_image>NUMBER_OF_IMAGES)
+    current_image=0;
 
   gcompris_bar_set_level(gcomprisBoard);
 
@@ -248,9 +280,20 @@ static void erase_next_level()
     number_of_item_x = ((gcomprisBoard->level+1)%2+1)*5;
     number_of_item_y = ((gcomprisBoard->level+1)%2+1)*5;
   }  
+
+  /* Select the number of layer depending on the level */
+
+  if (board_mode != DOUBLECLIC){
+    if(gcomprisBoard->level>4)
+      layers = 3;
+    else if(gcomprisBoard->level>2)
+      layers = 2;
+  }
       
   /* Try the next level */
-  erase_create_item(gnome_canvas_root(gcomprisBoard->canvas));}
+  erase_create_item(layers);
+
+}
   
 /* ==================================== */
 /* Destroy all the items */
@@ -267,11 +310,12 @@ static void erase_destroy_all_items()
   boardRootItem = NULL;
 }
 /* ==================================== */
-static GnomeCanvasItem *erase_create_item()
+static GnomeCanvasItem *erase_create_item(int layer)
 {
   int i,j;
   int ix, jy;
   GnomeCanvasItem *item = NULL;
+  GdkPixbuf *pixmap[3];
 
   boardRootItem = GNOME_CANVAS_GROUP(
 				     gnome_canvas_item_new (gnome_canvas_root(gcomprisBoard->canvas),
@@ -282,30 +326,47 @@ static GnomeCanvasItem *erase_create_item()
 
   number_of_item = 0;
 
+  pixmap[0] = gcompris_load_pixmap("images/transparent_square.png");
+  pixmap[1] = gcompris_load_pixmap("images/water_spot.png");
+  pixmap[2] = gcompris_load_pixmap("images/water_drop.png");
+
   for(i=0,ix=0; i<BOARDWIDTH; i+=BOARDWIDTH/number_of_item_x, ix++)
     {
       for(j=0, jy=0; j<BOARDHEIGHT; j+=BOARDHEIGHT/number_of_item_y, jy++)
 	{
+	  int current_layer = layer;
 
 	  if ((board_mode != NORMAL) && ((ix+jy) %2 == 0))
 	    continue;
 
-	  item = gnome_canvas_item_new (boardRootItem,
-					gnome_canvas_rect_get_type (),
-					"x1", (double) i,
-					"y1", (double) j,
-					"x2", (double) i+BOARDWIDTH/number_of_item_x,
-					"y2", (double)  j+BOARDHEIGHT/number_of_item_y,
-					"fill_color_rgba", gcompris_skin_get_color("erase/rectangle in"),
-					"outline_color_rgba", gcompris_skin_get_color("erase/rectangle out"),
-					"width_units", (double)1,
-					NULL);
-	  gtk_object_set_data(GTK_OBJECT(item),"state", GINT_TO_POINTER(0));
-	  gtk_signal_connect(GTK_OBJECT(item), "event", (GtkSignalFunc) item_event, NULL);
-	  number_of_item++;
+	  while(current_layer--)
+	    {
+	      double w = (BOARDWIDTH/number_of_item_x) *  (1.0 - (0.3 * current_layer));
+	      double h = (BOARDHEIGHT/number_of_item_y) * (1.0 - (0.3 * current_layer));
+	      double x = i + ((BOARDWIDTH/number_of_item_x)  - w) / 2;
+	      double y = j + ((BOARDHEIGHT/number_of_item_y) - h) / 2;
+
+	      item = gnome_canvas_item_new (boardRootItem,
+					    gnome_canvas_pixbuf_get_type (),
+					    "pixbuf", pixmap[current_layer],
+					    "x", x,
+					    "y", y,
+					    "width", w,
+					    "height", h,
+					    "width_set", TRUE,
+					    "height_set", TRUE,
+					    "anchor", GTK_ANCHOR_NW,
+					    NULL);
+
+	      gtk_signal_connect(GTK_OBJECT(item), "event", (GtkSignalFunc) item_event, NULL);
+	      number_of_item++;
+	    }
 	}
     }
 
+  for(i=layer-1; i>=0; i--)
+    gdk_pixbuf_unref(pixmap[i]);
+
   return NULL;
 }
 
@@ -326,7 +387,6 @@ static void game_won()
 
   if(gcomprisBoard->sublevel>gcomprisBoard->number_of_sublevel) {
     /* Try the next level */
-    int i;
     gcomprisBoard->sublevel=1;
     gcomprisBoard->level++;
     if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
@@ -336,7 +396,7 @@ static void game_won()
     if (board_mode == DOUBLECLIC){
       gdk_display_set_double_click_time( gdk_display_get_default(),
 					 DoubleClicLevel[gcomprisBoard->level-1]);
-      g_warning(_("Double clic value is now %d."),DoubleClicLevel[gcomprisBoard->level-1]);
+      g_warning("Double click value is now %d.", DoubleClicLevel[gcomprisBoard->level-1]);
     }
 
     gcompris_play_ogg ("bonus", NULL);
@@ -348,11 +408,13 @@ static void game_won()
 static gint
 item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 {
-  guint state;
 
   if(board_paused)
     return FALSE;
-  
+
+  if (event->type == GDK_MOTION_NOTIFY)
+    return;
+
   if (board_mode == NORMAL)
     if (event->type != GDK_ENTER_NOTIFY)
       return FALSE;
@@ -368,55 +430,17 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
       return FALSE;
 
 
-  if (board_mode != DOUBLECLIC){
-    state = (GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (item), "state")));
-    if(gcomprisBoard->level>2)
-      {
-	if(!state)
-	  {
-	    gnome_canvas_item_set(item,
-				  "fill_color_rgba", gcompris_skin_get_color("erase/rectangle in2"),
-				  "outline_color_rgba", gcompris_skin_get_color("erase/rectangle out2"),
-				  NULL);
-	    state++;
-	    gtk_object_set_data(GTK_OBJECT(item),"state", GINT_TO_POINTER(state));
-	    return FALSE;
-	  }
-	
-	if(gcomprisBoard->level>4) {
-	  if(state==1)
-	    {     
-	      state++;
-	      gtk_object_set_data(GTK_OBJECT(item),"state", GINT_TO_POINTER(state));
-	      gnome_canvas_item_set(item, 
-				    "fill_color_rgba", gcompris_skin_get_color("erase/rectangle in3"),
-				    "outline_color_rgba", NULL,
-				    NULL);
-	      return FALSE;
-	    }
-	}
-      }
-  }
-  else {
+  if (board_mode == DOUBLECLIC){
     if (event->type == GDK_BUTTON_PRESS){
-      gnome_canvas_item_set(item,
-			    "fill_color_rgba", gcompris_skin_get_color("erase/rectangle in2"),
-			    "outline_color_rgba", gcompris_skin_get_color("erase/rectangle out2"),
-			    NULL);
       return FALSE;
     }
     if (event->type == GDK_BUTTON_RELEASE){
-      gnome_canvas_item_set(item,
-			    "fill_color_rgba", gcompris_skin_get_color("erase/rectangle in"),
-			    "outline_color_rgba", gcompris_skin_get_color("erase/rectangle out"),
-			    NULL);
       return FALSE;
     }
   }
     
   gtk_object_destroy(GTK_OBJECT(item));
-  
-    
+
   if(--number_of_item == 0)
     {
       gamewon = TRUE;
@@ -426,3 +450,27 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
   
   return FALSE;
 }
+
+/** \brief shuffle_image_list, takes a char* array and it's length.
+ *         it swaps a random number of items in it in order to provide
+ *         the same list but in a random order.
+ *
+ * \param list: the array to shuffle
+ * \param size: the size of the array
+ *
+ */
+void shuffle_image_list(char *list[], int size)
+{
+  int i;
+
+  for(i=0; i<size; i++)
+    {
+      int random1 = RAND(0, size-1);
+      int random2 = RAND(0, size-1);
+      char *olditem;
+
+      olditem = list[random2];
+      list[random2] = list[random1];
+      list[random1] = olditem;
+    }
+}
