@@ -45,18 +45,21 @@ static void		 process_ok(void);
 static void		 highlight_selected(GnomeCanvasItem *);
 static void		 game_won(void);
 
+static void		 config_start(GcomprisBoard *agcomprisBoard,
+					     GcomprisProfile *aProfile);
+static void		 config_stop(void);
+
 #ifdef DEBUG
 static void		 dump_xml(void);
 #endif
 
 
-typedef struct _Board Board;
-struct _Board {
+typedef struct {
   char  *pixmapfile;
   char  *text1;
   char  *text2;
   char  *text3;
-};
+} Board;
 
 /* XML */
 static gboolean		 read_xml_file(char *fname);
@@ -121,7 +124,9 @@ static BoardPlugin menu_bp =
     process_ok,
     set_level,
     NULL,
-    NULL
+    NULL,
+    config_start,
+    config_stop
   };
 
 /*
@@ -130,11 +135,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(imageid)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -157,6 +158,12 @@ static void pause_board (gboolean pause)
  */
 static void start_board (GcomprisBoard *agcomprisBoard)
 {
+  GHashTable *config = gcompris_get_board_conf();
+
+  gcompris_change_locale(g_hash_table_lookup( config, "locale"));
+
+  g_hash_table_destroy(config);
+
   if(agcomprisBoard!=NULL)
     {
       gcomprisBoard=agcomprisBoard;
@@ -193,6 +200,9 @@ end_board ()
       imageid_destroy_all_items();
       destroy_board_list();
     }
+
+  gcompris_reset_locale();  
+
   gcomprisBoard = NULL;
 }
 
@@ -332,6 +342,15 @@ static GnomeCanvasItem *imageid_create_item(GnomeCanvasGroup *parent)
 				"x",  (double) xp,
 				"y",  (double) yp,
 				NULL);
+  gnome_canvas_item_new (boardRootItem,
+				      gnome_canvas_text_get_type (),
+				      "text", buf[0],
+				      "font", gcompris_skin_font_board_big,
+				      "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2 + 1.0,
+				      "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2 + 1.0,
+				      "anchor", GTK_ANCHOR_CENTER,
+				      "fill_color_rgba", gcompris_skin_color_shadow,
+				      NULL);
   text1_item = gnome_canvas_item_new (boardRootItem,
 				      gnome_canvas_text_get_type (),
 				      "text", buf[0],
@@ -339,7 +358,7 @@ static GnomeCanvasItem *imageid_create_item(GnomeCanvasGroup *parent)
 				      "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2,
 				      "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2,
 				      "anchor", GTK_ANCHOR_CENTER,
-				      "fill_color", "white",
+				      "fill_color_rgba", gcompris_skin_color_text_button,
 				      NULL);
 
   yp += gdk_pixbuf_get_height(button_pixmap) + VERTICAL_SEPARATION;
@@ -349,6 +368,15 @@ static GnomeCanvasItem *imageid_create_item(GnomeCanvasGroup *parent)
 				"x",  (double) xp,
 				"y",  (double) yp,
 				NULL);
+  gnome_canvas_item_new (boardRootItem,
+				      gnome_canvas_text_get_type (),
+				      "text", buf[1],
+				      "font", gcompris_skin_font_board_big,
+				      "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2 + 1.0,
+				      "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2 + 1.0,
+				      "anchor", GTK_ANCHOR_CENTER,
+				      "fill_color_rgba", gcompris_skin_color_shadow,
+				      NULL);
   text2_item = gnome_canvas_item_new (boardRootItem,
 				      gnome_canvas_text_get_type (),
 				      "text", buf[1],
@@ -356,7 +384,7 @@ static GnomeCanvasItem *imageid_create_item(GnomeCanvasGroup *parent)
 				      "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2,
 				      "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2,
 				      "anchor", GTK_ANCHOR_CENTER,
-				      "fill_color", "white",
+				      "fill_color_rgba", gcompris_skin_color_text_button,
 				      NULL);
 
   yp += gdk_pixbuf_get_height(button_pixmap) + VERTICAL_SEPARATION;
@@ -367,6 +395,15 @@ static GnomeCanvasItem *imageid_create_item(GnomeCanvasGroup *parent)
 				"y",  (double) yp,
 				NULL);
 
+  gnome_canvas_item_new (boardRootItem,
+				      gnome_canvas_text_get_type (),
+				      "text", buf[2],
+				      "font", gcompris_skin_font_board_big,
+				      "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2 + 1.0,
+				      "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2 + 1.0,
+				      "anchor", GTK_ANCHOR_CENTER,
+				      "fill_color_rgba", gcompris_skin_color_shadow,
+				      NULL);
   text3_item = gnome_canvas_item_new (boardRootItem,
 				      gnome_canvas_text_get_type (),
 				      "text", buf[2],
@@ -374,7 +411,7 @@ static GnomeCanvasItem *imageid_create_item(GnomeCanvasGroup *parent)
 				      "x", (double) xp + gdk_pixbuf_get_width(button_pixmap)/2,
 				      "y", (double) yp + gdk_pixbuf_get_height(button_pixmap)/2,
 				      "anchor", GTK_ANCHOR_CENTER,
-				      "fill_color", "white",
+				      "fill_color_rgba", gcompris_skin_color_text_button,
 				      NULL);
 
   gdk_pixbuf_unref(button_pixmap);
@@ -602,10 +639,10 @@ static gboolean read_xml_file(char *fname)
   /* if the file doesn't exist */
   if(!g_file_test(fname, G_FILE_TEST_EXISTS))
     {
-      g_warning(_("Couldn't find file %s !"), fname);
+      g_warning("Couldn't find file %s !", fname);
       return FALSE;
     }
-  g_warning(_("find file %s !"), fname);
+  g_warning("found file %s !", fname);
 
   /* parse the new file and put the result into newdoc */
   doc = xmlParseFile(fname);
@@ -646,3 +683,65 @@ static void destroy_board(Board * board) {
 	g_free(board->text3);
 	g_free(board);
 }
+
+
+/* ************************************* */
+/* *            Configuration          * */
+/* ************************************* */
+
+
+/* ======================= */
+/* = config_start        = */
+/* ======================= */
+
+static GcomprisProfile *profile_conf;
+static GcomprisBoard   *board_conf;
+
+static GHFunc save_table (gpointer key,
+		    gpointer value,
+		    gpointer user_data)
+{
+  gcompris_set_board_conf ( profile_conf,
+			    board_conf,
+			    (gchar *) key, 
+			    (gchar *) value);
+}
+
+static GcomprisConfCallback conf_ok(GHashTable *table)
+{
+  g_hash_table_foreach(table, (GHFunc) save_table, NULL);
+  
+  board_conf = NULL;
+  profile_conf = NULL;
+}
+
+static void
+config_start(GcomprisBoard *agcomprisBoard,
+		    GcomprisProfile *aProfile)
+{
+  board_conf = agcomprisBoard;
+  profile_conf = aProfile;
+
+  gcompris_configuration_window( g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
+						 agcomprisBoard->name, 
+						 aProfile->name), 
+				 (GcomprisConfCallback )conf_ok);
+
+  /* init the combo to previously saved value */
+  GHashTable *config = gcompris_get_conf( profile_conf, board_conf);
+
+  gchar *locale = g_hash_table_lookup( config, "locale");
+  
+  gcompris_combo_locales( locale);
+
+}
+
+  
+/* ======================= */
+/* = config_stop        = */
+/* ======================= */
+static void 
+config_stop()
+{
+}
+
