@@ -30,7 +30,6 @@ typedef enum {
   MACH_VERT_WALL,
   MACH_HOLE,
   MACH_DIAG_WALL,
-  MACH_BILLARD_BALL,
   MACH_BASKET_BALL,
   MACH_FLYING_BALL,
 } MachItemType;
@@ -79,13 +78,19 @@ static MachItem		*create_machine_item(MachItemType machItemType, double x, doubl
 /* The border in the image background */
 #define BORDER 40
 
+/* The inner board limit */
+#define MIN_X1	60
+#define MIN_X2	(BOARDWIDTH-MIN_X1)
+#define MIN_Y1	65
+#define MIN_Y2	(BOARDHEIGHT-30)
+
 /* Description of this plugin */
 static BoardPlugin menu_bp =
   {
     NULL,
     NULL,
     N_("Move the mouse"),
-    "minigolf",
+    "football",
     "Bruno Coudoin <bruno.coudoin@free.fr>",
     NULL,
     NULL,
@@ -99,6 +104,8 @@ static BoardPlugin menu_bp =
     NULL,
     set_level,
     NULL,
+    NULL,
+    NULL,
     NULL
   };
 
@@ -108,11 +115,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(machpuzzle)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -195,7 +198,7 @@ static gboolean is_our_board (GcomprisBoard *gcomprisBoard)
 static void minigolf_next_level()
 {
 
-  gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),"images/billard_background.jpg");
+  gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),"images/foot_background.png");
 
   gcompris_bar_set_level(gcomprisBoard);
 
@@ -230,7 +233,6 @@ static void minigolf_destroy_all_items()
 /* ==================================== */
 static GnomeCanvasItem *minigolf_create_item(GnomeCanvasGroup *parent)
 {
-  int i,j;
 
   boardRootItem = GNOME_CANVAS_GROUP(
 				     gnome_canvas_item_new (gnome_canvas_root(gcomprisBoard->canvas),
@@ -240,8 +242,8 @@ static GnomeCanvasItem *minigolf_create_item(GnomeCanvasGroup *parent)
 
 							    NULL));
 
-  create_machine_item(MACH_HOLE, 650.0, 235.0);
-  create_machine_item(MACH_BASKET_BALL, (double)RAND(50, 150), (double)RAND(60, 400));
+  create_machine_item(MACH_HOLE, 730.0, 260.0);
+  create_machine_item(MACH_BASKET_BALL, (double)RAND(60, 150), (double)RAND(60, 400));
 
 
   return NULL;
@@ -306,6 +308,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, MachItem *machItem)
    return FALSE;
 }
 
+#if 0
 static void dump_machItem(MachItem *machItem)
 {
 
@@ -321,15 +324,14 @@ static void dump_machItem(MachItem *machItem)
   printf("          vyo = %f\n", machItem->vyo);
 
 }
+#endif
 
 /* Create a machine item */
 static MachItem *create_machine_item(MachItemType machItemType, double x, double y)
 {
   MachItem		*machItem;
-  GnomeCanvasItem	*item;
   guint			 width;
   guint			 height;
-  guint			 hs = 0;
 
   machItem = g_new (MachItem, 1);
 
@@ -376,17 +378,17 @@ static MachItem *create_machine_item(MachItemType machItemType, double x, double
       break;
     case MACH_HOLE:
       /* Make the hole be smaller based on the level */
-      width = 70 - gcomprisBoard->level*2;
+      width = 110 - gcomprisBoard->level*3;
       machItem->moving	= FALSE;
       machItem->times   = 0.0;
 
-      machItem->xposo	= x;
-      machItem->xpos	= x;
+      machItem->xposo	= x - width/2;
+      machItem->xpos	= x - width/2;
       machItem->vxo	= 0;
       machItem->ax	= 0;
 
-      machItem->yposo	= y;
-      machItem->ypos	= y;
+      machItem->yposo	= y - width/2;
+      machItem->ypos	= y - width/2;
       machItem->vyo	= 0;
       machItem->ay	= 0;
 
@@ -434,7 +436,7 @@ static MachItem *create_machine_item(MachItemType machItemType, double x, double
 					      "x2", (double) machItem->xposo + width,
 					      "y2", (double) machItem->yposo + width,
 					      "outline_color", "black",
-					      "fill_color_rgba", 0xFFFF00FF,
+					      "fill_color", "white",
 					      "width_units", (double)1,
 					      NULL);
 
@@ -598,22 +600,22 @@ static void minigolf_move(GList *item_list)
 	  machItem->vxo += (machItem->ax * machItem->times);
 	  machItem->vyo += (machItem->ay * machItem->times);
 	  
-	  if(machItem->ypos >= BOARDHEIGHT - machItem->height -1)
-	    machItem->ypos = BOARDHEIGHT - machItem->height;
+	  if(machItem->ypos >= MIN_Y2 - machItem->height -1)
+	    machItem->ypos = MIN_Y2 - machItem->height;
 
-	  if(machItem->ypos < 0)
-	    machItem->ypos = 0;
+	  if(machItem->ypos < MIN_Y1)
+	    machItem->ypos = MIN_Y1;
 
-	  if(machItem->xpos < 0)
-	    machItem->xpos = 0;
+	  if(machItem->xpos < MIN_X1)
+	    machItem->xpos = MIN_X1;
 
-	  if(machItem->xpos > BOARDWIDTH)
-	    machItem->xpos = BOARDWIDTH;
+	  if(machItem->xpos > MIN_X2)
+	    machItem->xpos = MIN_X2;
 
 
 	  item_absolute_move(item, machItem->xpos, machItem->ypos);
 	  
-	  if(machItem->ypos>=BOARDHEIGHT-machItem->height-BORDER && (y1 - machItem->ypos)<=0 || collision == TRUE)
+	  if((machItem->ypos>=MIN_Y2-machItem->height-BORDER && (y1 - machItem->ypos)<=0) || collision == TRUE)
 	    {
 	      machItem->vyo   = machItem->vyo * -0.5;
 	      machItem->vxo   = machItem->vxo * 0.5;
@@ -625,7 +627,7 @@ static void minigolf_move(GList *item_list)
 	      //machItem->vxo *= 0.9;
 	    }
 	  
-	  if(y1<=BORDER && (y1 - machItem->ypos)>=0 || collision == TRUE)
+	  if((y1<=MIN_Y1 && (y1 - machItem->ypos)>=0) || collision == TRUE)
 	    {
 	      machItem->vyo   = machItem->vyo * -0.5;
 	      machItem->vxo   = machItem->vxo * 0.5;
@@ -635,7 +637,7 @@ static void minigolf_move(GList *item_list)
 	    }
 
 	  //	  if(x1<=5 && (x1 - machItem->xpos)>0 || collision == TRUE)
-	  if(x1<=BORDER && machItem->vxo<0 || collision == TRUE)
+	  if((x1<=MIN_X1 && machItem->vxo<0) || collision == TRUE)
 	    {
 	      machItem->vyo   = machItem->vyo * 0.5;
 	      machItem->vxo   = machItem->vxo * -0.5;
@@ -644,7 +646,7 @@ static void minigolf_move(GList *item_list)
 	      machItem->xposo=machItem->xpos;
 	    }
 
-	  if(x2>=BOARDWIDTH-BORDER && machItem->vxo>0 || collision == TRUE)
+	  if((x2>=MIN_X2 && machItem->vxo>0) || collision == TRUE)
 	    {
 	      machItem->vyo = 0.5 * machItem->vyo;
 	      machItem->vxo = machItem->vxo * -0.5;
