@@ -87,7 +87,7 @@ static GnomeCanvasItem *maze_create_item(GnomeCanvasGroup *parent);
 static void maze_destroy_all_items(void);
 static void maze_next_level(void);
 static void set_level (guint level);
-static gint key_press(guint keyval);
+static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str);
 /*--------------------*/
 static void draw_a_rect(GnomeCanvasGroup *group, int x1, int y1, int x2, int y2, char *color);
 static void draw_a_line(GnomeCanvasGroup *group, int x1, int y1, int x2, int y2, guint32 color);
@@ -120,8 +120,8 @@ static eyepos_t eye_pos_x=0, eye_pos_y=0, eye_pos_z=0;
 static void threeDdisplay();
 static void twoDdisplay();
 static void draw3D();
-static gint key_press_3D(guint keyval);
-static gint key_press_2D_relative(guint keyval);
+static gint key_press_3D(guint keyval, gchar *commit_str, gchar *preedit_str);
+static gint key_press_2D_relative(guint keyval, gchar *commit_str, gchar *preedit_str);
 /*----------------------*/
 
 /* Description of this plugin */
@@ -144,15 +144,15 @@ static BoardPlugin menu_bp =
     process_ok,
     set_level,//set_level,
     NULL,
-    repeat
+    repeat,
+    NULL,
+    NULL
   };
 
 /* =====================================================================
  *
  * =====================================================================*/
-BoardPlugin *get_bplugin_info(void) {
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(maze)
 
 /* =====================================================================
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -184,6 +184,10 @@ static void start_board (GcomprisBoard *agcomprisBoard) {
 
   if(agcomprisBoard!=NULL) {
     gcomprisBoard=agcomprisBoard;
+
+    /* disable im_context */
+    gcomprisBoard->disable_im_context = TRUE;
+
     gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), 
 			    gcompris_image_to_skin("gcompris-bg.jpg"));
     gcomprisBoard->level=1;
@@ -485,9 +489,9 @@ static GnomeCanvasItem *maze_create_item(GnomeCanvasGroup *parent) {
 						     NULL));
 
   if(modeIsInvisible) {
-    message = _("Look at your position and switch back to invisible mode to move");
+    message = _("Look at your position, then switch back to invisible mode to continue your moves");
   } else {
-    message = _("Look at your position and switch back to 3D mode to move");
+    message = _("Look at your position, then switch back to 3D mode to continue your moves");
   }
 
   warning_item = gnome_canvas_item_new (boardRootItem,
@@ -876,16 +880,16 @@ static void one_step(guint richting)
     }
 }
 
-static gint key_press(guint keyval)
+static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
 {
   guint richting=0,level=gcomprisBoard->level;
 
   if(board_paused)
     return FALSE;
 
-  if (threeDactive) return key_press_3D(keyval);
+  if (threeDactive) return key_press_3D(keyval, commit_str, preedit_str);
 
-  if (modeRelative) return key_press_2D_relative(keyval);
+  if (modeRelative) return key_press_2D_relative(keyval, commit_str, preedit_str);
 
   switch (keyval)
     {
@@ -972,7 +976,7 @@ static gint target_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
  return FALSE;
 }
 
-static gint key_press_2D_relative(guint keyval)
+static gint key_press_2D_relative(guint keyval, gchar *commit_str, gchar *preedit_str)
 {
   guint richting=0,level=gcomprisBoard->level;
 
@@ -1009,7 +1013,7 @@ static gint key_press_2D_relative(guint keyval)
   return TRUE;
 }
 
-static gint key_press_3D(guint keyval)
+static gint key_press_3D(guint keyval, gchar *commit_str, gchar *preedit_str)
 {	
   switch (keyval)
     {	
@@ -1293,7 +1297,7 @@ static const char *color(int dir)
  return "light grey";
 }
 
-static void Display(struct vector position, int viewdir, 
+static void gcDisplay(struct vector position, int viewdir, 
 		    struct screenparam sp, int xmin, int xmax, int dy, gboolean left_wall)
 {  int dxl=dx_left(sp,xmin,dy,left_wall),
      dxr=dx_right(sp,xmax,dy,left_wall),
@@ -1310,7 +1314,7 @@ static void Display(struct vector position, int viewdir,
      struct Trapez t=Trapez_hide(wall_coords(sp,vector_ctor(i,dy),left_wall),xmin,xmax);
      draw_Trapez(threedgroup,t,is_exit?"green":color(left_wall?TURN_LEFT(viewdir):viewdir),"black");
      // draw left of it
-     if (t.x_left-1>=xmin) Display(position,viewdir,sp,xmin,t.x_left-1,dy,left_wall);
+     if (t.x_left-1>=xmin) gcDisplay(position,viewdir,sp,xmin,t.x_left-1,dy,left_wall);
      // right of it ...
      xmin=t.x_right+1;
    }
@@ -1327,21 +1331,21 @@ static void Display(struct vector position, int viewdir,
    draw_Trapez(threedgroup,t,is_exit?"green":color(left_wall?TURN_RIGHT(viewdir):viewdir),"black");
    // draw right of it
    if (t.x_right+1<xmax)
-     Display(position,viewdir,sp,t.x_right+1,xmax,dy,left_wall);
+     gcDisplay(position,viewdir,sp,t.x_right+1,xmax,dy,left_wall);
    // draw right of it
    if (t.x_right+1<xmax)
-     Display(position,viewdir,sp,t.x_right+1,xmax,dy,left_wall);
+     gcDisplay(position,viewdir,sp,t.x_right+1,xmax,dy,left_wall);
    // left of it ...
    xmax=t.x_left-1;
    }
 
  if (xmin<=xmax) // draw in the middle (no wall there)
-   Display(position,viewdir,sp,xmin,xmax,dy+!left_wall,!left_wall);
+   gcDisplay(position,viewdir,sp,xmin,xmax,dy+!left_wall,!left_wall);
 }
 
 static void Display3(struct vector position, int viewdir,
 		     struct screenparam sp)
-{  Display(position, viewdir, sp, sp.pos.x-sp.size.x, sp.pos.x+sp.size.x, 
+{  gcDisplay(position, viewdir, sp, sp.pos.x-sp.size.x, sp.pos.x+sp.size.x, 
 	   0, TRUE);
 }
 
