@@ -20,6 +20,7 @@
 #include <ctype.h>
 #include <math.h>
 #include <assert.h>
+#include <string.h>
 
 #include "gcompris/gcompris.h"
 
@@ -41,6 +42,9 @@ static int gamewon;
 static void		 process_ok(void);
 static void		 highlight_selected(GnomeCanvasItem *);
 static void		 game_won(void);
+static void		 config_start(GcomprisBoard *agcomprisBoard,
+					     GcomprisProfile *aProfile);
+static void		 config_stop(void);
 
 typedef struct _Board Board;
 struct _Board {
@@ -73,8 +77,6 @@ static GList *board_list = NULL;
 #define NUMBER_OF_SUBLEVELS 9
 #define NUMBER_OF_LEVELS 4
 
-#define TEXT_COLOR "white"
-
 /* ================================================================ */
 static int board_number; // between 0 and board_list.length-1
 static int right_word; // between 1 and 3, indicates which choice is the right one (the player clicks on it
@@ -85,7 +87,8 @@ static GnomeCanvasItem *image_item = NULL;
 static GnomeCanvasItem *l1_item = NULL;
 static GnomeCanvasItem *l2_item = NULL;
 static GnomeCanvasItem *l3_item = NULL;
-static GnomeCanvasItem *text = NULL;
+static GnomeCanvasItem *text    = NULL;
+static GnomeCanvasItem *text_s  = NULL;
 static GnomeCanvasItem *button1 = NULL, *button2 = NULL, *button3 = NULL, *selected_button = NULL;
 
 static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent);
@@ -113,7 +116,9 @@ static BoardPlugin menu_bp =
     process_ok,
     set_level,
     NULL,
-    NULL
+    NULL,
+    config_start,
+    config_stop
   };
 
 /*
@@ -122,11 +127,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(missingletter)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -151,11 +152,17 @@ static void pause_board (gboolean pause)
  */
 static void start_board (GcomprisBoard *agcomprisBoard)
 {
+  GHashTable *config = gcompris_get_board_conf();
+
+  gcompris_change_locale(g_hash_table_lookup( config, "locale"));
+
+  g_hash_table_destroy(config);
+
   if(agcomprisBoard!=NULL)
     {
       gcomprisBoard=agcomprisBoard;
       gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
-			      "missing_letter/missingletter-bg.jpg");
+			      gcompris_image_to_skin("missingletter-bg.jpg"));
       gcomprisBoard->level=1;
       gcomprisBoard->maxlevel=NUMBER_OF_LEVELS;
       gcomprisBoard->sublevel=1;
@@ -185,6 +192,9 @@ static void end_board ()
       missing_letter_destroy_all_items();
       destroy_board_list();
     }
+
+  gcompris_reset_locale();
+
   gcomprisBoard = NULL;
 }
 
@@ -260,7 +270,7 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
 
   /* this is the coordinate of the text to find */
   gint txt_area_x = 515;
-  gint txt_area_y = 430;
+  gint txt_area_y = 435;
 
   board_number = (gcomprisBoard->level-1) * NUMBER_OF_SUBLEVELS + gcomprisBoard->sublevel-1;
 
@@ -285,6 +295,15 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
 
   yOffset = (gcomprisBoard->height - gdk_pixbuf_get_height(button_pixmap) - gdk_pixbuf_get_height(pixmap) - 2*VERTICAL_SEPARATION)/2;
 
+  text_s = gnome_canvas_item_new (boardRootItem,
+				gnome_canvas_text_get_type (),
+				"text", _(board->question),
+				"font", gcompris_skin_font_board_huge_bold,
+				"x", (double) txt_area_x + 1.0,
+				"y", (double) txt_area_y + 1.0,
+				"anchor", GTK_ANCHOR_CENTER,
+				"fill_color_rgba", gcompris_skin_get_color("missingletter/shadow"),
+				NULL);
   text = gnome_canvas_item_new (boardRootItem,
 				gnome_canvas_text_get_type (),
 				"text", _(board->question),
@@ -292,7 +311,7 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
 				"x", (double) txt_area_x,
 				"y", (double) txt_area_y,
 				"anchor", GTK_ANCHOR_CENTER,
-				"fill_color", TEXT_COLOR,
+				"fill_color_rgba", gcompris_skin_get_color("missingletter/question"),
 				NULL);
 
   gnome_canvas_item_get_bounds(text, &dx1, &dy1, &dx2, &dy2);
@@ -340,6 +359,15 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
 				   "x",  (double) xOffset,
 				   "y",  (double) yOffset,
 				   NULL);
+  gnome_canvas_item_new (boardRootItem,
+				   gnome_canvas_text_get_type (),
+				   "text", buf[0],
+				   "font", gcompris_skin_font_board_huge_bold,
+				   "x", (double) xOffset + gdk_pixbuf_get_width(button_pixmap)/2 + 1.0,
+				   "y", (double) yOffset + gdk_pixbuf_get_height(button_pixmap)/2 + 1.0,
+				   "anchor", GTK_ANCHOR_CENTER,
+				   "fill_color_rgba", gcompris_skin_color_shadow,
+				   NULL);
   l1_item = gnome_canvas_item_new (boardRootItem,
 				   gnome_canvas_text_get_type (),
 				   "text", buf[0],
@@ -347,7 +375,7 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
 				   "x", (double) xOffset + gdk_pixbuf_get_width(button_pixmap)/2,
 				   "y", (double) yOffset + gdk_pixbuf_get_height(button_pixmap)/2,
 				   "anchor", GTK_ANCHOR_CENTER,
-				   "fill_color", TEXT_COLOR,
+				   "fill_color_rgba", gcompris_skin_color_text_button,
 				   NULL);
 
   yOffset += HORIZONTAL_SEPARATION + gdk_pixbuf_get_height(button_pixmap);
@@ -357,6 +385,15 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
 				   "x",  (double) xOffset,
 				   "y",  (double) yOffset,
 				   NULL);
+  gnome_canvas_item_new (boardRootItem,
+				   gnome_canvas_text_get_type (),
+				   "text", buf[1],
+				   "font", gcompris_skin_font_board_huge_bold,
+				   "x", (double) xOffset + gdk_pixbuf_get_width(button_pixmap)/2 + 1.0,
+				   "y", (double) yOffset + gdk_pixbuf_get_height(button_pixmap)/2 + 1.0,
+				   "anchor", GTK_ANCHOR_CENTER,
+				   "fill_color_rgba", gcompris_skin_color_shadow,
+				   NULL);
   l2_item = gnome_canvas_item_new (boardRootItem,
 				   gnome_canvas_text_get_type (),
 				   "text", buf[1],
@@ -364,7 +401,7 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
 				   "x", (double) xOffset + gdk_pixbuf_get_width(button_pixmap)/2,
 				   "y", (double) yOffset + gdk_pixbuf_get_height(button_pixmap)/2,
 				   "anchor", GTK_ANCHOR_CENTER,
-				   "fill_color", TEXT_COLOR,
+				   "fill_color_rgba", gcompris_skin_color_text_button,
 				   NULL);
 
   yOffset += HORIZONTAL_SEPARATION + gdk_pixbuf_get_height(button_pixmap);
@@ -375,6 +412,15 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
 				   "x",  (double) xOffset,
 				   "y",  (double) yOffset,
 				   NULL);
+  gnome_canvas_item_new (boardRootItem,
+				   gnome_canvas_text_get_type (),
+				   "text", buf[2],
+				   "font", gcompris_skin_font_board_huge_bold,
+				   "x", (double) xOffset + gdk_pixbuf_get_width(button_pixmap)/2 + 1.0,
+				   "y", (double) yOffset + gdk_pixbuf_get_height(button_pixmap)/2 + 1.0,
+				   "anchor", GTK_ANCHOR_CENTER,
+				   "fill_color_rgba", gcompris_skin_color_shadow,
+				   NULL);
   l3_item = gnome_canvas_item_new (boardRootItem,
 				   gnome_canvas_text_get_type (),
 				   "text", buf[2],
@@ -382,7 +428,7 @@ static GnomeCanvasItem *missing_letter_create_item(GnomeCanvasGroup *parent)
 				   "x", (double) xOffset + gdk_pixbuf_get_width(button_pixmap)/2,
 				   "y", (double) yOffset + gdk_pixbuf_get_height(button_pixmap)/2,
 				   "anchor", GTK_ANCHOR_CENTER,
-				   "fill_color", TEXT_COLOR,
+				   "fill_color_rgba", gcompris_skin_color_text_button,
 				   NULL);
 
   gdk_pixbuf_unref(button_pixmap);
@@ -420,7 +466,8 @@ static gboolean process_ok_timeout() {
 
 static void process_ok() {
   if (gamewon) {
-    gnome_canvas_item_set(text, "text", board->answer, NULL);
+    gnome_canvas_item_set(text,   "text", board->answer, NULL);
+    gnome_canvas_item_set(text_s, "text", board->answer, NULL);
   }
   // leave time to display the right answer
   gcompris_bar_hide(TRUE);
@@ -605,10 +652,10 @@ static gboolean read_xml_file(char *fname)
   /* if the file doesn't exist */
   if(!g_file_test(fname, G_FILE_TEST_EXISTS))
     {
-      g_warning(_("Couldn't find file %s !"), fname);
+      g_warning("Couldn't find file %s !", fname);
       return FALSE;
     }
-  g_warning(_("find file %s !"), fname);
+  g_warning("found file %s !", fname);
 
   /* parse the new file and put the result into newdoc */
   doc = xmlParseFile(fname);
@@ -651,3 +698,65 @@ static void destroy_board(Board * board) {
   g_free(board->l3);
   g_free(board);
 }
+
+/* ************************************* */
+/* *            Configuration          * */
+/* ************************************* */
+
+
+/* ======================= */
+/* = config_start        = */
+/* ======================= */
+
+static GcomprisProfile *profile_conf;
+static GcomprisBoard   *board_conf;
+
+static GHFunc save_table (gpointer key,
+		    gpointer value,
+		    gpointer user_data)
+{
+  gcompris_set_board_conf ( profile_conf,
+			    board_conf,
+			    (gchar *) key, 
+			    (gchar *) value);
+}
+
+static GcomprisConfCallback conf_ok(GHashTable *table)
+{
+  g_hash_table_foreach(table, (GHFunc) save_table, NULL);
+  
+  board_conf = NULL;
+  profile_conf = NULL;
+
+  return NULL;
+}
+
+static void
+config_start(GcomprisBoard *agcomprisBoard,
+		    GcomprisProfile *aProfile)
+{
+  board_conf = agcomprisBoard;
+  profile_conf = aProfile;
+
+  gcompris_configuration_window( g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
+						 agcomprisBoard->name, 
+						 aProfile->name), 
+				 (GcomprisConfCallback )conf_ok);
+
+  /* init the combo to previously saved value */
+  GHashTable *config = gcompris_get_conf( profile_conf, board_conf);
+
+  gchar *locale = g_hash_table_lookup( config, "locale");
+  
+  gcompris_combo_locales( locale);
+
+}
+
+  
+/* ======================= */
+/* = config_stop        = */
+/* ======================= */
+static void 
+config_stop()
+{
+}
