@@ -84,8 +84,8 @@ static BoardPlugin menu_bp =
   {
     NULL,
     NULL,
-    N_("Money"),
-    N_("Pratice money usage"),
+    "Money",
+    "Pratise money usage",
     "Bruno Coudoin <bruno.coudoin@free.fr>",
     NULL,
     NULL,
@@ -99,6 +99,8 @@ static BoardPlugin menu_bp =
     process_ok,
     set_level,
     NULL,
+    NULL,
+    NULL,
     NULL
   };
 
@@ -108,11 +110,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(money)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -204,7 +202,6 @@ gboolean is_our_board (GcomprisBoard *gcomprisBoard)
 /* set initial values for the next level */
 static void money_next_level()
 {
-  GnomeCanvasItem *item = NULL;
   GdkPixbuf       *pixmap = NULL;
   guint		   min_price, max_price;
   guint		   number_of_item;
@@ -212,7 +209,7 @@ static void money_next_level()
   gchar		  *display_format;
 
   gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
-			  "money/money-bg.png");
+			  gcompris_image_to_skin("money-bg.png"));
 
   gcompris_bar_set_level(gcomprisBoard);
 
@@ -471,6 +468,7 @@ static void money_next_level()
   for(i=1; i<=number_of_item; i++)
   {
     double object_price;
+    gchar *text;
 
     pixmap = gcompris_load_pixmap(imageList[RAND(0, NUMBER_OF_IMAGES-1)]);
 
@@ -487,7 +485,8 @@ static void money_next_level()
 
     if(currentMode==WITH_CENTS)
       {
-	display_format = "%.2f €";
+	/* Set here the way to display money. Change only the money sign, and it's place, always keep %.2f, it will be replaced by 0,34 if decimal is ',' in your locale */
+	display_format = _("$ %.2f");
 	/* Add random cents */
 	if(gcomprisBoard->level == 1)
 	  {
@@ -500,20 +499,21 @@ static void money_next_level()
       }
     else
       {
-	display_format = "%.0f €";
+	display_format = _("$ %.0f");
       }
 
     price_target += object_price;
+    text = g_strdup_printf(display_format, object_price);
     gnome_canvas_item_new(boardRootItem,
 			  gnome_canvas_text_get_type (),
-			  "text", g_strdup_printf(display_format, object_price),
+			  "text", text,
 			  "font", gcompris_skin_font_board_big,
 			  "x", (double) (i*BOARDWIDTH)/(number_of_item+1),
 			  "y", (double) 180,
 			  "anchor", GTK_ANCHOR_CENTER,
 			  "fill_color", "white",
 			  NULL);
-    
+    g_free(text);
     gdk_pixbuf_unref(pixmap);
   }
 
