@@ -107,10 +107,10 @@ money_widget_get_type ()
 	return money_widget_type;
 }
 
+#if 0
 static void
 finalize (GtkObject *object)
 {
-  guint		   i, length;
   MoneyItem	  *moneyitem;
 
   Money_Widget *moneyWidget = (Money_Widget *) object;
@@ -130,6 +130,7 @@ finalize (GtkObject *object)
   moneyWidget->priv = NULL;
 
 }
+#endif
 
 static void
 class_init (Money_WidgetClass *class)
