@@ -1,6 +1,6 @@
 /* gcompris - paratrooper.c
  *
- * Time-stamp: <2005/03/30 22:04:44 bruno>
+ * Time-stamp: <2005/10/12 23:25:31 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -77,7 +77,7 @@ static void	 	 pause_board (gboolean pause);
 static void	 	 end_board (void);
 static gboolean	 	 is_our_board (GcomprisBoard *gcomprisBoard);
 static void	 	 set_level (guint level);
-static gint	 	 key_press(guint keyval);
+static gint	 	 key_press(guint keyval, gchar *commit_str, gchar *preedit_str);
 
 static GnomeCanvasItem	*paratrooper_create_cloud(GnomeCanvasGroup *parent);
 static gint		 paratrooper_drop_clouds (GtkWidget *widget, gpointer data);
@@ -114,6 +114,8 @@ static BoardPlugin menu_bp =
    NULL,
    set_level,
    NULL,
+   NULL,
+   NULL,
    NULL
 };
 
@@ -123,11 +125,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin 
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(paratrooper)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -183,6 +181,9 @@ static void start_board (GcomprisBoard *agcomprisBoard)
     {
       gcomprisBoard=agcomprisBoard;
 
+      /* disable im_context */
+      gcomprisBoard->disable_im_context = TRUE;
+
       gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery3_background.png");
 
 
@@ -226,7 +227,7 @@ set_level (guint level)
     }
 }
 
-static gint key_press(guint keyval)
+static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
 {
 
   if(!gcomprisBoard)
@@ -256,46 +257,6 @@ static gint key_press(guint keyval)
     case GDK_KP_Enter:
     case GDK_Return:
       return TRUE;
-    case GDK_KP_0:
-    case GDK_KP_Insert:
-      keyval=GDK_0;
-      break;
-    case GDK_KP_1:
-    case GDK_KP_End:
-      keyval=GDK_1;
-      break;
-    case GDK_KP_2:
-    case GDK_KP_Down:
-      keyval=GDK_2;
-      break;
-    case GDK_KP_3:
-    case GDK_KP_Page_Down:
-      keyval=GDK_3;
-      break;
-    case GDK_KP_4:
-    case GDK_KP_Left:
-      keyval=GDK_4;
-      break;
-    case GDK_KP_5:
-    case GDK_KP_Begin:
-      keyval=GDK_5;
-      break;
-    case GDK_KP_6:
-    case GDK_KP_Right:
-      keyval=GDK_6;
-      break;
-    case GDK_KP_7:
-    case GDK_KP_Home:
-      keyval=GDK_7;
-      break;
-    case GDK_KP_8:
-    case GDK_KP_Up:
-      keyval=GDK_8;
-      break;
-    case GDK_KP_9:
-    case GDK_KP_Page_Up:
-      keyval=GDK_9;
-      break;
     case GDK_Right:
       break;
     case GDK_Left:
