@@ -1,6 +1,6 @@
 /* gcompris - planegame.c
  *
- * Time-stamp: <2005/03/30 22:05:27 bruno>
+ * Time-stamp: <2005/10/15 16:54:30 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -54,7 +54,7 @@ static void pause_board (gboolean pause);
 static void end_board (void);
 static gboolean is_our_board (GcomprisBoard *gcomprisBoard);
 static void set_level (guint level);
-static gint key_press(guint keyval);
+static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str);
 
 static GnomeCanvasItem *planegame_create_item(GnomeCanvasGroup *parent);
 static gint planegame_drop_items (GtkWidget *widget, gpointer data);
@@ -89,6 +89,8 @@ static BoardPlugin menu_bp =
    NULL,
    set_level,
    NULL,
+   NULL,
+   NULL,
    NULL
 };
 
@@ -98,11 +100,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin 
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(planegame)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -145,6 +143,9 @@ static void start_board (GcomprisBoard *agcomprisBoard)
     {
       gcomprisBoard=agcomprisBoard;
 
+      /* disable im_context */
+      gcomprisBoard->disable_im_context = TRUE;
+
       gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery3_background.png");
 
 
@@ -186,7 +187,7 @@ set_level (guint level)
     }
 }
 
-static gint key_press(guint keyval)
+static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
 {
 
   if(!gcomprisBoard)
@@ -215,46 +216,6 @@ static gint key_press(guint keyval)
     case GDK_KP_Enter:
     case GDK_Return:
       return TRUE;
-    case GDK_KP_0:
-    case GDK_KP_Insert:
-      keyval=GDK_0;
-      break;
-    case GDK_KP_1:
-    case GDK_KP_End:
-      keyval=GDK_1;
-      break;
-    case GDK_KP_2:
-    case GDK_KP_Down:
-      keyval=GDK_2;
-      break;
-    case GDK_KP_3:
-    case GDK_KP_Page_Down:
-      keyval=GDK_3;
-      break;
-    case GDK_KP_4:
-    case GDK_KP_Left:
-      keyval=GDK_4;
-      break;
-    case GDK_KP_5:
-    case GDK_KP_Begin:
-      keyval=GDK_5;
-      break;
-    case GDK_KP_6:
-    case GDK_KP_Right:
-      keyval=GDK_6;
-      break;
-    case GDK_KP_7:
-    case GDK_KP_Home:
-      keyval=GDK_7;
-      break;
-    case GDK_KP_8:
-    case GDK_KP_Up:
-      keyval=GDK_8;
-      break;
-    case GDK_KP_9:
-    case GDK_KP_Page_Up:
-      keyval=GDK_9;
-      break;
     case GDK_Right:
       if(planespeed_x < MAXSPEED)
 	planespeed_x++;
@@ -301,7 +262,6 @@ is_our_board (GcomprisBoard *gcomprisBoard)
 static void planegame_next_level() 
 {
   GdkPixbuf *pixmap = NULL;
-  char *str = NULL;
 
   gcompris_bar_set_level(gcomprisBoard);
 
@@ -316,8 +276,7 @@ static void planegame_next_level()
   /* Setup and Display the plane */
   planespeed_y = 0;
   planespeed_x = 0;
-  str = g_strdup_printf("%s%s", pixmapsdir, "tuxhelico.png");
-  pixmap = gcompris_load_pixmap(str);
+  pixmap = gcompris_load_pixmap("gcompris/misc/tuxhelico.png");
   plane_x = 50;
   plane_y = 300;
   planeitem = gnome_canvas_item_new (gnome_canvas_root(gcomprisBoard->canvas),
@@ -353,10 +312,6 @@ static void planegame_next_level()
 			   gcomprisBoard->number_of_sublevel);
       gcompris_score_set(gcomprisBoard->sublevel);
     }
-
-
-  g_free (str);
-
 }
 
 #define ISIN(x1, y1, px1, py1, px2, py2) (x1>px1 && x1<px2 && y1>py1 && y2<py2 ? TRUE : FALSE)
@@ -512,7 +467,6 @@ static GnomeCanvasItem *planegame_create_item(GnomeCanvasGroup *parent)
 {
   GdkPixbuf *pixmap = NULL;
   GnomeCanvasItem *itemgroup;
-  char *str = NULL;
   char *number = NULL;
   int i, min;
   CloudItem *clouditem;
@@ -530,8 +484,7 @@ static GnomeCanvasItem *planegame_create_item(GnomeCanvasGroup *parent)
     }
   number = g_strdup_printf("%d", i);
 
-  str = g_strdup_printf("%s%s", pixmapsdir, "cloud.png");
-  pixmap = gcompris_load_pixmap(str);
+  pixmap = gcompris_load_pixmap("gcompris/misc/cloud.png");
 
   itemgroup = \
     gnome_canvas_item_new (parent,
@@ -574,7 +527,6 @@ static GnomeCanvasItem *planegame_create_item(GnomeCanvasGroup *parent)
 
   item_list = g_list_append (item_list, clouditem);
 
-  g_free (str);
   g_free (number);
 
   return (itemgroup);
