@@ -20,6 +20,8 @@ class Gcompris_ballcatch:
   def __init__(self, gcomprisBoard):
     self.gcomprisBoard = gcomprisBoard
 
+    self.gcomprisBoard.disable_im_context = True
+
     # These are used to let us restart only after the bonus is displayed.
     # When the bonus is displayed, it call us first with pause(1) and then with pause(0)
     self.board_paused  = 0;
@@ -139,7 +141,7 @@ class Gcompris_ballcatch:
     print("Gcompris_ballcatch config.")
 
 
-  def key_press(self, keyval):
+  def key_press(self, keyval, commit_str, preedit_str):
     print("Gcompris_ballcatch key press. %i" % keyval)
 
     if (keyval == gtk.keysyms.Shift_L):
@@ -148,7 +150,7 @@ class Gcompris_ballcatch:
     if (keyval == gtk.keysyms.Shift_R):
       self.right_continue = False
 
-    return gtk.FALSE
+    return False
       
   # Called by gcompris core 
   def pause(self, pause):
