@@ -35,6 +35,9 @@ class Gcompris_melody:
 
   def __init__(self, gcomprisBoard):
     self.gcomprisBoard = gcomprisBoard
+
+    self.gcomprisBoard.disable_im_context = True
+    
     print("Gcompris_melody __init__.")
 
     # These are used to let us restart only after the bonux is displayed.
@@ -47,6 +50,11 @@ class Gcompris_melody:
     self.gcomprisBoard.level=1
     self.gcomprisBoard.sublevel=1 
     self.gcomprisBoard.number_of_sublevel=1
+
+    # pause the bg music
+    print "pause sound"
+    gcompris.sound.pause()
+
     self.timers = []
     self.solution = []
     self.kidstry = []
@@ -86,17 +94,18 @@ class Gcompris_melody:
     self.gcomprisBoard.maxlevel = 9
 
     # Play an intro sound
-    gcompris.sound.play_ogg("melody/" + self.melodylist[self.theme][0]['theme'] + "/melody")
+    gcompris.sound.play_ogg_cb("melody/" + self.melodylist[self.theme][0]['theme'] + "/melody", self.intro_cb)
     
     gcompris.bar_set(gcompris.BAR_REPEAT|gcompris.BAR_LEVEL)
 
     self.display_current_level()
-    self.pause(0);
+    self.pause(1);
     print("Gcompris_melody start.")
     
   def end(self):
     self.cleanup()
     print("Gcompris_melody end.")
+    gcompris.sound.resume()
         
 
   def ok(self):
@@ -210,7 +219,7 @@ class Gcompris_melody:
 
     self.bang_item.show()
     
-    gcompris.sound.play_ogg(a['sound'])
+    gcompris.sound.play_ogg_cb(a['sound'], self.sound_played)
     self.timers.pop(0)
 
 
@@ -255,27 +264,27 @@ class Gcompris_melody:
       
     self.timers.append(gtk.timeout_add(1300, self.repeat_it))
               
-  def key_press(self, keyval):
+  def key_press(self, keyval, commit_str, preedit_str):
     print("got key %i" % keyval)
     # Play sounds with the keys
     if ((keyval == gtk.keysyms.KP_1) or (keyval == gtk.keysyms._1)):
       print "son1"
       self.sound_play(self.melodylist[self.theme][1][0])
-      return gtk.TRUE
+      return True
     if ((keyval == gtk.keysyms.KP_2) or (keyval == gtk.keysyms._2)):
       print "son2"
       self.sound_play(self.melodylist[self.theme][1][1])
-      return gtk.TRUE
+      return True
     if ((keyval == gtk.keysyms.KP_3) or (keyval == gtk.keysyms._3)):
       print "son3"
       self.sound_play(self.melodylist[self.theme][1][2])
-      return gtk.TRUE
+      return True
     if ((keyval == gtk.keysyms.KP_4) or (keyval == gtk.keysyms._4)):
       print "son4"
       self.sound_play(self.melodylist[self.theme][1][3])
-      return gtk.TRUE
+      return True
 
-    return gtk.FALSE
+    return False
 
 
   def pause(self, pause):  
@@ -325,11 +334,11 @@ class Gcompris_melody:
     if event.type == gtk.gdk.BUTTON_PRESS:
       if event.button == 1:
           self.sound_play(sound_struct)
-    return gtk.FALSE
+    return False
   
   # ---------------- sound is effectively played -----------------------
   def sound_play(self, sound_struct):
-    gcompris.sound.play_ogg(sound_struct['sound'])
+    gcompris.sound.play_ogg_cb(sound_struct['sound'], self.sound_played)
     self.tried(sound_struct)
     return
   
@@ -352,5 +361,13 @@ class Gcompris_melody:
       	self.display_current_level()
 
     
-    return gtk.FALSE
-  
+    return False
+
+  def sound_played(self, file):
+    print "python sound played :", file
+
+  def intro_cb(self, file):
+    print "intro passed. go play"
+    self.pause(0)
+    self.populate(self.sound_list)	
+   
\ No newline at end of file
