@@ -82,8 +82,8 @@ static BoardPlugin menu_bp =
   {
     NULL,
     NULL,
-    N_("Read Colors"),
-    N_("Click on the corresponding color"),
+    "Read Colors",
+    "Click on the corresponding color",
     "Pascal Georges pascal.georges1@free.fr>",
     NULL,
     NULL,
@@ -97,15 +97,15 @@ static BoardPlugin menu_bp =
     process_ok,
     NULL,//set_level,
     NULL,
+    NULL,
+    NULL,
     NULL
   };
 
 /* =====================================================================
  *
  * =====================================================================*/
-BoardPlugin *get_bplugin_info(void) {
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(read_colors)
 
 /* =====================================================================
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -351,7 +351,7 @@ static void process_ok() {
  * =====================================================================*/
 static gint item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data) {
   double x, y;
-  int i, j, clicked;
+  int i, clicked;
 
   x = event->button.x;
   y = event->button.y;
@@ -419,7 +419,6 @@ static void init_xml()
 static void add_xml_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
 {
   char *text = NULL;
-  char * tmp = NULL;
   char *sColor = NULL;
   int color = 0;
   int i;
@@ -489,10 +488,10 @@ static gboolean read_xml_file(char *fname)
   /* if the file doesn't exist */
   if(!g_file_test(fname, G_FILE_TEST_EXISTS))
     {
-      g_warning(_("Couldn't find file %s !"), fname);
+      g_warning("Couldn't find file %s !", fname);
       return FALSE;
     }
-  g_warning(_("find file %s !"), fname);
+  g_warning("found file %s !", fname);
 
   /* parse the new file and put the result into newdoc */
   doc = xmlParseFile(fname);
