@@ -1,6 +1,6 @@
 /* gcompris - reading.c
  *
- * Time-stamp: <2004/11/06 23:14:34 bruno>
+ * Time-stamp: <2005/09/29 22:09:55 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -23,6 +23,7 @@
 
 #include <errno.h>
 #include <stdio.h>
+#include <string.h>
 
 #include "gcompris/gcompris.h"
 
@@ -73,6 +74,9 @@ static LettersItem toDeleteFocus;
 gint current_x;
 gint current_y;
 gint numberOfLine;
+gint font_size;
+gint interline;
+
 
 static void		 start_board (GcomprisBoard *agcomprisBoard);
 static void		 pause_board (gboolean pause);
@@ -87,6 +91,9 @@ static gint		 reading_drop_items (void);
 //static void reading_destroy_item(LettersItem *item);
 static void		 reading_destroy_all_items(void);
 static gint		 reading_next_level(void);
+static void		 reading_config_start(GcomprisBoard *agcomprisBoard,
+					     GcomprisProfile *aProfile);
+static void		 reading_config_stop(void);
 
 static void		 player_win(void);
 static void		 player_loose(void);
@@ -104,8 +111,8 @@ static BoardPlugin menu_bp =
 {
    NULL,
    NULL,
-   N_("Reading"),
-   N_("Read a list of words and then tell if the given word is in it"),
+   "Reading",
+   "Read a list of words and then work out if the given word is in it",
    "Bruno Coudoin <bruno.coudoin@free.fr>",
    NULL,
    NULL,
@@ -119,7 +126,9 @@ static BoardPlugin menu_bp =
    NULL,
    set_level,
    NULL,
-   NULL
+   NULL,
+   reading_config_start,
+   reading_config_stop
 };
 
 /*
@@ -128,11 +137,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(reading)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = UNPAUSE
@@ -167,12 +172,18 @@ static void pause_board (gboolean pause)
  */
 static void start_board (GcomprisBoard *agcomprisBoard)
 {
+  GHashTable *config = gcompris_get_board_conf();
+
+  gcompris_change_locale(g_hash_table_lookup( config, "locale"));
+
+  g_hash_table_destroy(config);
 
   if(agcomprisBoard!=NULL)
     {
       gcomprisBoard=agcomprisBoard;
 
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "reading/reading-bg.jpg");
+      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
+			      gcompris_image_to_skin("reading-bg.jpg"));
       wait_for_ready = TRUE;
       gamewon = FALSE;
 
@@ -180,6 +191,21 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->maxlevel = 9;
       gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
 
+      font_size = PANGO_PIXELS(pango_font_description_get_size (pango_font_description_from_string (gcompris_skin_font_board_medium)));
+      interline = (int) (1.5*font_size);
+
+      PangoContext *pango_context = gtk_widget_get_pango_context  (GTK_WIDGET(agcomprisBoard->canvas));
+
+      PangoFontMetrics* pango_metrics =  pango_context_get_metrics (pango_context,
+								    pango_font_description_from_string (gcompris_skin_font_board_medium),
+								    pango_language_from_string   (gcompris_get_locale()));
+
+      int ascent = PANGO_PIXELS(pango_font_metrics_get_ascent (pango_metrics));
+      int descent = PANGO_PIXELS(pango_font_metrics_get_descent (pango_metrics));
+      interline = ascent + descent;
+
+      g_warning ("Font to display words have size %d  ascent : %d, descent : %d.\n Set inerline to %d", font_size, ascent, descent, interline);
+
       /* Default mode */
       currentMode=MODE_VERTICAL;
       if(gcomprisBoard->mode && g_strcasecmp(gcomprisBoard->mode, "horizontal")==0)
@@ -198,6 +224,9 @@ end_board ()
       pause_board(TRUE);
       reading_destroy_all_items();
     }
+
+  gcompris_reset_locale();
+
   gcomprisBoard = NULL;
 }
 
@@ -265,7 +294,7 @@ static gint reading_next_level()
       numberOfLine=2+gcomprisBoard->level;
     }
 
-  current_y = BASE_Y1;
+  current_y = BASE_Y1 - 2 * interline;
 
   gcomprisBoard->number_of_sublevel=1;
   gcomprisBoard->sublevel=1;
@@ -302,14 +331,12 @@ static void reading_destroy_all_items()
     g_free(textToFind);
     textToFind=NULL;
     }
-  
+
   if (words!=NULL) 
     {
     g_ptr_array_free (words, TRUE);
     words=NULL;
     }
-  
-  
 
 }
 
@@ -370,10 +397,8 @@ static GnomeCanvasItem *display_what_to_do(GnomeCanvasGroup *parent)
 
 static gboolean reading_create_item(GnomeCanvasGroup *parent)
 {
-  gint   i;
   gint   anchor = GTK_ANCHOR_CENTER;
   gchar *word;
-  gchar *overword;
 
   assert(textToFind!=NULL);
 
@@ -413,10 +438,6 @@ static gboolean reading_create_item(GnomeCanvasGroup *parent)
   if(textToFindIndex>=0)
     textToFindIndex--;
 
-  /* fill up the overword with X */
-
-  overword = g_strnfill (g_utf8_strlen(word,-1),'x');
-
   previousFocus.rootItem = \
     GNOME_CANVAS_GROUP( gnome_canvas_item_new (parent,
 					       gnome_canvas_group_get_type (),
@@ -431,30 +452,32 @@ static gboolean reading_create_item(GnomeCanvasGroup *parent)
     gnome_canvas_item_new (GNOME_CANVAS_GROUP(previousFocus.rootItem),
 			   gnome_canvas_text_get_type (),
 			   "text", word,
-			   "font", gcompris_skin_font_board_fixed,
+			   "font", gcompris_skin_font_board_medium,
 			   "x", (double) 0,
 			   "y", (double) 0,
 			   "anchor", anchor,
 			   "fill_color", "black",
 			   NULL);
 
+  gchar *oldword = g_strdup_printf("<span foreground=\"black\" background=\"black\">%s</span>", word);
+
   previousFocus.overwriteItem = \
     gnome_canvas_item_new (GNOME_CANVAS_GROUP(previousFocus.rootItem),
 			   gnome_canvas_text_get_type (),
-			   "text", overword,
-			   "font", gcompris_skin_font_board_fixed,
+			   "markup", oldword,
+			   "font", gcompris_skin_font_board_medium,
 			   "x", (double) 0,
 			   "y", (double) 0,
 			   "anchor", anchor,
-			   "fill_color", "black",
 			   NULL);
+
+  g_free(oldword);
   gnome_canvas_item_hide(previousFocus.overwriteItem);
-  g_free(overword);
 
   // Calculate the next spot
   if(currentMode==MODE_VERTICAL)
     {
-      current_y += 20;
+      current_y += interline;
       numberOfLine--;
     }
   else
@@ -467,12 +490,12 @@ static gboolean reading_create_item(GnomeCanvasGroup *parent)
       if(x2>BASE_X2)
 	{
 	  // Do the line Wrapping
-	  gnome_canvas_item_move(GNOME_CANVAS_ITEM(previousFocus.rootItem), BASE_X1-x1, 20);
-	  current_y += 20;
+	  gnome_canvas_item_move(GNOME_CANVAS_ITEM(previousFocus.rootItem), BASE_X1-x1, interline);
+	  current_y += interline;
 	  current_x = BASE_X1;
 	  numberOfLine--;
 	}
-      current_x += x2-x1 + 12;
+      current_x += x2-x1 + font_size;
     }
 
   return (TRUE);
@@ -571,7 +594,7 @@ static void ask_yes_no()
 
   item = gnome_canvas_item_new (boardRootItem,
 				gnome_canvas_text_get_type (),
-				"text", _("Yes I saw it"),
+				"text", _("Yes, I saw it"),
 				"font", gcompris_skin_font_board_big,
 				"x", (double) x_offset +
 				gdk_pixbuf_get_width(button_pixmap)/2,
@@ -685,6 +708,7 @@ item_event_valid(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	  {
 	    player_loose();
 	  }
+	return TRUE;
       }
       break;
 
@@ -712,12 +736,13 @@ static FILE *get_wordfile(const char *locale)
                                                                                                                               
   if(wordsfd==NULL)
     {
+      g_free(filename);
       /* Second Try to find a file matching the 'max' and the locale */
-      g_sprintf(filename, "%s%s%.2s",
-              PACKAGE_DATA_DIR, "/wordsgame/wordslevelmax.",
-              locale);
+      filename = g_strdup_printf("%s%s%.2s",
+				 PACKAGE_DATA_DIR, "/wordsgame/wordslevelmax.",
+				 locale);
       //      g_message("Trying to open file %s ", filename);
-                                                                                                                              
+      
       wordsfd = fopen (filename, "r");
     }
                                                                                                                               
@@ -780,6 +805,67 @@ static gchar *get_random_word(gboolean remove)
 }
 
 
+/* ************************************* */
+/* *            Configuration          * */
+/* ************************************* */
+
+
+/* ======================= */
+/* = config_start        = */
+/* ======================= */
+
+static GcomprisProfile *profile_conf;
+static GcomprisBoard   *board_conf;
+
+static GHFunc save_table (gpointer key,
+		    gpointer value,
+		    gpointer user_data)
+{
+  gcompris_set_board_conf ( profile_conf,
+			    board_conf,
+			    (gchar *) key, 
+			    (gchar *) value);
+}
+
+static GcomprisConfCallback conf_ok(GHashTable *table)
+{
+  g_hash_table_foreach(table, (GHFunc) save_table, NULL);
+  
+  board_conf = NULL;
+  profile_conf = NULL;
+}
+
+static void
+reading_config_start(GcomprisBoard *agcomprisBoard,
+		    GcomprisProfile *aProfile)
+{
+  board_conf = agcomprisBoard;
+  profile_conf = aProfile;
+
+  gcompris_configuration_window( g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
+						 agcomprisBoard->name, 
+						 aProfile->name), 
+				 (GcomprisConfCallback )conf_ok);
+
+  /* init the combo to previously saved value */
+  GHashTable *config = gcompris_get_conf( profile_conf, board_conf);
+
+  gchar *locale = g_hash_table_lookup( config, "locale");
+  
+  gcompris_combo_locales( locale);
+
+}
+
+  
+/* ======================= */
+/* = config_stop        = */
+/* ======================= */
+static void 
+reading_config_stop()
+{
+}
+
+
 
 /* Local Variables: */
 /* mode:c */
