@@ -31,7 +31,7 @@ static gint	 animate_id = 0;
 static int	 leavenow;
 
 static void	 start_board (GcomprisBoard *agcomprisBoard);
-static gint	 key_press(guint keyval);
+static gint	 key_press(guint keyval, gchar *commit_str, gchar *preedit_str);
 static void	 pause_board (gboolean pause);
 static void	 end_board (void);
 static gboolean	 is_our_board (GcomprisBoard *gcomprisBoard);
@@ -134,8 +134,8 @@ static BoardPlugin menu_bp =
   {
     NULL,
     NULL,
-    N_("Reverse count"),
-    N_("Practice substraction with a funny game"),
+    "Reverse count",
+    "Practice substraction with a funny game",
     "Bruno Coudoin <bruno.coudoin@free.fr>",
     NULL,
     NULL,
@@ -149,6 +149,8 @@ static BoardPlugin menu_bp =
     process_ok,
     set_level,
     NULL,
+    NULL,
+    NULL,
     NULL
   };
 
@@ -158,11 +160,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(reversecount)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -192,6 +190,10 @@ static void start_board (GcomprisBoard *agcomprisBoard)
   if(agcomprisBoard!=NULL)
     {
       gcomprisBoard=agcomprisBoard;
+
+      /* disable im_context */
+      gcomprisBoard->disable_im_context = TRUE;
+
       gcomprisBoard->level=1;
       gcomprisBoard->maxlevel=7;
       gcomprisBoard->sublevel=1;
@@ -246,7 +248,7 @@ gboolean is_our_board (GcomprisBoard *gcomprisBoard)
 }
 
 /* ======================================= */
-gint key_press(guint keyval)
+gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
 {
 
   if(!gcomprisBoard)
