@@ -1,6 +1,6 @@
 /* gcompris - shapegame.c
  *
- * Time-stamp: <2005/03/30 22:06:15 bruno>
+ * Time-stamp: <2005/11/12 18:56:26 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -134,6 +134,7 @@ static GnomeCanvasItem	*shape_list_root_item;
 /* The tooltip */
 static GnomeCanvasGroup	*tooltip_root_item;
 static GnomeCanvasItem	*tooltip_text_item;
+static GnomeCanvasItem	*tooltip_text_item_s;
 static GnomeCanvasItem	*tooltip_bg_item;
 
 static void		 start_board (GcomprisBoard *agcomprisBoard);
@@ -142,7 +143,10 @@ static void 		 end_board (void);
 static gboolean 	 is_our_board (GcomprisBoard *gcomprisBoard);
 static void 		 set_level (guint level);
 static void 		 process_ok(void);
-static gint		 key_press(guint keyval);
+static gint		 key_press(guint keyval, gchar *commit_str, gchar *preedit_str);
+static void	         config_start (GcomprisBoard *agcomprisBoard,
+					   GcomprisProfile *aProfile);
+static void	         config_stop (void);
 
 static void              shapegame_init_canvas(GnomeCanvasGroup *parent);
 static void 		 shapegame_destroy_all_items(void);
@@ -166,8 +170,8 @@ static BoardPlugin menu_bp =
 {
    NULL,
    NULL,
-   N_("Make the puzzle"),
-   N_("Drag and Drop the items to rebuild the object"),
+   "Make the puzzle",
+   "Drag and Drop the items to rebuild the object",
    "Bruno Coudoin <bruno.coudoin@free.fr>",
    NULL,
    NULL,
@@ -181,7 +185,9 @@ static BoardPlugin menu_bp =
    process_ok,
    set_level,
    NULL,
-   NULL
+   NULL,
+   config_start,
+   config_stop
 };
 
 /*
@@ -190,11 +196,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin 
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(shapegame)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -222,10 +224,21 @@ static void start_board (GcomprisBoard *agcomprisBoard)
   gchar *filename = NULL;
   gboolean default_background = TRUE;
 
+  if (strcmp(agcomprisBoard->name, "imagename")==0){
+    GHashTable *config = gcompris_get_board_conf();
+    
+    gcompris_change_locale(g_hash_table_lookup( config, "locale"));
+
+    g_hash_table_destroy(config);
+  }
+
   if(agcomprisBoard!=NULL)
     {
       gcomprisBoard=agcomprisBoard;
 
+      /* disable im_context */
+      gcomprisBoard->disable_im_context = TRUE;
+
       /* set initial values for this level */
       gcomprisBoard->level = 1;
 
@@ -294,6 +307,11 @@ end_board ()
       shapegame_destroy_all_items();
       gcomprisBoard->level = 1;       // Restart this game to zero
     }
+
+  if (strcmp(gcomprisBoard->name, "imagename")==0){
+    gcompris_reset_locale();
+  }
+
   gcomprisBoard = NULL;
   gcompris_set_cursor(GCOMPRIS_DEFAULT_CURSOR);
 }
@@ -317,9 +335,39 @@ is_our_board (GcomprisBoard *gcomprisBoard)
     {
       if(g_strcasecmp(gcomprisBoard->type, "shapegame")==0)
 	{
+	  BoardPlugin *bp_board = g_malloc0(sizeof(BoardPlugin));
+	
+	  bp_board->handle        = menu_bp.handle;
+	  bp_board->filename      = menu_bp.filename;
+	  bp_board->name          = menu_bp.name;
+	  bp_board->description   = menu_bp.description;
+	  bp_board->author        = menu_bp.author;
+	  bp_board->init          = menu_bp.init;
+	  bp_board->cleanup       = menu_bp.cleanup;
+	  bp_board->about         = menu_bp.about;
+	  bp_board->configure     = menu_bp.configure;
+	  bp_board->start_board   = menu_bp.start_board;
+	  bp_board->pause_board   = menu_bp.pause_board;
+	  bp_board->end_board     = menu_bp.end_board;
+	  bp_board->is_our_board  = menu_bp.is_our_board;
+	  bp_board->key_press     = menu_bp.key_press;
+	  bp_board->ok            = menu_bp.ok;
+	  bp_board->set_level     = menu_bp.set_level;
+	  bp_board->config        = menu_bp.config;
+	  bp_board->repeat        = menu_bp.repeat;
+	  
+	  if (strcmp(gcomprisBoard->name, "imagename")==0){
+	    bp_board->config_start  = menu_bp.config_start;
+	    bp_board->config_stop   = menu_bp.config_stop;
+	  } else {
+	    bp_board->config_start  = NULL;
+	    bp_board->config_stop   = NULL;
+	  }
+	  
+	  
 	  /* Set the plugin entry */
-	  gcomprisBoard->plugin=&menu_bp;
-
+	  gcomprisBoard->plugin = bp_board;
+	
 	  return TRUE;
 	}
     }
@@ -329,7 +377,7 @@ is_our_board (GcomprisBoard *gcomprisBoard)
 /*
  * Keypress here are use for entering the editing mode
  */
-static gint key_press(guint keyval)
+static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
 {
   guint c;
   gboolean stop = FALSE;
@@ -361,46 +409,6 @@ static gint key_press(guint keyval)
     case GDK_Return:
       process_ok();
       return TRUE;
-    case GDK_KP_0:
-    case GDK_KP_Insert:
-      keyval=GDK_0;
-      break;
-    case GDK_KP_1:
-    case GDK_KP_End:
-      keyval=GDK_1;
-      break;
-    case GDK_KP_2:
-    case GDK_KP_Down:
-      keyval=GDK_2;
-      break;
-    case GDK_KP_3:
-    case GDK_KP_Page_Down:
-      keyval=GDK_3;
-      break;
-    case GDK_KP_4:
-    case GDK_KP_Left:
-      keyval=GDK_4;
-      break;
-    case GDK_KP_5:
-    case GDK_KP_Begin:
-      keyval=GDK_5;
-      break;
-    case GDK_KP_6:
-    case GDK_KP_Right:
-      keyval=GDK_6;
-      break;
-    case GDK_KP_7:
-    case GDK_KP_Home:
-      keyval=GDK_7;
-      break;
-    case GDK_KP_8:
-    case GDK_KP_Up:
-      keyval=GDK_8;
-      break;
-    case GDK_KP_9:
-    case GDK_KP_Page_Up:
-      keyval=GDK_9;
-      break;
     case GDK_Right:
     case GDK_Delete:
     case GDK_BackSpace:
@@ -414,7 +422,7 @@ static gint key_press(guint keyval)
     {
     case 'e':
       /* Enter Edit Mode */
-      gcompris_dialog(_("You entered the Edit mode\nMove the puzzle items and\ntype 's' to save, and\n'd' to display all the shapes"), NULL);
+      gcompris_dialog(_("You have entered Edit mode\nMove the puzzle items;\ntype 's' to save, and\n'd' to display all the shapes"), NULL);
       edit_mode = TRUE;
       break;
     case 's':
@@ -422,7 +430,7 @@ static gint key_press(guint keyval)
       if(edit_mode)
 	{
 	  write_xml_file("/tmp/gcompris-board.xml");
-	  gcompris_dialog(_("This board data are saved under\n/tmp/gcompris-board.xml"), NULL);
+	  gcompris_dialog(_("The data from this activity are saved under\n/tmp/gcompris-board.xml"), NULL);
 	}
       break;
     case 'd':
@@ -674,6 +682,17 @@ static void shapegame_init_canvas(GnomeCanvasGroup *parent)
 			   NULL);
   gdk_pixbuf_unref(pixmap);
 
+  tooltip_text_item_s = \
+    gnome_canvas_item_new (GNOME_CANVAS_GROUP(tooltip_root_item),
+			   gnome_canvas_text_get_type (),
+			   "text", "",
+			   "font", gcompris_skin_font_board_small,
+			   "x", (double)gdk_pixbuf_get_width(pixmap)/2 + 1.0,
+			   "y", 24.0 + 1.0,
+			   "anchor", GTK_ANCHOR_CENTER,
+			   "justification", GTK_JUSTIFY_CENTER,
+			   "fill_color_rgba", gcompris_skin_color_shadow,
+			   NULL);
   tooltip_text_item = \
     gnome_canvas_item_new (GNOME_CANVAS_GROUP(tooltip_root_item),
 			   gnome_canvas_text_get_type (),
@@ -989,6 +1008,9 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, Shape *shape)
 	 gnome_canvas_item_set(GNOME_CANVAS_ITEM(tooltip_bg_item),
 			       "y", 0.0,
 			       NULL);
+	 gnome_canvas_item_set(GNOME_CANVAS_ITEM(tooltip_text_item_s),
+			       "text", shape->tooltip,
+			       NULL);
 	 gnome_canvas_item_set(GNOME_CANVAS_ITEM(tooltip_text_item),
 			       "text", shape->tooltip,
 			       NULL);
@@ -1526,11 +1548,11 @@ static void create_title(char *name, double x, double y, GtkJustification justif
 			   gnome_canvas_text_get_type (),
 			   "text", name,
 			   "font", gcompris_skin_font_board_medium,
-			   "x", x + 1,
-			   "y", y + 1,
+			   "x", x + 1.0,
+			   "y", y + 1.0,
 			   "anchor", GTK_ANCHOR_CENTER,
 			   "justification", justification,
-			   "fill_color", "black",
+			   "fill_color_rgba", gcompris_skin_color_shadow,
 			   NULL);
 
   gnome_canvas_item_raise_to_top(item);
@@ -1670,7 +1692,7 @@ add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
 
       for(i=0; i<j; i++)
 	{
-	  points->coords[i] = atof(d[i]);
+	  points->coords[i] = g_ascii_strtod(d[i], NULL);
 	}
       g_strfreev(d);
     }
@@ -1678,12 +1700,12 @@ add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
   /* get the X coord of the shape */
   cx = xmlGetProp(xmlnode,"x");
   if(!cx) cx = "100";
-  x = atof(cx);
+  x = g_ascii_strtod(cx, NULL);
 
   /* get the Y coord of the shape */
   cy = xmlGetProp(xmlnode,"y");
   if(!cy) cy = "100";
-  y = atof(cy);
+  y = g_ascii_strtod(cy, NULL);
 
   /* Back up the current locale to be sure to load well C formated numbers */
   locale = g_strdup(gcompris_get_locale());
@@ -1692,12 +1714,12 @@ add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
   /* get the ZOOMX coord of the shape */
   czoomx = xmlGetProp(xmlnode,"zoomx");
   if(!czoomx) czoomx = "1";
-  zoomx = atof(czoomx);
+  zoomx = g_ascii_strtod(czoomx, NULL);
 
   /* get the ZOOMY coord of the shape */
   czoomy = xmlGetProp(xmlnode,"zoomy");
   if(!czoomy) czoomy = "1";
-  zoomy = atof(czoomy);
+  zoomy = g_ascii_strtod(czoomy, NULL);
 
   /* get the POSITION of the shape */
   /* Position in the xml means:
@@ -1877,10 +1899,10 @@ read_xml_file(char *fname)
   /* if the file doesn't exist */
   if(!g_file_test(fname, G_FILE_TEST_EXISTS)) 
     {
-      g_warning(_("Couldn't find file %s !"), fname);
+      g_warning("Couldn't find file %s !", fname);
       return FALSE;
     }
-  g_warning(_("find file %s !"), fname);
+  g_warning("found file %s !", fname);
 
   /* parse the new file and put the result into newdoc */
   doc = xmlParseFile(fname);
@@ -1915,7 +1937,7 @@ read_xml_file(char *fname)
   if(!tmpstr) 
       shapeBox.x = 15;
   else
-      shapeBox.x = atof(tmpstr);
+    shapeBox.x = g_ascii_strtod(tmpstr, NULL);
   g_warning("shapeBox.x=%f\n", shapeBox.x);
 
   tmpstr = xmlGetProp(doc->children,"shapebox_y");
@@ -1923,7 +1945,7 @@ read_xml_file(char *fname)
   if(!tmpstr) 
       shapeBox.y = 25;
   else
-      shapeBox.y = atof(tmpstr);
+    shapeBox.y = g_ascii_strtod(tmpstr, NULL);
   g_warning("shapeBox.y=%f\n", shapeBox.y);
 
   tmpstr = xmlGetProp(doc->children,"shapebox_w");
@@ -1931,7 +1953,7 @@ read_xml_file(char *fname)
   if(!tmpstr) 
       shapeBox.w = 80;
   else
-      shapeBox.w = atof(tmpstr);
+    shapeBox.w = g_ascii_strtod(tmpstr, NULL);
   g_warning("shapeBox.w=%f\n", shapeBox.w);
 
   tmpstr = xmlGetProp(doc->children,"shapebox_h");
@@ -1939,7 +1961,7 @@ read_xml_file(char *fname)
   if(!tmpstr) 
       shapeBox.h = 430;
   else
-      shapeBox.h = atof(tmpstr);
+    shapeBox.h = g_ascii_strtod(tmpstr, NULL);
   g_warning("shapeBox.h=%f\n", shapeBox.h);
 
   tmpstr = xmlGetProp(doc->children,"shapebox_nb_shape_x");
@@ -2045,6 +2067,69 @@ write_xml_file(char *fname)
 }
 
 
+
+/* ************************************* */
+/* *            Configuration          * */
+/* ************************************* */
+
+
+/* ======================= */
+/* = config_start        = */
+/* ======================= */
+
+static GcomprisProfile *profile_conf;
+static GcomprisBoard   *board_conf;
+
+static GHFunc save_table (gpointer key,
+		    gpointer value,
+		    gpointer user_data)
+{
+  gcompris_set_board_conf ( profile_conf,
+			    board_conf,
+			    (gchar *) key, 
+			    (gchar *) value);
+}
+
+static GcomprisConfCallback conf_ok(GHashTable *table)
+{
+  g_hash_table_foreach(table, (GHFunc) save_table, NULL);
+  
+  board_conf = NULL;
+  profile_conf = NULL;
+}
+
+static void
+config_start(GcomprisBoard *agcomprisBoard,
+		    GcomprisProfile *aProfile)
+{
+  board_conf = agcomprisBoard;
+  profile_conf = aProfile;
+
+  gcompris_configuration_window( g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
+						 agcomprisBoard->name, 
+						 aProfile->name), 
+				 (GcomprisConfCallback )conf_ok);
+
+  /* init the combo to previously saved value */
+  GHashTable *config = gcompris_get_conf( profile_conf, board_conf);
+
+  gchar *locale = g_hash_table_lookup( config, "locale");
+  
+  gcompris_combo_locales( locale);
+
+}
+
+  
+/* ======================= */
+/* = config_stop        = */
+/* ======================= */
+static void 
+config_stop()
+{
+}
+
+
+
 
 /* Local Variables: */
 /* mode:c */
