@@ -1,6 +1,6 @@
 /* gcompris - smallnumbers.c
  *
- * Time-stamp: <2005/04/19 23:47:07 bruno>
+ * Time-stamp: <2005/10/12 22:45:09 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  * 
@@ -39,7 +39,7 @@ static void pause_board (gboolean pause);
 static void end_board (void);
 static gboolean is_our_board (GcomprisBoard *gcomprisBoard);
 static void set_level (guint level);
-static gint key_press(guint keyval);
+static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str);
 
 static void smallnumbers_create_item(GnomeCanvasGroup *parent);
 static gint smallnumbers_drop_items (GtkWidget *widget, gpointer data);
@@ -48,6 +48,10 @@ static void smallnumbers_destroy_all_items(void);
 static void smallnumbers_next_level(void);
 static void smallnumbers_gotkey_item(GnomeCanvasItem *item, guint key);
 
+static void		 smallnumber_config_start(GcomprisBoard *agcomprisBoard,
+					     GcomprisProfile *aProfile);
+static void		 smallnumber_config_stop(void);
+
 static void player_win(GnomeCanvasItem *item);
 static void player_loose(void);
 
@@ -55,13 +59,17 @@ static  guint32              fallSpeed = 0;
 static  double               speed = 0.0;
 static  double               imageZoom = 0.0;
 
+/* if board has alternate locale */
+static gchar *locale_sound = NULL;
+static gboolean with_sound = FALSE;
+
 /* Description of this plugin */
 static BoardPlugin menu_bp =
 {
    NULL,
    NULL,
-   N_("Numbers With Dices"),
-   N_("Type the keyboard number 1 to 9 before the dice reaches the ground"),
+   "Numbers With Dice",
+   "Type the keyboard number 1 to 9 before the dice reaches the ground",
    "Bruno Coudoin <bruno.coudoin@free.fr>",
    NULL,
    NULL,
@@ -75,7 +83,9 @@ static BoardPlugin menu_bp =
    NULL,
    set_level,
    NULL,
-   NULL
+   NULL,
+   smallnumber_config_start,
+   smallnumber_config_stop
 };
 
 /*
@@ -84,11 +94,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin 
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(smallnumbers)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = UNPAUSE
@@ -132,11 +138,24 @@ static void pause_board (gboolean pause)
  */
 static void start_board (GcomprisBoard *agcomprisBoard)
 {
+  GHashTable *config = gcompris_get_board_conf();
+
+  locale_sound = g_hash_table_lookup( config, "locale_sound");
+
+  gchar *control_sound = g_hash_table_lookup( config, "with_sound");
+
+  if (control_sound && strcmp(g_hash_table_lookup( config, "with_sound"),"True")==0)
+    with_sound = TRUE;
+  else
+    with_sound = FALSE;
 
   if(agcomprisBoard!=NULL)
     {
       gcomprisBoard=agcomprisBoard;
 
+      /* disable im_context */
+      gcomprisBoard->disable_im_context = TRUE;
+
       gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "images/scenery3_background.png");
 
       gcomprisBoard->level = 1;
@@ -187,7 +206,7 @@ set_level (guint level)
     }
 }
 
-static gint key_press(guint keyval)
+static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
 {
   gchar *old_value;
   gchar *old_name;
@@ -217,53 +236,14 @@ static gint key_press(guint keyval)
     case GDK_dead_circumflex:
     case GDK_Num_Lock:
       return FALSE; 
-    case GDK_KP_0:
-    case GDK_KP_Insert:
-      keyval=GDK_0;
-      break;
-    case GDK_KP_1:
-    case GDK_KP_End:
-      keyval=GDK_1;
-      break;
-    case GDK_KP_2:
-    case GDK_KP_Down:
-      keyval=GDK_2;
-      break;
-    case GDK_KP_3:
-    case GDK_KP_Page_Down:
-      keyval=GDK_3;
-      break;
-    case GDK_KP_4:
-    case GDK_KP_Left:
-      keyval=GDK_4;
-      break;
-    case GDK_KP_5:
-    case GDK_KP_Begin:
-      keyval=GDK_5;
-      break;
-    case GDK_KP_6:
-    case GDK_KP_Right:
-      keyval=GDK_6;
-      break;
-    case GDK_KP_7:
-    case GDK_KP_Home:
-      keyval=GDK_7;
-      break;
-    case GDK_KP_8:
-    case GDK_KP_Up:
-      keyval=GDK_8;
-      break;
-    case GDK_KP_9:
-    case GDK_KP_Page_Up:
-      keyval=GDK_9;
-      break;
     }
 
   sprintf(str, "%c", keyval);
 
   keyval = atoi(str);
 
-  g_list_foreach(GNOME_CANVAS_GROUP(boardRootItem)->item_list, (GFunc) smallnumbers_gotkey_item, (void *)keyval);
+  g_list_foreach(GNOME_CANVAS_GROUP(boardRootItem)->item_list, 
+		 (GFunc) smallnumbers_gotkey_item, (void *)keyval);
 
   return TRUE;
 }
@@ -411,7 +391,10 @@ static void smallnumbers_create_item(GnomeCanvasGroup *parent)
     lettersItem[1] = '\0';
 
     str1 = g_strdup_printf("%s%s", lettersItem, ".ogg");
-    str2 = gcompris_get_asset_file("gcompris alphabet", NULL, "audio/x-ogg", str1);
+    str2 = gcompris_get_asset_file_locale("gcompris alphabet", NULL, "audio/x-ogg", str1, locale_sound);
+
+    if (with_sound)
+      gcompris_play_ogg(str2, NULL);
 
     g_free(str1);
     g_free(str2);
@@ -491,6 +474,91 @@ static void player_loose()
 }
 
 
+/* ======================= */
+/* = config_start        = */
+/* ======================= */
+
+static GcomprisProfile *profile_conf;
+static GcomprisBoard   *board_conf;
+
+static GHFunc save_table (gpointer key,
+		    gpointer value,
+		    gpointer user_data)
+{
+  gcompris_set_board_conf ( profile_conf,
+			    board_conf,
+			    (gchar *) key, 
+			    (gchar *) value);
+}
+
+static GcomprisConfCallback conf_ok(GHashTable *table)
+{
+  g_hash_table_foreach(table, (GHFunc) save_table, NULL);
+  
+  board_conf = NULL;
+  profile_conf = NULL;
+}
+
+static gboolean check_text(gchar *key, gchar *text, GtkLabel *label){
+  gtk_label_set_markup(label, text);
+
+  return TRUE;
+}
+
+static void sound_control_box_toggled(GtkToggleButton *togglebutton,
+				      gpointer combo)
+{
+  gtk_widget_set_sensitive(GTK_WIDGET(combo), gtk_toggle_button_get_active (togglebutton));
+}
+
+
+static void
+smallnumber_config_start(GcomprisBoard *agcomprisBoard,
+		    GcomprisProfile *aProfile)
+{
+  board_conf = agcomprisBoard;
+  profile_conf = aProfile;
+
+  gchar *label;
+  
+  label = g_strdup_printf("<b>%s</b> configuration\n for profile <b>%s</b>",
+			  agcomprisBoard->name, aProfile->name);
+
+  gcompris_configuration_window(label, (GcomprisConfCallback )conf_ok);
+
+  g_free(label);
+
+  /* init the combo to previously saved value */
+  GHashTable *config = gcompris_get_conf( profile_conf, board_conf);
+
+  locale_sound = g_hash_table_lookup( config, "locale_sound");
+
+  gchar *control_sound = g_hash_table_lookup( config, "with_sound");
+  if (control_sound && strcmp(g_hash_table_lookup( config, "with_sound"),"True")==0)
+    with_sound = TRUE;
+  else
+    with_sound = FALSE;
+
+  GtkCheckButton  *sound_control = gcompris_boolean_box("Enable sounds", "with_sound", with_sound);
+  
+  GtkComboBox *sound_box = gcompris_combo_locales_asset( "Select sound locale", locale_sound, "gcompris colors", NULL, "audio/x-ogg", "purple.ogg");
+
+  gtk_widget_set_sensitive(GTK_WIDGET(sound_box), with_sound);
+
+  g_signal_connect(G_OBJECT(sound_control), "toggled", 
+		   G_CALLBACK(sound_control_box_toggled),
+		   sound_box);
+
+}  
+/* ======================= */
+/* = config_stop        = */
+/* ======================= */
+static void 
+smallnumber_config_stop()
+{
+}
+
+
 
 
 /* Local Variables: */
