@@ -65,7 +65,7 @@ static guint		user_points = 0;
  * Functions Definition
  */
 static void		process_ok(void);
-static gint		key_press(guint keyval);
+static gint		key_press(guint keyval, gchar *commit_str, gchar *preedit_str);
 static GnomeCanvasItem *target_create_item(GnomeCanvasGroup *parent);
 static void		target_destroy_all_items(void);
 static void		target_next_level(void);
@@ -119,8 +119,8 @@ static BoardPlugin menu_bp =
   {
     NULL,
     NULL,
-    N_("Practice addition with a target game"),
-    N_("Touch the target and count the points"),
+    "Practice addition with a target game",
+    "Hit the target and count your points",
     "Bruno Coudoin <bruno.coudoin@free.fr>",
     NULL,
     NULL,
@@ -134,6 +134,8 @@ static BoardPlugin menu_bp =
     process_ok,
     set_level,
     NULL,
+    NULL,
+    NULL,
     NULL
   };
 
@@ -143,11 +145,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(target)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -188,6 +186,10 @@ static void start_board (GcomprisBoard *agcomprisBoard)
   if(agcomprisBoard!=NULL)
     {
       gcomprisBoard=agcomprisBoard;
+
+      /* disable im_context */
+      gcomprisBoard->disable_im_context = TRUE;
+
       gcomprisBoard->level=1;
       gcomprisBoard->maxlevel=NUMBER_OF_TARGET;
       gcomprisBoard->sublevel=1;
@@ -226,7 +228,7 @@ static void set_level (guint level)
 
 
 /* ======================================= */
-static gint key_press(guint keyval)
+static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
 {
   guint c;
 
@@ -257,46 +259,6 @@ static gint key_press(guint keyval)
     case GDK_Return:
       process_ok();
       return TRUE;
-    case GDK_KP_0:
-    case GDK_KP_Insert:
-      keyval=GDK_0;
-      break;
-    case GDK_KP_1:
-    case GDK_KP_End:
-      keyval=GDK_1;
-      break;
-    case GDK_KP_2:
-    case GDK_KP_Down:
-      keyval=GDK_2;
-      break;
-    case GDK_KP_3:
-    case GDK_KP_Page_Down:
-      keyval=GDK_3;
-      break;
-    case GDK_KP_4:
-    case GDK_KP_Left:
-      keyval=GDK_4;
-      break;
-    case GDK_KP_5:
-    case GDK_KP_Begin:
-      keyval=GDK_5;
-      break;
-    case GDK_KP_6:
-    case GDK_KP_Right:
-      keyval=GDK_6;
-      break;
-    case GDK_KP_7:
-    case GDK_KP_Home:
-      keyval=GDK_7;
-      break;
-    case GDK_KP_8:
-    case GDK_KP_Up:
-      keyval=GDK_8;
-      break;
-    case GDK_KP_9:
-    case GDK_KP_Page_Up:
-      keyval=GDK_9;
-      break;
     case GDK_Right:
     case GDK_Left:
       break;
