@@ -20,6 +20,7 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include <string.h>
 #include <ctype.h>
 #include <math.h>
 #include <assert.h>
@@ -85,18 +86,15 @@ gboolean	 load_level(guint level, guint card);
 
 static jam	 current_card  ={0,0,0,NULL};
 
-static void	 draw_border(GnomeCanvasGroup *rootBorder);
 static void	 draw_grid  (GnomeCanvasGroup *rootBorder);
 static gint	 cars_from_strv(char *strv);
-static void	 load_error(void);
-static void	 load_not_found(void);
 
 /* Description of this plugin */
 static BoardPlugin menu_bp =
   {
     NULL,
     NULL,
-    N_("A sliding block puzzle game"),
+    "A sliding block puzzle game",
     "",
     "Bruno Coudoin <bruno.coudoin@free.fr>",
     NULL,
@@ -111,7 +109,9 @@ static BoardPlugin menu_bp =
     NULL,
     set_level,
     NULL,
-    repeat
+    repeat,
+    NULL,
+    NULL
   };
 
 /*
@@ -120,11 +120,7 @@ static BoardPlugin menu_bp =
  *
  */
 
-BoardPlugin
-*get_bplugin_info(void)
-{
-  return &menu_bp;
-}
+GET_BPLUGIN_INFO(traffic)
 
 /*
  * in : boolean TRUE = PAUSE : FALSE = CONTINUE
@@ -174,7 +170,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       }
 
       gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
-			      "traffic/traffic-bg.jpg");
+			      gcompris_image_to_skin("traffic-bg.jpg"));
 
       traffic_next_level();
 
@@ -270,7 +266,6 @@ static void traffic_destroy_all_items()
 /* ==================================== */
 static GnomeCanvasItem *traffic_create_item(GnomeCanvasGroup *parent)
 {
-  int i,j;
   GnomeCanvasGroup *borderItem = NULL;
 
   boardRootItem = GNOME_CANVAS_GROUP(
@@ -285,7 +280,6 @@ static GnomeCanvasItem *traffic_create_item(GnomeCanvasGroup *parent)
 							 "x", (double) OFSET_X,
 							 "y", (double) OFSET_Y,
 							 NULL));
-  //  draw_border(borderItem);
   draw_grid(borderItem);
 
   allcars= GNOME_CANVAS_GROUP(
@@ -384,38 +378,6 @@ void draw_car(car *thiscar)
   gtk_object_set_data(GTK_OBJECT(car_rect),"whatami",(gpointer)"car_rect");
 }
 
-static void draw_border(GnomeCanvasGroup *rootBorder)
-{
-  GnomeCanvasItem *border;
-  GnomeCanvasPoints *points;
-  double mypoints[]={
-    0,0,
-    261,0,
-    261,90,
-    251,90,
-    251,9,
-    9,9,
-    9,251,
-    251,251,
-    251,130,
-    261,130,
-    261,261,
-    0,261,
-    0,0
-  };
-
-  points=gnome_canvas_points_new(13);
-  memcpy(points->coords,mypoints,sizeof(mypoints));
-
-  border=gnome_canvas_item_new(rootBorder,
-			       gnome_canvas_polygon_get_type(),
-			       "points", points,
-			       "fill_color", "black",
-			       "outline_color", NULL,
-			       "width_units", 0.0,
-			       NULL);
-}
-
 void draw_jam(jam *myjam)
 {
   int whichcar;
@@ -647,7 +609,6 @@ gint cars_from_strv(char *strv)
 {
   car *ccar;
   char x,y,id;
-  int col, row;
   int number_of_cars = 0;
   gboolean more_car = TRUE;
 
@@ -724,13 +685,3 @@ gint cars_from_strv(char *strv)
   return number_of_cars;
 }
 
-void load_error(void)
-{
-  board_finished(BOARD_FINISHED_RANDOM);
-}
-
-void load_not_found(void)
-{
-  board_finished(BOARD_FINISHED_RANDOM);
-}
-
