@@ -17,6 +17,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include "glib.h"
 #include "assetml.h"
 #include <config.h>
 
@@ -25,7 +26,6 @@
 #include <libxml/parser.h>
 
 #include <locale.h>
-#include <dirent.h>
 #include <string.h>
 
 #define FILE_EXT ".assetml"
@@ -33,7 +33,7 @@
 const gchar	*assetml_get_locale(void);
 static gchar	*reactivate_newline(gchar *str);
 static void	 dump_asset(AssetML *assetml);
-int		 selectAssetML(const struct dirent *d);
+int		 selectAssetML(const gchar *dirent);
 void		 assetml_read_xml_file(GList **gl_result, char *fname,
 				       gchar *dataset, gchar* categories, gchar* mimetype, 
 				       const gchar *locale, gchar* file);
@@ -42,6 +42,8 @@ void		 assetml_load_xml(GList **gl_result, gchar *dataset, gchar* categories,
 				  const gchar* locale, gchar* file);
 void		 free_asset(AssetML *assetml);
 
+GHashTable *asset_cache = NULL;
+
 /*
  * This returns the locale for which text must be displayed
  *
@@ -87,19 +89,27 @@ static gchar *reactivate_newline(gchar *str)
 void dump_asset(AssetML *assetml)
 {
 
-  printf("Dump Asset\n");
+  g_message("Dump Asset\n");
 
   if(assetml==NULL)
     return;
 
-  printf("  dataset     = %s\n",assetml->dataset);
-  printf("  file        = %s\n",assetml->file);
-  printf("  name        = %s\n",assetml->name);
-  printf("  locale      = %s\n",assetml->locale);
-  printf("  description = %s\n",assetml->description);
-  printf("  categories  = %s\n",assetml->categories);
-  printf("  mimetype    = %s\n",assetml->mimetype);
-  printf("  credits     = %s\n",assetml->credits);
+  if(assetml->dataset)
+    g_message("  dataset     = %s\n",assetml->dataset);
+  if(assetml->file)
+    g_message("  file        = %s\n",assetml->file);
+  if(assetml->name)
+    g_message("  name        = %s\n",assetml->name);
+  if(assetml->locale)
+    g_message("  locale      = %s\n",assetml->locale);
+  if(assetml->description)
+    g_message("  description = %s\n",assetml->description);
+  if(assetml->categories)
+    g_message("  categories  = %s\n",assetml->categories);
+  if(assetml->mimetype)
+    g_message("  mimetype    = %s\n",assetml->mimetype);
+  if(assetml->credits)
+    g_message("  credits     = %s\n",assetml->credits);
 
 }
 
@@ -205,7 +215,11 @@ static gboolean matching(AssetML *assetml, gchar *mydataset,
 {
   g_assert(assetml);
 
-  assetml->dataset = g_strdup(mydataset);
+  if (!assetml->locale)
+    assetml->locale = g_strdup(mylocale);
+  if (!assetml->dataset)
+    assetml->dataset = g_strdup(mydataset);
+
   if(assetml->dataset && dataset)
     if(g_ascii_strcasecmp(assetml->dataset, dataset))
       return FALSE;
@@ -217,7 +231,9 @@ static gboolean matching(AssetML *assetml, gchar *mydataset,
    * pt     pt_BR       OK
    * pt_BR  pt          NO
    */
-  assetml->locale = g_strdup(mylocale);
+  if (!assetml->locale)
+    assetml->locale = g_strdup(mylocale);
+
   if(assetml->locale && locale)
     if(g_ascii_strncasecmp(assetml->locale, locale, strlen(assetml->locale)))
       return FALSE;
@@ -268,8 +284,21 @@ static gboolean matching(AssetML *assetml, gchar *mydataset,
 static void
 parse_doc(GList **gl_result, xmlDocPtr doc, 
 	  gchar *mydataset, gchar *rootdir, gchar* mylocale,
-	  gchar *dataset, gchar* categories, gchar* mimetype, const gchar* locale, gchar* file)
+	  gchar *dataset, gchar* categories, gchar* mimetype, const gchar* locale, gchar* file, GList **cache)
 {
+  if (*cache){
+    GList *list;
+
+    for (list= *cache; list != NULL; list=list->next){
+      AssetML *assetml = (AssetML *) list->data;
+      
+      if (matching(assetml, mydataset, dataset, categories, 
+		   mimetype, mylocale, locale, file))
+	*gl_result = g_list_append (*gl_result, assetml);
+    }
+    return;
+  }
+
   xmlNodePtr node;
 
   /* find <Asset> nodes and add them to the list, this just
@@ -279,13 +308,24 @@ parse_doc(GList **gl_result, xmlDocPtr doc,
        we pass NULL as the node of the child */
     AssetML *assetml = assetml_add_xml_to_data(doc, node, rootdir, NULL);
 
-    if(assetml && matching(assetml, mydataset, dataset, categories, mimetype, mylocale, locale, file))
+    if(assetml && matching(assetml, mydataset, dataset, categories, 
+			   mimetype, mylocale, locale, file)) {
+      g_message("if(assetml && matching  g_list_append)\n");
+
       *gl_result = g_list_append (*gl_result, assetml);
-				
+    }
+
+    if (assetml)
+      *cache = g_list_append( *cache,  assetml);
+
   }
 }
 
-
+void assetml_real_free_assetlist(GList *assetlist)
+{
+  g_list_foreach (assetlist, (GFunc) free_asset, NULL);
+  g_list_free(assetlist);
+}
 
 /* read an xml file into our memory structures and update our view,
    dump any old data we have in memory if we can load a new set
@@ -300,55 +340,80 @@ void assetml_read_xml_file(GList **gl_result, char *assetmlfile,
   gchar *mylocale;
   gchar *mydataset;
 
+  GList *cache = NULL;
+
   g_return_if_fail(assetmlfile!=NULL);
 
-  /* parse the new file and put the result into newdoc */
-  doc = xmlParseFile(assetmlfile);
-
-  /* in case something went wrong */
-  if(!doc) {
-    g_warning("Oups, the parsing of %s failed", assetmlfile);
-    return;
+  /* cache asset for performance in non direct search */
+  if (!asset_cache){
+    asset_cache = g_hash_table_new_full( g_str_hash,
+					 g_str_equal,
+					 g_free,
+					 (GDestroyNotify) assetml_free_assetlist
+					 );
   }
-  
-  if(/* if there is no root element */
-     !doc->children ||
-     /* if it doesn't have a name */
-     !doc->children->name ||
-     /* if it isn't a Assetml node */
-     g_strcasecmp(doc->children->name,"AssetML")!=0) 
-    {
-      xmlFreeDoc(doc);
-      g_warning("Oups, the file %s is not of the assetml type", assetmlfile);
+
+  cache = g_hash_table_lookup (asset_cache, assetmlfile);
+
+  /* parse the new file and put the result into newdoc */
+  if (! cache){
+    doc = xmlParseFile(assetmlfile);
+
+    /* in case something went wrong */
+    if(!doc) {
+      g_warning("Oups, the parsing of %s failed", assetmlfile);
       return;
     }
+  
+    if(/* if there is no root element */
+       !doc->children ||
+       /* if it doesn't have a name */
+       !doc->children->name ||
+       /* if it isn't a Assetml node */
+       g_strcasecmp(doc->children->name,"AssetML")!=0) 
+      {
+	xmlFreeDoc(doc);
+	g_warning("Oups, the file %s is not of the assetml type", assetmlfile);
+	return;
+      }
 
-  rootdir   = xmlGetProp(doc->children,"rootdir");
-  mydataset = xmlGetProp(doc->children,"dataset");
-  mylocale    = xmlGetProp(doc->children,"locale");
+    rootdir   = xmlGetProp(doc->children,"rootdir");
+    mydataset = xmlGetProp(doc->children,"dataset");
+    mylocale  = xmlGetProp(doc->children,"locale");
+  }
+  else {
+    AssetML *myasset = (AssetML *) cache->data;
+
+    mylocale = myasset->locale;
+    mydataset = myasset->dataset;
+    rootdir = NULL;
+  }
 
   /* parse our document and replace old data */
-  parse_doc(gl_result, doc, mydataset, rootdir, mylocale, dataset, categories, mimetype, locale, file);
+  parse_doc(gl_result, doc, mydataset, rootdir, mylocale, dataset, categories, mimetype, locale, file, &cache);
 
-  xmlFree(rootdir);
-  xmlFree(mydataset);
+  if (rootdir)
+    g_hash_table_replace( asset_cache, g_strdup(assetmlfile), cache);
 
-  xmlFreeDoc(doc);
+  if (rootdir){
+    xmlFree(rootdir);
+    xmlFree(mydataset);
+    xmlFreeDoc(doc);
+  }
 }
 
 
 /*
  * Select only files with FILE_EXT
  */
-int selectAssetML(const struct dirent *d)
+int selectAssetML(const gchar *dirent)
 {
-  gchar *file = ((struct dirent *)d)->d_name;
   guint ext_length = strlen(FILE_EXT);
 
-  if(strlen(file)<ext_length)
+  if(strlen(dirent)<ext_length)
     return 0;
 
-  return (strncmp (&file[strlen(file)-ext_length], FILE_EXT, ext_length) == 0);
+  return (strncmp (&dirent[strlen(dirent)-ext_length], FILE_EXT, ext_length) == 0);
 }
 
 /* load all the xml files in the assetml path
@@ -357,20 +422,21 @@ int selectAssetML(const struct dirent *d)
 void assetml_load_xml(GList **gl_result, gchar *dataset, gchar* categories, gchar* mimetype, const gchar *locale, 
 		      gchar* name)
 {
-  struct dirent *one_dirent;
-  int n;
-  DIR *dir;
+  const gchar  *one_dirent;
+  GDir    *dir;
 
-  dir = opendir(ASSETML_DIR);
+  dir = g_dir_open(ASSETML_DIR, 0, NULL);
   if(!dir) {
     g_warning("opendir returns no files with extension %s in directory %s", FILE_EXT, ASSETML_DIR);
     return;
+  } else {
+    g_message("assetml_load_xml directory parsing=%s\n", ASSETML_DIR);
   }
 
-  while((one_dirent = readdir(dir)) != NULL) {
+  while((one_dirent = g_dir_read_name(dir)) != NULL) {
 
-    if(strstr(one_dirent->d_name, FILE_EXT)) {
-      gchar *assetmlfile = g_strdup_printf("%s/%s", ASSETML_DIR, one_dirent->d_name);
+    if(strstr(one_dirent, FILE_EXT)) {
+      gchar *assetmlfile = g_strdup_printf("%s/%s", ASSETML_DIR, one_dirent);
       
       assetml_read_xml_file(gl_result, assetmlfile,
 			    dataset, categories, mimetype, locale, name);
@@ -378,7 +444,7 @@ void assetml_load_xml(GList **gl_result, gchar *dataset, gchar* categories, gcha
       g_free(assetmlfile);
     }
   }
-  closedir(dir);
+  g_dir_close(dir);
 }
 
 
@@ -400,29 +466,28 @@ void free_asset(AssetML *assetml)
 
 void assetml_free_assetlist(GList *assetlist)
 {
-  g_list_foreach (assetlist, (GFunc) free_asset, NULL);
+  /* does not  free assets because cache */
+  //g_list_foreach (assetlist, (GFunc) free_asset, NULL);
   g_list_free(assetlist);
-
-
 }
 
 GList*	 assetml_get_asset(gchar *dataset, gchar* categories, gchar* mimetype, const gchar *locale, gchar* file)
 {
   GList *gl_result = NULL;
 
+  g_message("assetml_get_asset file=%s\n", file);
+
   assetml_load_xml(&gl_result, dataset, categories, mimetype, locale, file);
 
-  if(g_list_length(gl_result)==0)
+  if(gl_result && g_list_length(gl_result)==0)
     {
       g_list_free(gl_result);
       return NULL;
     }
   else
     {
-#ifdef DEBUG
-      printf("Dumping return value of assetml_get_asset\n");
+      g_message("assetml_get_asset file=%s number of matches=%d\n", file, g_list_length(gl_result));
       g_list_foreach (gl_result, (GFunc) dump_asset, NULL);
-#endif
       return gl_result;
     }
 }
