@@ -1,6 +1,6 @@
 /* gcompris - bar.c
  *
- * Time-stamp: <2005/04/10 19:25:52 bruno>
+ * Time-stamp: <2005/10/03 21:36:37 bruno>
  *
  * Copyright (C) 2000-2003 Bruno Coudoin
  *
@@ -24,6 +24,8 @@
  *
  */
 
+#include <string.h>
+
 #include "gcompris.h"
 #include "gcompris_config.h"
 #include "about.h"
@@ -66,7 +68,6 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 {
 
   GdkPixbuf   *pixmap = NULL;
-  GnomeCanvasItem *item;
   GnomeCanvasItem *rootitem;
   gint16           width, height;
   double           zoom;
@@ -89,8 +90,6 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 				"pixbuf", pixmap, 
 				"x", (double) 0,
 				"y", (double) 0,
-				"width", (double)  gdk_pixbuf_get_width(pixmap),
-				"height", (double) gdk_pixbuf_get_height(pixmap),
 				NULL);
   gdk_pixbuf_unref(pixmap);
 
@@ -103,10 +102,6 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 				     "x", (double) (width/NUMBER_OF_ITEMS) * 1 -
 				     gdk_pixbuf_get_width(pixmap)/2,
 				     "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
-				     "width", (double)  gdk_pixbuf_get_width(pixmap),
-				     "height", (double) gdk_pixbuf_get_height(pixmap),
-				     "width_set", TRUE, 
-				     "height_set", TRUE,
 				     NULL);
   gdk_pixbuf_unref(pixmap);
 
@@ -128,10 +123,6 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 				     "x", (double) (width/NUMBER_OF_ITEMS) * 9 - 
 				     gdk_pixbuf_get_width(pixmap)/2,
 				     "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
-				     "width", (double)  gdk_pixbuf_get_width(pixmap),
-				     "height", (double) gdk_pixbuf_get_height(pixmap),
-				     "width_set", TRUE, 
-				     "height_set", TRUE,
 				     NULL);
   gdk_pixbuf_unref(pixmap);
 
@@ -153,10 +144,6 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 				   "x", (double) (width/NUMBER_OF_ITEMS) * 7 -
 				   gdk_pixbuf_get_width(pixmap)/2,
 				   "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
-				   "width", (double)  gdk_pixbuf_get_width(pixmap),
-				   "height", (double) gdk_pixbuf_get_height(pixmap),
-				   "width_set", TRUE, 
-				   "height_set", TRUE,
 				   NULL);
   gdk_pixbuf_unref(pixmap);
 
@@ -178,10 +165,6 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 				      "x", (double) (width/NUMBER_OF_ITEMS) * 5 -
 				      gdk_pixbuf_get_width(pixmap)/2,
 				      "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
-				      "width", (double)  gdk_pixbuf_get_width(pixmap),
-				      "height", (double) gdk_pixbuf_get_height(pixmap),
-				      "width_set", TRUE, 
-				      "height_set", TRUE,
 				      NULL);
   gdk_pixbuf_unref(pixmap);
 
@@ -203,10 +186,6 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 				       "x", (double) (width/NUMBER_OF_ITEMS) * 6 -
 				       gdk_pixbuf_get_width(pixmap)/2,
 				       "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
-				       "width", (double)  gdk_pixbuf_get_width(pixmap),
-				       "height", (double) gdk_pixbuf_get_height(pixmap),
-				       "width_set", TRUE, 
-				       "height_set", TRUE,
 				       NULL);
   gdk_pixbuf_unref(pixmap);
   
@@ -227,10 +206,6 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 				     "x", (double) (width/NUMBER_OF_ITEMS) * 4 -
 				     gdk_pixbuf_get_width(pixmap)/2,
 				     "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
-				     "width", (double)  gdk_pixbuf_get_width(pixmap),
-				     "height", (double) gdk_pixbuf_get_height(pixmap),
-				     "width_set", TRUE, 
-				     "height_set", TRUE,
 				     NULL);
   gdk_pixbuf_unref(pixmap);
 
@@ -251,10 +226,6 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 				     "x", (double) (width/NUMBER_OF_ITEMS) * 3 -
 				     gdk_pixbuf_get_width(pixmap)/2,
 				     "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
-				     "width", (double)  gdk_pixbuf_get_width(pixmap),
-				     "height", (double) gdk_pixbuf_get_height(pixmap),
-				     "width_set", TRUE, 
-				     "height_set", TRUE,
 				     NULL);
   gdk_pixbuf_unref(pixmap);
 
@@ -275,10 +246,6 @@ void gcompris_bar_start (GnomeCanvas *theCanvas)
 				     "x", (double) (width/NUMBER_OF_ITEMS) * 2 -
 				     gdk_pixbuf_get_width(pixmap)/2,
 				     "y", (double) (height-gdk_pixbuf_get_height(pixmap)*zoom)/2,
-				     "width", (double)  gdk_pixbuf_get_width(pixmap),
-				     "height", (double) gdk_pixbuf_get_height(pixmap),
-				     "width_set", TRUE, 
-				     "height_set", TRUE,
 				     NULL);
   gdk_pixbuf_unref(pixmap);
 
@@ -317,7 +284,6 @@ void gcompris_bar_set_level(GcomprisBoard *gcomprisBoard)
     {
 
       str = g_strdup_printf("level%d.png", gcomprisBoard->level);
-      GcomprisProperties	*properties = gcompris_get_properties();
       pixmap = gcompris_load_skin_pixmap(str);
    
       g_free(str);
@@ -357,7 +323,6 @@ gcompris_bar_set_repeat_icon (GdkPixbuf *pixmap)
 void
 gcompris_bar_set (const GComprisBarFlags flags)
 {
-  GcomprisProperties	*properties = gcompris_get_properties();
 
   current_flags = flags;
 
