@@ -1,6 +1,6 @@
 /* gcompris - config.c
  *
- * Time-stamp: <2005/04/07 00:19:08 bruno>
+ * Time-stamp: <2005/11/12 19:00:36 bruno>
  *
  * Copyright (C) 2000-2003 Bruno Coudoin
  *
@@ -23,12 +23,12 @@
  * Configuration of gcompris
  */
 
+#include <string.h>
+
 #include "gcompris.h"
 #include "gcompris_config.h"
 #include "locale.h"
 
-#include <dirent.h>
-
 #if defined _WIN32 || defined __WIN32__
 # undef WIN32   /* avoid warning on mingw32 */
 # define WIN32
@@ -63,37 +63,39 @@ static gchar *linguas[] = {
   "",			N_("Your system default"),
   "am_ET.UTF-8", 	N_("Amharic"),
   "ar_AE.UTF-8", 	N_("Arabic"),
-  "az_AZ.UTF-8", 	N_("Azerbaijani Turkic"),
+  "az_AZ.UTF-8", 	N_("Turkish (Azerbaijan)"),
   "bg_BG.UTF-8",	N_("Bulgarian"),
   "ca_ES.UTF-8",	N_("Catalan"),
-  "cs_CZ.UTF-8",	N_("Czech"),
+  "cs_CZ.UTF-8",	N_("Czech Republic"),
   "da_DK.UTF-8", 	N_("Danish"),
   "de_DE.UTF-8", 	N_("German"),
   "el_GR.UTF-8", 	N_("Greek"),
-  "en_CA.UTF-8",	N_("English (Canadian)"),
+  "en_CA.UTF-8",	N_("English (Canada)"),
   "en_GB.UTF-8",	N_("English (Great Britain)"),
-  "en_US.UTF-8",	N_("English (USA)"),
   "es_ES.UTF-8", 	N_("Spanish"),
+  "eu_ES.UTF-8",	N_("Basque"),
   "fi_FI.UTF-8", 	N_("Finnish"),
   "fr_FR.UTF-8", 	N_("French"),
   "ga_IE.UTF-8", 	N_("Irish (Gaelic)"),
   "he_IL.UTF-8",	N_("Hebrew"),
-  "hi_IN.UTF-8",	N_("Indian (Hindi)"),
-  "gu_IN.UTF-8",	N_("Indian (Gujarati)"),
-  "pa_IN.UTF-8",	N_("Indian (Punjabi)"),
+  "hi_IN.UTF-8",	N_("Hindi"),
+  "gu_IN.UTF-8",	N_("Gujarati"),
+  "pa_IN.UTF-8",	N_("Punjabi"),
   "hu_HU.UTF-8",	N_("Hungarian"),
   "hr_HR.UTF-8",	N_("Croatian"),
   "it_IT.UTF-8", 	N_("Italian"),
+  "ka_GE.UTF-8",        N_("Georgian"),
   "lt_LT.UTF-8",	N_("Lithuanian"),
   "mk_MK.UTF-8",	N_("Macedonian"),
   "ml_IN.UTF-8",	N_("Malayalam"),
   "ms_MY.UTF-8",	N_("Malay"),
+  "ne_NP.UTF-8",	N_("Nepal"),
   "nl_NL.UTF-8",	N_("Dutch"),
   "nb_NO.UTF-8",	N_("Norwegian Bokmal"),
   "nn_NO.UTF-8",	N_("Norwegian Nynorsk"),
   "pl_PL.UTF-8",	N_("Polish"),
   "pt_PT.UTF-8",	N_("Portuguese"),
-  "pt_BR.UTF-8",	N_("Brazil Portuguese"),
+  "pt_BR.UTF-8",	N_("Portuguese (Brazil)"),
   "ro_RO.UTF-8",	N_("Romanian"),
   "ru_RU.UTF-8",	N_("Russian"),
   "rw_RW.UTF-8",	N_("Kinyarwanda"),
@@ -104,6 +106,7 @@ static gchar *linguas[] = {
   "sr_YU.UTF-8",	N_("Serbian"),
   "sv_FI.UTF-8",	N_("Swedish"),
   "tr_TR.UTF-8",	N_("Turkish"),
+  "vi_VN.UTF-8",	N_("Vietnamese"),
   "wa_BE.UTF-8",	N_("Walloon"),
   "zh_CN.UTF-8",	N_("Chinese (Simplified)"),
   NULL, NULL
@@ -123,18 +126,16 @@ static gchar *screenname[] = {
 };
 
 static gchar *filtername[] = {
-  N_("No filter"),
-  N_("Only this level"),
-  N_("Up to this level"),
-  N_("This level and above")
+  N_("<i>Use Gcompris administration module\nto filter boards</i>")
 };
 
 static void set_locale_flag(gchar *locale);
 static gchar *get_locale_name(gchar *locale);
 static gchar *get_next_locale(gchar *locale);
 static gchar *get_previous_locale(gchar *locale);
-static void   display_difficulty_level();
-static gint item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data);
+static gint   item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data);
+static void   display_previous_next(guint x_start, guint y_start, 
+				    gchar *eventname_previous, gchar *eventname_next);
 
 
 /*
@@ -180,15 +181,24 @@ void gcompris_config_start ()
   y = BOARDHEIGHT - (BOARDHEIGHT - gdk_pixbuf_get_height(pixmap))/2;
   gdk_pixbuf_unref(pixmap);
 
-  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-				gnome_canvas_text_get_type (),
-				"text", _("GCompris Configuration"),
-				"font", gcompris_skin_font_title,
-				"x", (double) BOARDWIDTH/2,
-				"y", (double) y_start + 40,
-				"anchor", GTK_ANCHOR_CENTER,
-				"fill_color_rgba", gcompris_skin_color_title,
-				NULL);
+  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+			 gnome_canvas_text_get_type (),
+			 "text", _("GCompris Configuration"),
+			 "font", gcompris_skin_font_title,
+			 "x", (double) BOARDWIDTH/2 + 1.0,
+			 "y", (double) y_start + 40 + 1.0,
+			 "anchor", GTK_ANCHOR_CENTER,
+			 "fill_color_rgba", gcompris_skin_color_shadow,
+			 NULL);
+  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+			 gnome_canvas_text_get_type (),
+			 "text", _("GCompris Configuration"),
+			 "font", gcompris_skin_font_title,
+			 "x", (double) BOARDWIDTH/2,
+			 "y", (double) y_start + 40,
+			 "anchor", GTK_ANCHOR_CENTER,
+			 "fill_color_rgba", gcompris_skin_color_title,
+			 NULL);
 
   // OK
   pixmap = gcompris_load_skin_pixmap("button_large.png");
@@ -206,6 +216,15 @@ void gcompris_config_start ()
 		     (GtkSignalFunc) gcompris_item_event_focus,
 		     NULL);
 
+  gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+			 gnome_canvas_text_get_type (),
+			 "text", _("OK"),
+			 "font", gcompris_skin_font_title,
+			 "x", (double)  BOARDWIDTH*0.5 + 1.0,
+			 "y", (double)  y - gdk_pixbuf_get_height(pixmap) + 20 + 1.0,
+			 "anchor", GTK_ANCHOR_CENTER,
+			 "fill_color_rgba", gcompris_skin_color_shadow,
+			 NULL);
   item2 = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_text_get_type (),
 				"text", _("OK"),
@@ -387,37 +406,36 @@ void gcompris_config_start ()
 
   // Skin
   {
-    struct dirent *one_dirent;
-    guint i;
-    char *str;
-    DIR *dir;
+    gchar *one_dirent;
+    guint  i;
+    GDir  *dir;
     
     /* Load the Pixpmaps directory file names */
-    dir = opendir(PACKAGE_DATA_DIR"/skins");
+    dir = g_dir_open(PACKAGE_DATA_DIR"/skins", 0, NULL);
 
     if (!dir)
       g_error (_("Couldn't open skin dir: %s"), PACKAGE_DATA_DIR"/skins");
     
     /* Fill up the skin list */
-    while((one_dirent = readdir(dir)) != NULL) {
+    while((one_dirent = g_dir_read_name(dir)) != NULL) {
 
-      if (one_dirent->d_name[0] != '.') {
+      if (one_dirent[0] != '.') {
 	gchar *filename;
 	/* Only directory here are skins */
-	filename = g_strdup_printf("%s/skins/%s", PACKAGE_DATA_DIR, one_dirent->d_name);
+	filename = g_strdup_printf("%s/skins/%s", PACKAGE_DATA_DIR, one_dirent);
 
 	if (g_file_test ((filename), G_FILE_TEST_IS_DIR)) {
-	  gchar *skin_name = g_strdup_printf("%s", one_dirent->d_name);
+	  gchar *skin_name = g_strdup_printf("%s", one_dirent);
 	  skinlist = g_list_append (skinlist, skin_name);
 	}
 	g_free(filename);
       }
     }
-    closedir(dir);
+    g_dir_close(dir);
 
     /* Should not happen. It the user found the config, there should be a skin */
     if(g_list_length(skinlist) == 0) {
-      g_warning( _("No skin found in %s\n"), PACKAGE_DATA_DIR"/skins");
+      g_warning( "No skin found in %s\n", PACKAGE_DATA_DIR"/skins");
     }
 
     /* Find the current skin index */
@@ -445,14 +463,14 @@ void gcompris_config_start ()
   // Difficulty Filter
   y_start += Y_GAP;
 
-  display_previous_next(x_start, y_start, "filter_style_previous", "filter_style_next");
+  //  display_previous_next(x_start, y_start, "filter_style_previous", "filter_style_next");
 
   stars_group_x = x_start + 45;
   stars_group_y = y_start - 25;
 
   item_filter_text = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 						gnome_canvas_text_get_type (),
-						"text", gettext(filtername[properties->filter_style]), 
+						"markup", gettext(filtername[0]), 
 						"font", gcompris_skin_font_subtitle,
 						"x", (double) x_text_start,
 						"y", (double) y_start,
@@ -461,9 +479,6 @@ void gcompris_config_start ()
 						NULL);
 
 
-  // Difficulty star action button
-  display_difficulty_level();
-
   is_displayed = TRUE;
 }
 
@@ -490,7 +505,7 @@ void gcompris_config_stop ()
   pixmap_checked = NULL;
 
   /* UnPause the board */
-  if(gcomprisBoard->plugin->pause_board != NULL && is_displayed)
+  if((gcomprisBoard->plugin->pause_board != NULL) && is_displayed)
     {
       gcomprisBoard->plugin->pause_board(FALSE);
     }
@@ -505,7 +520,7 @@ void gcompris_config_stop ()
 /*-------------------------------------------------------------------------------*/
 /*-------------------------------------------------------------------------------*/
 /*-------------------------------------------------------------------------------*/
-
+static void
 display_previous_next(guint x_start, guint y_start, 
 		      gchar *eventname_previous, gchar *eventname_next)
 {
@@ -557,7 +572,7 @@ static void set_locale_flag(gchar *locale)
   if(locale[0] == '\0') {
     /* Set the flag to the default user's locale */
     locale = gcompris_get_user_default_locale();
-    printf("gcompris_get_user_default_locale = %s\n", locale);
+    g_message("gcompris_get_user_default_locale = %s\n", locale);
   }
 
   /* First try to find a flag for the long locale name */
@@ -663,31 +678,6 @@ static gchar *get_previous_locale(gchar *locale)
   return(locale);
 }
 
-static void display_difficulty_level() 
-{
-  GcomprisProperties	*properties = gcompris_get_properties();
-
-  if(properties->filter_style != GCOMPRIS_FILTER_NONE) {
-    if(properties->difficulty_filter == 0)	/* If it was the devel mode, exit it */
-      properties->difficulty_filter = 1;
-
-    if(stars_group)
-      gtk_object_destroy(GTK_OBJECT(stars_group));
-	    
-    stars_group = gcompris_display_difficulty_stars(GNOME_CANVAS_GROUP(rootitem),
-						    (double) stars_group_x,
-						    (double) stars_group_y,
-						    (double) 1,
-						    properties->difficulty_filter);
-    gtk_signal_connect(GTK_OBJECT(stars_group), "event",
-		       (GtkSignalFunc) item_event_ok,
-		       "difficulty_next");
-  } else {
-    if(stars_group)
-      gnome_canvas_item_hide(stars_group);
-  }
-}
-
 /* Callback for the bar operations */
 static gint
 item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
@@ -695,7 +685,7 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
   GcomprisProperties	*properties = gcompris_get_properties();
 
   if(data==NULL)
-    return;
+    return FALSE;
 
   switch (event->type) 
     {
@@ -716,7 +706,6 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	  gcompris_skin_load(properties->skin);
 	  gcompris_config_stop();
 	  gcompris_properties_save(properties);
-	  gcompris_load_menus();
 
 	  if(properties->music || properties->fx) {
 	    initSound();
@@ -725,6 +714,14 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
       else if(!strcmp((char *)data, "fullscreen"))
 	{
 	  properties->fullscreen = (properties->fullscreen ? 0 : 1);
+
+#ifdef XRANDR
+	  /* Changing screen without xrandr is more complex, it requires to remove the
+	     black border we created manually.
+	  */
+	  if(!properties->noxrandr)
+	    gcompris_set_fullscreen(properties->fullscreen);
+#endif
 	  /* Warning changing the image needs to update pixbuf_ref for the focus usage */
 	  g_object_set_data (G_OBJECT (item), "pixbuf_ref",  
 			     (properties->fullscreen ? pixmap_checked : pixmap_unchecked));
@@ -832,33 +829,6 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 							 (char *)g_list_nth_data(skinlist, skin_index)),
 				 NULL);
 	}
-      else if(!strcmp((char *)data, "difficulty_next"))
-	{
-	  if(properties->difficulty_filter++ >= properties->difficulty_max)
-	    properties->difficulty_filter = 1;
-
-	  display_difficulty_level();
-	}
-      else if(!strcmp((char *)data, "filter_style_previous"))
-	{
-	  if(properties->filter_style-- < 1)
-	    properties->filter_style = GCOMPRIS_FILTER_ABOVE;
-
-	  gnome_canvas_item_set (item_filter_text,
-				 "text", gettext(filtername[properties->filter_style]), 
-				 NULL);
-	  display_difficulty_level();
-	}
-      else if(!strcmp((char *)data, "filter_style_next"))
-	{
-	  if(properties->filter_style++ >= GCOMPRIS_FILTER_ABOVE)
-	    properties->filter_style = 0;
-
-	  gnome_canvas_item_set (item_filter_text,
-				 "text", gettext(filtername[properties->filter_style]), 
-				 NULL);
-	  display_difficulty_level();
-	}
     default:
       break;
     }
