@@ -1,6 +1,6 @@
 /* gcompris - file_selector.c
  *
- * Time-stamp: <2005/04/17 16:01:23 bruno>
+ * Time-stamp: <2005/11/12 19:00:49 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -26,7 +26,7 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <dirent.h>
+#include <string.h>
 
 /* libxml includes */
 #include <libxml/tree.h>
@@ -46,9 +46,6 @@ static gint		 item_event_file_selector(GnomeCanvasItem *item,
 static gint		 item_event_scroll(GnomeCanvasItem *item,
 					   GdkEvent *event,
 					   GnomeCanvas *canvas);
-static gint		 item_event_fileset_selector(GnomeCanvasItem *item, 
-						     GdkEvent *event, 
-						     gpointer data);
 static gint		 item_event_directory(GnomeCanvasItem *item, 
 					      GdkEvent *event, 
 					      char *dir);
@@ -60,7 +57,6 @@ static int		 display_file_selector(int mode,
 					       FileSelectorCallBack iscb);
 static void		 entry_enter_callback( GtkWidget *widget,
 					       GtkWidget *entry );
-static int		 create_rootdir (gchar *rootdir);
 static void		 free_stuff (GtkObject *obj, gchar* data);
 
 static gboolean		 file_selector_displayed = FALSE;
@@ -77,19 +73,18 @@ static GtkEntry *widget_entry = NULL;
 static GList  *file_list = NULL;
 
 /* Represent the limits of control area */
-#define	CONTROL_AREA_X1	40.0
-#define	CONTROL_AREA_Y1	20.0
-#define	CONTROL_AREA_X2	760.0
-#define	CONTROL_AREA_Y2	80.0
+static guint32 control_area_x1;
+static guint32 control_area_y1;
+static guint32 directory_label_y;
 
 /* Represent the limits of the file area */
 #define	DRAWING_AREA_X1	40.0
-#define DRAWING_AREA_Y1	120.0
+#define DRAWING_AREA_Y1	220.0
 #define DRAWING_AREA_X2	760.0
 #define DRAWING_AREA_Y2	500.0
 
-#define HORIZONTAL_NUMBER_OF_IMAGE	6
-#define VERTICAL_NUMBER_OF_IMAGE	5
+#define HORIZONTAL_NUMBER_OF_IMAGE	5
+#define VERTICAL_NUMBER_OF_IMAGE	3
 #define IMAGE_GAP			18
 
 #define IMAGE_WIDTH  (DRAWING_AREA_X2-DRAWING_AREA_X1)/HORIZONTAL_NUMBER_OF_IMAGE-IMAGE_GAP
@@ -202,12 +197,17 @@ display_file_selector(int the_mode,
 
   mode = the_mode;
 
+  /* Get the coordinate x y of the control area from the skin */
+  control_area_x1   = gcompris_skin_get_number_default("gcompris/fileselectx", 85);
+  control_area_y1   = gcompris_skin_get_number_default("gcompris/fileselecty", 80);
+  directory_label_y = gcompris_skin_get_number_default("gcompris/fileselectdiry", 180);
+
   if(file_types) {
     file_types_string = g_strdup(file_types);
   }
 
   if(rootitem)
-    return;
+    return 0;
 
   gcompris_bar_hide(TRUE);
 
@@ -240,13 +240,13 @@ display_file_selector(int the_mode,
   gdk_pixbuf_unref(pixmap);
 
   /* Entry area */
-  widget_entry = (GtkEntry *)gtk_entry_new_with_max_length (50);
+  widget_entry = (GtkEntry *)gtk_entry_new_with_max_length (30);
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_widget_get_type (),
 				"widget", GTK_WIDGET(widget_entry),
-				"x", (double) CONTROL_AREA_X1 + 10,
-				"y", (double) y_start + 30,
-				"width", 250.0,
+				"x", (double) control_area_x1,
+				"y", (double) control_area_y1,
+				"width", 230.0,
 				"height", 30.0,
 				"anchor", GTK_ANCHOR_NW,
 				"size_pixels", FALSE,
@@ -297,8 +297,8 @@ display_file_selector(int the_mode,
     gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 			   gnome_canvas_widget_get_type (),
 			   "widget", GTK_WIDGET(gtk_combo_filetypes),
-			   "x", (double) CONTROL_AREA_X1 + 450,
-			   "y", (double) y_start + 30,
+			   "x", (double) control_area_x1 + 400,
+			   "y", (double) control_area_y1,
 			   "width", 250.0,
 			   "height", 35.0,
 			   "anchor", GTK_ANCHOR_NW,
@@ -388,47 +388,15 @@ display_file_selector(int the_mode,
 
   file_selector_displayed = TRUE;
 
-  if(g_get_home_dir()) {
-    full_rootdir = g_strconcat(g_get_home_dir(), "/.gcompris/user_data", NULL);
-    create_rootdir(full_rootdir);
-    g_free(full_rootdir);
-
-    full_rootdir = g_strconcat(g_get_home_dir(), "/.gcompris/user_data/", rootdir, NULL);
-  } else {
-    /* On WIN98, No home dir */
-    full_rootdir = g_strdup_printf("%s", "gcompris/user_data");
-    create_rootdir(full_rootdir);
-    g_free(full_rootdir);
-  
-    full_rootdir = g_strdup_printf("%s/%s", "gcompris/user_data", rootdir);
-  }
-
+  full_rootdir = g_strconcat(gcompris_get_current_user_dirname(), "/", rootdir, NULL);
   create_rootdir(full_rootdir);
 
   current_rootdir = full_rootdir;
+
   display_files(rootitem, full_rootdir);
 
-}
+  return 0;
 
-
-/*
- * create the root dir if needed
- *
- * return 0 if OK, -1 if ERROR
- */
-static int
-create_rootdir (gchar *rootdir)
-{
-
-  if(g_file_test(rootdir, G_FILE_TEST_IS_DIR)) {
-    return 0;
-  }
-
-#if defined WIN32
-  return(mkdir(rootdir));
-#else
-  return(mkdir(rootdir, 0755));
-#endif
 }
 
 static void
@@ -441,8 +409,8 @@ static void display_files(GnomeCanvasItem *root_item, gchar *rootdir)
 {
   GnomeCanvasItem *item;
   double iw, ih;
-  struct dirent *one_dirent;
-  DIR *dir;
+  const gchar *one_dirent;
+  GDir  *dir;
 
   /* Initial image position */
   guint ix  = 0.0;
@@ -460,7 +428,7 @@ static void display_files(GnomeCanvasItem *root_item, gchar *rootdir)
     return;
 
   /* Display the directory content */
-  dir = opendir(rootdir);
+  dir = g_dir_open(rootdir, 0, NULL);
 
   if (!dir) {
     g_warning("gcompris_file_selector : no root directory found in %s", rootdir);
@@ -541,9 +509,9 @@ static void display_files(GnomeCanvasItem *root_item, gchar *rootdir)
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(file_root_item),
 				gnome_canvas_text_get_type (),
 				"text", rootdir,
-				"x", (double)CONTROL_AREA_X1 + 10,
-				"y", (double)CONTROL_AREA_Y1 + 50,
-				"fill_color_rgba", 0x0000FFFF,
+				"x", (double)control_area_x1,
+				"y", (double)directory_label_y,
+				"fill_color_rgba", gcompris_skin_get_color("gcompris/fileselectcol"),
 				"anchor", GTK_ANCHOR_NW,
 				NULL);
 
@@ -553,18 +521,11 @@ static void display_files(GnomeCanvasItem *root_item, gchar *rootdir)
 
   /* Insert all files in a sorted list */
 
-  while((one_dirent = readdir(dir)) != NULL) {
+  while((one_dirent = g_dir_read_name(dir)) != NULL) {
     gchar *filename;
 
-    if((strcmp(one_dirent->d_name, "..")==0) &&
-       strcmp(current_rootdir, rootdir)==0)
-      continue;
-
-    if(strcmp(one_dirent->d_name, ".")==0)
-      continue;
-
     filename = g_strdup_printf("%s/%s",
-			       rootdir, (gchar*)(one_dirent->d_name));
+			       rootdir, (gchar*)(one_dirent));
 
     if(g_file_test(filename, G_FILE_TEST_IS_DIR)) {
       dir_list = g_list_insert_sorted(dir_list, filename,
@@ -586,7 +547,7 @@ static void display_files(GnomeCanvasItem *root_item, gchar *rootdir)
 
     gchar *allfilename = listrunner->data;
     gchar *filename    = g_path_get_basename(allfilename);
-    gchar *ext         = rindex(filename, '.');
+    gchar *ext         = strrchr(filename, '.');
 
 
 
@@ -651,7 +612,7 @@ static void display_files(GnomeCanvasItem *root_item, gchar *rootdir)
 				  "x", (double)ix + (IMAGE_WIDTH + IMAGE_GAP)/2,
 				  "y", (double)iy + IMAGE_HEIGHT - 5,
 				  "anchor", GTK_ANCHOR_CENTER,
-				  "fill_color_rgba", 0x0000FFFF,
+				  "fill_color_rgba", gcompris_skin_get_color("gcompris/fileselectcol"),
 				  NULL);
 
     if(g_file_test(allfilename, G_FILE_TEST_IS_DIR)) {
@@ -684,7 +645,7 @@ static void display_files(GnomeCanvasItem *root_item, gchar *rootdir)
     listrunner = g_list_next(listrunner);
   }
 
-  closedir(dir);
+  g_dir_close(dir);
 
 }
 
@@ -694,7 +655,7 @@ item_event_directory(GnomeCanvasItem *item, GdkEvent *event, gchar *dir)
 {
 
   if(!rootitem)
-    return;
+    return FALSE;
 
   switch (event->type) 
     {
@@ -724,7 +685,7 @@ item_event_scroll(GnomeCanvasItem *item, GdkEvent *event, GnomeCanvas *canvas)
 {
   int x, y;
   if(!rootitem)
-    return;
+    return FALSE;
 
   switch (event->type) 
     {
@@ -735,6 +696,8 @@ item_event_scroll(GnomeCanvasItem *item, GdkEvent *event, GnomeCanvas *canvas)
       else if ( event->scroll.direction == GDK_SCROLL_DOWN )
 	gnome_canvas_scroll_to (canvas, x, y + 20);
 
+      break;
+    default:
       break;
     }
   return FALSE;
@@ -746,7 +709,7 @@ item_event_file_selector(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 {
 
   if(!rootitem)
-    return;
+    return FALSE;
 
   switch (event->type) 
     {
@@ -789,7 +752,7 @@ item_event_file_selector(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	  } else {
 	    /* LOAD Mode, get the file_type from the extension in the mimetype */
 	    GcomprisMimeType *mimeType = NULL;
-	    gchar *ext         = rindex(result, '.');
+	    gchar *ext         = strrchr(result, '.');
 
 	    /* Extract the mime type */
 	    if(ext) {
@@ -838,7 +801,7 @@ static void entry_enter_callback( GtkWidget *widget,
   if(!rootitem)
     return;
 
-  entry_text = gtk_entry_get_text(GTK_ENTRY(entry));
+  entry_text = (char *)gtk_entry_get_text(GTK_ENTRY(entry));
 }
 
 /*
@@ -847,9 +810,6 @@ static void entry_enter_callback( GtkWidget *widget,
  */
 
 void parseMime (xmlDocPtr doc, xmlNodePtr xmlnode) {
-  gchar *mimeSetName = NULL;
-  gchar *filename;
-  GList	*mimeList = NULL;	/* List of Mimes */
 
   GcomprisMimeType *gcomprisMime = g_malloc0 (sizeof (GcomprisMimeType));
 
@@ -930,7 +890,7 @@ gboolean load_mime_type_from_file(gchar *fname)
   /* if the file doesn't exist */
   if(!g_file_test ((fname), G_FILE_TEST_EXISTS)) 
     {
-      g_warning(_("Couldn't find file %s !"), fname);
+      g_warning("Couldn't find file %s !", fname);
       return FALSE;
     }
 
@@ -961,16 +921,15 @@ gboolean load_mime_type_from_file(gchar *fname)
 
 /**
  * gcompris_load_mime_types
- * Load all the mime type in PACKAGE_DATA_DIR"/gcompris/mimetypes/*.xml"
+ * Load all the mime type in PACKAGE_DATA_DIR"/gcompris/mimetypes/ *.xml"
  *
  * Must be called once at GCompris startup.
  *
  */
 void gcompris_load_mime_types() 
 {
-  struct dirent *one_dirent;
-  DIR *dir;
-  int n;
+  const gchar  *one_dirent;
+  GDir   *dir;
 
   if(mimetypes_hash) {
     return;
@@ -981,31 +940,32 @@ void gcompris_load_mime_types()
   mimetypes_desc_hash = g_hash_table_new (g_str_hash, g_str_equal);
 
   /* Load the Pixpmaps directory file names */
-  dir = opendir(PACKAGE_DATA_DIR"/gcompris/mimetypes/");
+  dir = g_dir_open(PACKAGE_DATA_DIR"/gcompris/mimetypes/", 0, NULL);
 
   if (!dir) {
-    g_warning("gcompris_load_mime_types : no mime types found in %s", PACKAGE_DATA_DIR"/gcompris/mimetypes/");
+    g_warning("gcompris_load_mime_types : no mime types found in %s", 
+	      PACKAGE_DATA_DIR"/gcompris/mimetypes/");
   } else {
 
-    while((one_dirent = readdir(dir)) != NULL) {
+    while((one_dirent = g_dir_read_name(dir)) != NULL) {
       /* add the board to the list */
       gchar *filename;
       
       filename = g_strdup_printf("%s/%s",
-				 PACKAGE_DATA_DIR"/gcompris/mimetypes/", one_dirent->d_name);
+				 PACKAGE_DATA_DIR"/gcompris/mimetypes/", one_dirent);
 
       if(!g_file_test(filename, G_FILE_TEST_IS_REGULAR)) {
 	g_free(filename);
 	continue;
       }
 
-      if(selectMenuXML(one_dirent->d_name)) {
+      if(selectMenuXML(one_dirent)) {
 	load_mime_type_from_file(filename);
       }
       g_free(filename);
     }
   }
-  closedir(dir);
+  g_dir_close(dir);
 }
 
 
