@@ -1,6 +1,6 @@
 /* gcompris - gameutil.c
  *
- * Time-stamp: <2005/04/10 23:50:40 bruno>
+ * Time-stamp: <2005/11/17 11:13:26 yves>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -19,12 +19,14 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <dirent.h>
 #include <math.h>
+#include <string.h>
+#include <time.h>
 
 /* libxml includes */
 #include <libxml/tree.h>
 #include <libxml/parser.h>
+#include <libxml/parserInternals.h>
 
 #include "gcompris.h"
 
@@ -34,9 +36,6 @@
 
 #define MAX_DESCRIPTION_LENGTH 1000
 
-/* default gnome pixmap directory in which this game tales the icon */
-static char *lettersdir = "letters/";
-
 /* List of all available boards  */
 static GList *boards_list = NULL;
 
@@ -48,6 +47,12 @@ extern GnomeCanvas *canvas;
 
 typedef void (*sighandler_t)(int);
 
+
+GList *gcompris_get_boards_list()
+{
+  return boards_list;
+}
+
 /*
  * Returns a filename path found from the assetml base. 
  */
@@ -56,12 +61,11 @@ gchar *gcompris_get_asset_file(gchar *dataset, gchar* categories,
 {
   GList *gl_result;
   AssetML *assetml;
-  GdkPixbuf *pixmap;
   gchar* resultfile = NULL;
 
   gl_result = assetml_get_asset(dataset, categories, mimetype, gcompris_get_locale(), file);
 
-  if(g_list_length(gl_result)>0)
+  if(gl_result && g_list_length(gl_result)>0)
     {
 
       /* Always get the first item */
@@ -72,13 +76,69 @@ gchar *gcompris_get_asset_file(gchar *dataset, gchar* categories,
 	  resultfile = g_strdup(assetml->file);
 	}
 
+      assetml_free_assetlist(gl_result);
     }
   else
     {
-      g_warning("Asset not found (dataset='%s' category='%s' mimetype='%s' locale='%s' file='%s')\n", 
-		dataset, categories, mimetype, gcompris_get_locale(), file);
+      
+      g_warning("Asset not found:\n");
+      g_warning("   locale='%s'\n", gcompris_get_locale());
+      if (dataset)
+	g_warning("   dataset='%s'\n", dataset);
+      if (categories)
+	g_warning("   category='%s'\n", categories);
+      if(mimetype)
+	g_warning("   mimetype='%s'\n", mimetype);
+      if(file)
+	g_warning("   file='%s'\n", file);
+    }
+
+  return (resultfile);
+}
+
+/*
+ * Returns a filename path found from the assetml base. 
+ */
+gchar *gcompris_get_asset_file_locale(gchar *dataset, gchar* categories, 
+			       gchar* mimetype, gchar* file, gchar *locale)
+{
+  GList *gl_result;
+  AssetML *assetml;
+  gchar* resultfile = NULL;
+  gchar *mylocale = locale;
+
+  if (!mylocale || (strcmp( mylocale, "NULL") == 0))
+    mylocale = (gchar *)gcompris_get_locale();
+
+  gl_result = assetml_get_asset(dataset, categories, mimetype, mylocale, file);
+
+  if(gl_result && g_list_length(gl_result)>0)
+    {
+
+      /* Always get the first item */
+      assetml = (AssetML *)g_list_nth_data(gl_result, 0);
+
+      if(assetml->file)
+	{
+	  resultfile = g_strdup(assetml->file);
+	}
+
+      assetml_free_assetlist(gl_result);
+    }
+  else
+    {
+      
+      g_warning("Asset not found:\n");
+      g_warning("   locale='%s'\n", mylocale);
+      if (dataset)
+	g_warning("   dataset='%s'\n", dataset);
+      if (categories)
+	g_warning("   category='%s'\n", categories);
+      if(mimetype)
+	g_warning("   mimetype='%s'\n", mimetype);
+      if(file)
+	g_warning("   file='%s'\n", file);
     }
-  assetml_free_assetlist(gl_result);
 
   return (resultfile);
 }
@@ -124,7 +184,7 @@ GdkPixbuf *gcompris_load_pixmap(char *pixmapfile)
 
   if (!filename) {
     char *str;
-    g_warning (_("Couldn't find file %s !"), pixmapfile);
+    g_warning ("Couldn't find file %s !", pixmapfile);
 
     str = g_strdup_printf("%s\n%s\n%s\n%s", 
 			  _("Couldn't find file"), 
@@ -304,16 +364,27 @@ gint gcompris_item_event_focus(GnomeCanvasItem *item, GdkEvent *event,
  * \f \n \r \t \\ \" and the octal format.
  * 
  */
-gchar *reactivate_newline(gchar *str)
+gchar *reactivate_newline(char *str)
 {
   gchar *newstr;
 
+  xmlParserCtxtPtr ctxt = xmlNewParserCtxt	();
+
   if(str==NULL)
     return NULL;
 
-  newstr = g_strcompress(str);
+
+
+  newstr =  xmlStringDecodeEntities	(ctxt, 
+					 str, 
+					 XML_SUBSTITUTE_REF, 
+					 0, 
+					 0, 
+					 0);
+    
+  xmlFreeParserCtxt		(ctxt);
   
-  g_free(str);
+  //g_free(str);
 
   return newstr;
 }
@@ -324,9 +395,15 @@ gchar *reactivate_newline(gchar *str)
  */
 
 static void
-gcompris_add_xml_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child, GcomprisBoard *gcomprisBoard)
+gcompris_add_xml_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child, GcomprisBoard *gcomprisBoard, gboolean db)
 {
   GcomprisProperties	*properties = gcompris_get_properties();
+  gchar *title=NULL;
+  gchar *description=NULL;
+  gchar *prerequisite=NULL;
+  gchar *goal=NULL;
+  gchar *manual=NULL;
+  gchar *credit=NULL;
 
   if(/* if the node has no name */
      !xmlnode->name ||
@@ -346,7 +423,16 @@ gcompris_add_xml_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child, Gcomp
   gcomprisBoard->boarddir		 = xmlGetProp(xmlnode,"boarddir");
   gcomprisBoard->mandatory_sound_file	 = xmlGetProp(xmlnode,"mandatory_sound_file");
   gcomprisBoard->mandatory_sound_dataset = xmlGetProp(xmlnode,"mandatory_sound_dataset");
-  gcomprisBoard->section		 = xmlGetProp(xmlnode,"section");
+
+  gchar *path                            = xmlGetProp(xmlnode,"section");
+  if (strlen(path)==1){
+    g_free(path);
+    path = g_strdup("");
+    if (strcmp(gcomprisBoard->name,"root")==0)
+      gcomprisBoard->name = "";
+  }
+
+  gcomprisBoard->section		 = path;
 
   gcomprisBoard->title = NULL;
   gcomprisBoard->description = NULL;
@@ -363,103 +449,63 @@ gcompris_add_xml_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child, Gcomp
   if(properties->difficulty_max < atoi(gcomprisBoard->difficulty))
     properties->difficulty_max = atoi(gcomprisBoard->difficulty);
 
-  xmlnode = xmlnode->xmlChildrenNode;
-  while (xmlnode != NULL) {
-    gchar *lang = xmlGetProp(xmlnode,"lang");
+  for (xmlnode = xmlnode->xmlChildrenNode; xmlnode != NULL; xmlnode = xmlnode->next) {
+    if (xmlHasProp(xmlnode, "lang"))
+      continue;
+
     /* get the title of the board */
-    if (!strcmp(xmlnode->name, "title")
-	&& (lang==NULL
-	    || !strcmp(lang, gcompris_get_locale())
-	    || !strncmp(lang, gcompris_get_locale(), 2)))
+    if (!strcmp(xmlnode->name, "title"))
       {
-	gcomprisBoard->title = reactivate_newline(xmlNodeListGetString(doc, 
-								       xmlnode->xmlChildrenNode, 1));
+	title = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 0);
+	gcomprisBoard->title = reactivate_newline(gettext(title));
       }
 
     /* get the description of the board */
-    if (!strcmp(xmlnode->name, "description")
-	&& (lang==NULL ||
-	    !strcmp(lang, gcompris_get_locale())
-	    || !strncmp(lang, gcompris_get_locale(), 2)))
+    if (!strcmp(xmlnode->name, "description"))
       {
-	int i;
-	gcomprisBoard->description = reactivate_newline(xmlNodeListGetString(doc, 
-									     xmlnode->xmlChildrenNode, 1));
-
-	/* WARNING: I used to use the richtext item that handle the clipping but it is not
-	 * stable enough. Here I remove any \n unterered by the translator and insert new newlines
-	 */
-
-	/* Remove newline in description if needed */
-	for(i=0; i<strlen(gcomprisBoard->description); i++) {
-	  if(gcomprisBoard->description[i]=='\n')
-	    gcomprisBoard->description[i]=' ';
-	}
-
-	/* Insert newline in description if needed */
-	i=60;
-	while(i<strlen(gcomprisBoard->description)) {
-	  char *index;
-	  index = strchr(gcomprisBoard->description+i, ' ');
-	  if(index)
-	    *index='\n';
-	  i+=70;
-	}
+	description = xmlNodeListGetString(doc, xmlnode->xmlChildrenNode, 0);
+	gcomprisBoard->description = reactivate_newline(gettext(description));
       }
 
     /* get the help prerequisite help of the board */
-    if (!strcmp(xmlnode->name, "prerequisite")
-	&& (lang==NULL ||
-	    !strcmp(lang, gcompris_get_locale())
-	    || !strncmp(lang, gcompris_get_locale(), 2)))
+    if (!strcmp(xmlnode->name, "prerequisite"))
       {
 	if(gcomprisBoard->prerequisite)
 	  g_free(gcomprisBoard->prerequisite);
-
-	gcomprisBoard->prerequisite = reactivate_newline(xmlNodeListGetString(doc, 
-									      xmlnode->xmlChildrenNode, 1));
+	
+	prerequisite = xmlNodeListGetString(doc,  xmlnode->xmlChildrenNode, 0);
+	gcomprisBoard->prerequisite = reactivate_newline(gettext(prerequisite));
       }
 
     /* get the help goal of the board */
-    if (!strcmp(xmlnode->name, "goal")
-	&& (lang==NULL ||
-	    !strcmp(lang, gcompris_get_locale())
-	    || !strncmp(lang, gcompris_get_locale(), 2)))
+    if (!strcmp(xmlnode->name, "goal"))
       {
 	if(gcomprisBoard->goal)
 	  g_free(gcomprisBoard->goal);
   
-	gcomprisBoard->goal = reactivate_newline(xmlNodeListGetString(doc, 
-								      xmlnode->xmlChildrenNode, 1));
+	goal = xmlNodeListGetString(doc,  xmlnode->xmlChildrenNode, 0);
+	gcomprisBoard->goal = reactivate_newline(gettext(goal));
       }
 
     /* get the help user manual of the board */
-    if (!strcmp(xmlnode->name, "manual")
-	&& (lang==NULL ||
-	    !strcmp(lang, gcompris_get_locale())
-	    || !strncmp(lang, gcompris_get_locale(), 2)))
+    if (!strcmp(xmlnode->name, "manual"))
       {
 	if(gcomprisBoard->manual)
 	  g_free(gcomprisBoard->manual);
-  
-	gcomprisBoard->manual = reactivate_newline(xmlNodeListGetString(doc, 
-									xmlnode->xmlChildrenNode, 1));
+
+	manual = xmlNodeListGetString(doc,  xmlnode->xmlChildrenNode, 0);
+	gcomprisBoard->manual = reactivate_newline(gettext(manual));
       }
 
     /* get the help user credit of the board */
-    if (!strcmp(xmlnode->name, "credit")
-	&& (lang==NULL ||
-	    !strcmp(lang, gcompris_get_locale())
-	    || !strncmp(lang, gcompris_get_locale(), 2)))
+    if (!strcmp(xmlnode->name, "credit"))
       {
 	if(gcomprisBoard->credit)
 	  g_free(gcomprisBoard->credit);
   
-	gcomprisBoard->credit = reactivate_newline(xmlNodeListGetString(doc, 
-									xmlnode->xmlChildrenNode, 1));
+	credit = xmlNodeListGetString(doc,  xmlnode->xmlChildrenNode, 0);
+	gcomprisBoard->credit = reactivate_newline(gettext(credit));
       }
-
-    xmlnode = xmlnode->next;
   }
 
 
@@ -472,11 +518,39 @@ gcompris_add_xml_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child, Gcomp
      gcomprisBoard->description == NULL) {
     g_error("failed to read a mandatory field for this board (mandatory fields are name type icon_name difficulty section title description). check the board xml file is complete, perhaps xml-i18n-tools did not generate the file properly");
   }
+
+  if (db){
+    gcompris_db_board_update( &gcomprisBoard->board_id, 
+			      &gcomprisBoard->section_id, 
+			      gcomprisBoard->name, 
+			      gcomprisBoard->section, 
+			      gcomprisBoard->author, 
+			      gcomprisBoard->type, 
+			      gcomprisBoard->mode, 
+			      atoi(gcomprisBoard->difficulty), 
+			      gcomprisBoard->icon_name, 
+			      gcomprisBoard->boarddir,
+			      gcomprisBoard->mandatory_sound_file,
+			      gcomprisBoard->mandatory_sound_dataset,
+			      gcomprisBoard->filename,
+			      title,
+			      description,
+			      prerequisite,
+			      goal,
+			      manual,
+			      credit
+			      );
+  
+    g_warning("db board written %d in %d  %s/%s", 
+	      gcomprisBoard->board_id, gcomprisBoard->section_id, 
+	      gcomprisBoard->section, gcomprisBoard->name);
+  }
+  
 }
 
 /* parse the doc, add it to our internal structures and to the clist */
 static void
-parse_doc(xmlDocPtr doc, GcomprisBoard *gcomprisBoard)
+parse_doc(xmlDocPtr doc, GcomprisBoard *gcomprisBoard, gboolean db)
 {
   xmlNodePtr node;
 
@@ -485,7 +559,7 @@ parse_doc(xmlDocPtr doc, GcomprisBoard *gcomprisBoard)
   for(node = doc->children->children; node != NULL; node = node->next) {
     /* add the board to the list, there are no children so
        we pass NULL as the node of the child */
-    gcompris_add_xml_to_data(doc, node, NULL, gcomprisBoard);
+    gcompris_add_xml_to_data(doc, node, NULL, gcomprisBoard, db);
   }
 }
 
@@ -495,13 +569,15 @@ parse_doc(xmlDocPtr doc, GcomprisBoard *gcomprisBoard)
    dump any old data we have in memory if we can load a new set
    Return a newly allocated GcomprisBoard or NULL if the parsing failed
 */
-GcomprisBoard *gcompris_read_xml_file(GcomprisBoard *gcomprisBoard, char *fname)
+GcomprisBoard *gcompris_read_xml_file(GcomprisBoard *gcomprisBoard, 
+				      char *fname,
+				      gboolean db)
 {
   gchar *filename;
   /* pointer to the new doc */
   xmlDocPtr doc;
 
-  g_return_val_if_fail(fname!=NULL,FALSE);
+  g_return_val_if_fail(fname!=NULL, NULL);
 
   filename = g_strdup(fname);
 
@@ -516,8 +592,8 @@ GcomprisBoard *gcompris_read_xml_file(GcomprisBoard *gcomprisBoard, char *fname)
 
       if(!g_file_test ((filename), G_FILE_TEST_EXISTS))
 	{
-	  g_warning(_("Couldn't find file %s !"), fname);
-	  g_warning(_("Couldn't find file %s !"), filename);
+	  g_warning("Couldn't find file %s !", fname);
+	  g_warning("Couldn't find file %s !", filename);
 	  g_free(filename);
 	  g_free(gcomprisBoard);
 	  return NULL;
@@ -546,13 +622,14 @@ GcomprisBoard *gcompris_read_xml_file(GcomprisBoard *gcomprisBoard, char *fname)
     return NULL;
   }
   
+  /* Store the file that belong to this board for trace and further need */
+  gcomprisBoard->filename=filename;
+
   /* parse our document and replace old data */
-  parse_doc(doc, gcomprisBoard);
+  parse_doc(doc, gcomprisBoard, db);
 
   xmlFreeDoc(doc);
 
-  /* Store the file that belong to this board for trace and further need */
-  gcomprisBoard->filename=filename;
   gcomprisBoard->board_ready=FALSE;
   gcomprisBoard->canvas=canvas;
 
@@ -574,36 +651,18 @@ GcomprisBoard *gcompris_get_board_from_section(gchar *section)
 
   for(list = boards_list; list != NULL; list = list->next) {
     GcomprisBoard *board = list->data;
+	   
+    gchar *fullname = NULL;
+    
+    fullname = g_strdup_printf("%s/%s",
+			       board->section, board->name);
 
-    if (strcmp (board->type,"menu") == 0){
-
-    g_warning("gcompris_get_board_from_section searching '%s' in menu board %s", section, board->section);
-
-      if( board->section && (strcmp (board->section, section) == 0))
-	{
-	  g_warning("gcompris_get_board_from_section found '%s' in board '%s'\n", section, board->section);
-	  return board;
-	}
-    }
-    else {
-      gchar *fullname = NULL;
-      gchar *path = NULL;
-
-      path = g_strndup (board->section,strlen(board->section)-2);
-
-      fullname = g_strdup_printf("%s/%s",
-				 path, board->name);
-
-      g_free(path);
-
-      g_warning("gcompris_get_board_from_section searching '%s' in menu board %s", section, fullname);
-
-      if (strcmp (fullname, section) == 0){
-	g_free(fullname);
-	return board;
-      }
+    if (strcmp (fullname, section) == 0){
       g_free(fullname);
+      return board;
     }
+    g_free(fullname);
+    
   }
   g_warning("gcompris_get_board_from_section searching '%s' but NOT FOUND\n", section);
   return NULL;
@@ -622,35 +681,40 @@ GList *gcompris_get_menulist(gchar *section)
 {
   GList *list = NULL;
   GList *result_list = NULL;
-  gchar *path;
+  gchar *model;
+
+  if (strlen(section)==1)
+    model = g_strdup("");
+  else
+    model = g_strdup(section);
+
+  if(!section){
+    g_warning("gcompris_get_menulist called with section == NULL !");
+    return NULL;
+  }
 
   for(list = boards_list; list != NULL; list = list->next) {
     GcomprisBoard *board = list->data;
 
-    if(board && board->section 
-       && strlen(section)<=strlen(board->section)
-       && strcmp (section, board->section) != 0) {
-
-      path = g_path_get_dirname(board->section);
-
-      if(strcmp (section, path) == 0) {	
+    if (strcmp (model, board->section) == 0) {	
+      if (strlen(board->name) != 0)
 	result_list = g_list_append(result_list, board);
-      }
-      g_free(path);
     }
   }
 
+  g_free(model);
+
   /* Sort the list now */
   result_list = g_list_sort(result_list, boardlist_compare_func);
 
   return result_list;
 }
 
-/*
- * Select only files with .xml extention
+/** Select only files with .xml extention
+ *
  * Return 1 if the given file end in .xml 0 else
  */
-int selectMenuXML(gchar *file)
+int selectMenuXML(const gchar *file)
 {
 
   if(strlen(file)<4)
@@ -665,43 +729,86 @@ void cleanup_menus() {
   for(list = boards_list; list != NULL; list = list->next) {
     GcomprisBoard *gcomprisBoard = list->data;
 
-    gcompris_read_xml_file(gcomprisBoard, gcomprisBoard->filename);
+    gcompris_read_xml_file(gcomprisBoard, gcomprisBoard->filename, FALSE);
   }
 }
 
+
+/*
+ * suppress_int_from_list
+ */
+
+GList *suppress_int_from_list(GList *list, int value)
+{
+
+  GList *cell = list;
+  int *data;
+
+  while (cell != NULL){
+    data = cell->data;
+    if (*data==value){
+      g_free(data);
+      return g_list_remove(list, data);
+    }
+    cell = cell->next;
+  }
+  g_warning("suppress_int_from_list value %d not found", value);
+  return list;
+}
+
+gboolean compare_id(gconstpointer data1, gconstpointer data2)
+{
+  int *i = (int *) data1;
+  int *j = (int *) data2;
+
+  if (*i == *j)
+    return 0;
+  else
+    return -1;
+}
+
 /*
  * gcompris_load_menus
  *
  * Load all the menu it can from the given dirname
  *
  */
-void gcompris_load_menus_dir(char *dirname){
-  struct dirent *one_dirent;
-  DIR *dir;
-  int n;
+void gcompris_load_menus_dir(char *dirname, gboolean db){
+  const gchar   *one_dirent;
+  GDir          *dir;
+  GcomprisProperties	*properties = gcompris_get_properties();
+  GList *list_old_boards_id = NULL;
 
-  dir = opendir(dirname);
+  if (!g_file_test(dirname, G_FILE_TEST_IS_DIR)) {
+    g_warning("Failed to parse board in '%s' because it's not a directory\n", dirname);
+    return;
+  }
+
+  dir = g_dir_open(dirname, 0, NULL);
 
   if (!dir) {
     g_warning("gcompris_load_menus : no menu found in %s", dirname);
+    return;
   } else {
+    if (db)
+      list_old_boards_id = gcompris_db_get_board_id(list_old_boards_id);
 
-    while((one_dirent = readdir(dir)) != NULL) {
+    while((one_dirent = g_dir_read_name(dir)) != NULL) {
       /* add the board to the list */
       GcomprisBoard *gcomprisBoard = NULL;
       gchar *filename;
       
       filename = g_strdup_printf("%s/%s",
-				 dirname, one_dirent->d_name);
+				 dirname, one_dirent);
 
       if(!g_file_test(filename, G_FILE_TEST_IS_REGULAR)) {
 	g_free(filename);
 	continue;
       }
 
-      if(selectMenuXML(one_dirent->d_name)) {
+      if(selectMenuXML(one_dirent)) {
 	gcomprisBoard = g_malloc0 (sizeof (GcomprisBoard));
-	gcomprisBoard->board_dir = dirname;
+	gcomprisBoard->board_dir = g_strdup(dirname);
 
 	/* Need to be initialized here because gcompris_read_xml_file is used also to reread 	*/
 	/* the locale data									*/
@@ -709,15 +816,45 @@ void gcompris_load_menus_dir(char *dirname){
 	gcomprisBoard->plugin=NULL;
 	gcomprisBoard->previous_board=NULL;
 
-	boards_list = g_list_append(boards_list, gcompris_read_xml_file(gcomprisBoard, 
-									filename));
-
+	GcomprisBoard *board_read = gcompris_read_xml_file(gcomprisBoard, filename, db);
+	if (board_read){
+	  list_old_boards_id = suppress_int_from_list(list_old_boards_id, board_read->board_id);
+	  if (properties->administration)
+	    boards_list = g_list_append(boards_list, board_read);
+	  else {
+	    if ((strncmp(board_read->section,
+			 "/administration",
+			 strlen("/administration"))!=0)) {
+		
+	      if (gcompris_get_current_profile() &&
+		  !(g_list_find_custom(gcompris_get_current_profile()->activities, 
+				       &(board_read->board_id), compare_id))) {
+		boards_list = g_list_append(boards_list, board_read);
+	      } else {
+		boards_list = g_list_append(boards_list, board_read);
+	      }
+	    }
+	  }
+	}
       }
       g_free(filename);
     }
   }
-  closedir(dir);
+
+  if (db){
+    /* remove suppressed boards from db */
+    while (list_old_boards_id != NULL){
+      int *data=list_old_boards_id->data;
+      gcompris_db_remove_board(*data);
+      list_old_boards_id=g_list_remove(list_old_boards_id, data);
+      g_free(data);
+    }
+
+  }
+  
+  g_dir_close(dir);
 }
+  
 
 /* load all the menus xml files in the gcompris path
  * into our memory structures.
@@ -731,12 +868,44 @@ void gcompris_load_menus()
     return;
   }
 
-  gcompris_load_menus_dir(properties->package_data_dir);
+  if ((!properties->reread_menu) && gcompris_db_check_boards()){
+    boards_list = gcompris_load_menus_db(boards_list);
 
-  if (properties->local_directory)
-    gcompris_load_menus_dir(properties->local_directory);
+    if (!properties->administration){
+      GList *out_boards = NULL;
+      GList *list = NULL;
+      GcomprisBoard *board;
 
-  gcompris_get_menulist(properties->root_menu);
+      for (list = boards_list; list != NULL; list = list->next){
+	board = (GcomprisBoard *)list->data;
+	if (g_list_find_custom(gcompris_get_current_profile()->activities,
+			       &(board->board_id), compare_id))
+	  out_boards = g_list_append(out_boards, board);
+      }
+      for (list = out_boards; list != NULL; list = list->next)
+	boards_list = g_list_remove(boards_list, list->data);
+    }
+  }
+  else {
+    int db = (gcompris_get_current_profile() ? TRUE: FALSE);
+    properties->reread_menu = TRUE;
+    gcompris_load_menus_dir(properties->package_data_dir, db);
+    GDate *today = g_date_new();
+    g_date_set_time (today, time (NULL));
+
+    gchar date[11];
+    g_date_strftime (date, 11, "%F", today);
+    gcompris_db_set_date(date);
+    gcompris_db_set_version(VERSION);
+    g_date_free(today);
+  }
+  
+
+  if (properties->local_directory){
+    gchar *board_dir = g_strdup_printf("%s/boards/", properties->local_directory);
+    gcompris_load_menus_dir(board_dir, FALSE);
+    g_free(board_dir);
+  }
 }
 
 /* ======================================= */
@@ -907,6 +1076,9 @@ void gcompris_dialog(gchar *str, DialogBoxCallBack dbcb)
 
   printf("Dialog=%s\n", str);
 
+  if(!gcomprisBoard)
+    return;
+
   /* If we are already running do nothing */
   if(rootDialogItem) {
     g_warning("Cannot run a dialog box, one is already running. Message = %s\n", str);
@@ -914,7 +1086,7 @@ void gcompris_dialog(gchar *str, DialogBoxCallBack dbcb)
   }
 
   /* First pause the board */
-  if(gcomprisBoard->plugin->pause_board != NULL)
+  if(gcomprisBoard->plugin && gcomprisBoard->plugin->pause_board != NULL)
       gcomprisBoard->plugin->pause_board(TRUE);
 
   gcompris_bar_hide(TRUE);
@@ -1004,9 +1176,8 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, DialogBoxCallBack dbcb)
       break;
     case GDK_BUTTON_PRESS:
       if(rootDialogItem)
-	gtk_object_destroy(GTK_OBJECT(rootDialogItem));
-      rootDialogItem = NULL;
-      
+	gcompris_dialog_close();
+
       /* restart the board */
       if(gcomprisBoard->plugin->pause_board != NULL)
 	gcomprisBoard->plugin->pause_board(FALSE);
@@ -1019,6 +1190,7 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, DialogBoxCallBack dbcb)
     default:
       break;
     }
+  return TRUE;
 }
 
 /**
@@ -1033,20 +1205,19 @@ GnomeCanvasGroup *gcompris_display_difficulty_stars(GnomeCanvasGroup *parent,
 						    gint difficulty)
 {
   GdkPixbuf *pixmap = NULL;
-  int i;
   GnomeCanvasGroup *stars_group = NULL;
-  GnomeCanvasGroup *item = NULL;
+  GnomeCanvasPixbuf *item = NULL;
   gchar *filename = NULL;
 
   if(difficulty==0 || difficulty>6)
-    return;
+    return NULL;
 
   filename = g_strdup_printf("difficulty_star%d.png", difficulty);
   pixmap   = gcompris_load_skin_pixmap(filename);
   g_free(filename);
 
   if(!pixmap)
-    return;
+    return NULL;
 
   stars_group = GNOME_CANVAS_GROUP(
 				  gnome_canvas_item_new (parent,
@@ -1089,29 +1260,52 @@ gchar *g_utf8_strndup(gchar* utf8text, gint n)
  return result;
 } 
 
+/** \brief search a given relative file in all gcompris dir it could be found
+ *     
+ * \return NULL or a new gchar* with the absolute_filename of the given filename
+ *
+ */
 gchar *gcompris_find_absolute_filename(gchar *filename)
 {
-  gchar *absolute_filename;
+  int			 i = 0;
+  gchar			*absolute_filename;
+  gchar			*dir_to_search[4];
   GcomprisProperties	*properties = gcompris_get_properties();
+  GcomprisBoard		*gcomprisBoard = get_current_gcompris_board();
 
-  /* Search it on the file system */
+  /* Check it's already an absolute file */
+  if(g_path_is_absolute (filename) &&
+     g_file_test (filename, G_FILE_TEST_IS_REGULAR))
+    return g_strdup(filename);
 
-  if (!g_path_is_absolute (filename)) {
-    absolute_filename = g_strdup_printf("%s/%s", properties->package_data_dir, filename);
-    if (!g_file_test (absolute_filename, G_FILE_TEST_EXISTS)) {
-      GcomprisBoard   *gcomprisBoard = get_current_gcompris_board();
+  /*
+   * Search it on the file system
+   */
+  
+  dir_to_search[i++] = properties->package_data_dir;
+  dir_to_search[i++] = properties->user_data_dir;
+
+  if(gcomprisBoard)
+    dir_to_search[i++] = gcomprisBoard->board_dir;
+
+  dir_to_search[i++] = NULL;
+
+  absolute_filename = g_strdup(filename);
+  i = 0;
+  
+  while (dir_to_search[i])
+    {
       g_free(absolute_filename);
-      absolute_filename = g_strdup_printf("%s/%s", gcomprisBoard->board_dir, filename);
+      absolute_filename = g_strdup_printf("%s/%s", dir_to_search[i], filename);
+      i++;
+      if(g_file_test (absolute_filename, G_FILE_TEST_IS_REGULAR))
+	goto FOUND;
     }
-  } else {
-    absolute_filename = strdup(filename);
-  }
-
-  if (!g_file_test (absolute_filename, G_FILE_TEST_EXISTS)){
-    g_free(absolute_filename);
-    return NULL;
-  }
+    
+  g_free(absolute_filename);
+  return NULL;
 
+ FOUND:
   return absolute_filename;
 }
 
