@@ -44,17 +44,19 @@
 #endif
 
 gchar 		*g_utf8_strndup(gchar*,gint);
+gchar           *reactivate_newline(char *str);
 
 GdkPixbuf	*gcompris_load_pixmap(char *pixmapfile);
 void		 gcompris_set_image_focus(GnomeCanvasItem *item, gboolean focus);
 gint		 gcompris_item_event_focus(GnomeCanvasItem *item, GdkEvent *event, 
 					   GnomeCanvasItem *dest_item);
-GcomprisBoard	*gcompris_read_xml_file(GcomprisBoard *gcomprisBoard, char *fname);
+GcomprisBoard	*gcompris_read_xml_file(GcomprisBoard *gcomprisBoard, char *fname, gboolean db);
 
 GcomprisBoard   *gcompris_get_board_from_section(gchar *section);
 GList		*gcompris_get_menulist(gchar *section);
 void		 gcompris_load_menus();
 void		 gcompris_load_mime_types();
+GList           *gcompris_get_boards_list();
 
 gchar		*convertUTF8Toisolat1(gchar * text);
 void		 item_absolute_move(GnomeCanvasItem *item, int x, int y);
@@ -94,6 +96,9 @@ GdkPixbuf	*gcompris_load_pixmap_asset(gchar *dataset, gchar* categories,
 gchar		*gcompris_get_asset_file(gchar *dataset, gchar* categories, 
 					 gchar* mimetype, gchar* file);
 
+gchar		*gcompris_get_asset_file_locale(gchar *dataset, gchar* categories, 
+					 gchar* mimetype, gchar* file, gchar *locale);
+
 /*! \fn void		 gcompris_clone_item(GnomeCanvasItem *item, GnomeCanvasGroup *parent)
     \brief recursive c func to clone GnomeCanvasItem
 
@@ -102,7 +107,10 @@ gchar		*gcompris_get_asset_file(gchar *dataset, gchar* categories,
 */
 void		 gcompris_clone_item(GnomeCanvasItem *item, GnomeCanvasGroup *parent);
 
-/* find the complete filename lookig for the file everywhere */
+/* find the complete filename looking for the file everywhere */
 gchar *gcompris_find_absolute_filename(gchar *filename);
 
+/** Select only files with .xml extention */
+int selectMenuXML(const gchar *file);
+
 #endif
