@@ -1,6 +1,4 @@
 /* gcompris - gcompris.c
- *
- * Time-stamp: <2005/04/19 23:12:30 bruno>
  *
  * Copyright (C) 2000-2003 Bruno Coudoin
  *
@@ -26,8 +24,11 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <time.h>
+#include <string.h>
 
 #include "gcompris.h"
+#include "gcompris_config.h"
+#include "about.h"
 #include <locale.h>
 
 #include "cursor.h"
@@ -45,23 +46,42 @@
 # define WIN32
 #endif
 
+#ifdef WIN32
+/* List of keycodes */
+static gchar *keycode[] =
+  {
+    "83640",
+    "33251",
+    "99301",
+    "71848",
+    "79657",
+    "47561",
+    "84175",
+    NULL
+  };
+#endif
+
+#define KEYCODE_LENGTH 5
+static char current_keycode[KEYCODE_LENGTH];
+static int  current_keycode_index;
+
 GtkWidget *window;
 GtkWidget *drawing_area;
 GnomeCanvas *canvas;
 GnomeCanvas *canvas_bar;
 GnomeCanvas *canvas_bg;
-
-gboolean grace_period = FALSE;
-
+ 
 //static gint pause_board_cb (GtkWidget *widget, gpointer data);
 static void quit_cb (GtkWidget *widget, gpointer data);
+static void map_cb  (GtkWidget *widget, gpointer data);
 static gint board_widget_key_press_callback (GtkWidget   *widget,
 					    GdkEventKey *event,
 					    gpointer     client_data);
+void gcompris_terminate(int  signum);
 
 GcomprisProperties	*properties = NULL;
-GcomprisBoard		*gcomprisBoardMenu = NULL;
 static gboolean		 antialiased = FALSE;
+static gboolean		 is_mapped = FALSE;
 
 /****************************************************************************/
 /* Some constants.  */
@@ -75,20 +95,27 @@ static gboolean		gcompris_debug = FALSE;
 /* Command line params */
 
 /*** gcompris-popttable */
-static int popt_fullscreen	  = FALSE;
-static int popt_window		  = FALSE;
-static int popt_sound		  = FALSE;
-static int popt_mute		  = FALSE;
-static int popt_cursor		  = FALSE;
-static int popt_version		  = FALSE;
-static int popt_aalias		  = FALSE;
-static int popt_difficulty_filter = FALSE;
-static int popt_debug		  = FALSE;
-static int popt_noxrandr	  = FALSE;
-/* <YC experimental local only options> */
+static int popt_fullscreen	   = FALSE;
+static int popt_window		   = FALSE;
+static int popt_sound		   = FALSE;
+static int popt_mute		   = FALSE;
+static int popt_cursor		   = FALSE;
+static int popt_version		   = FALSE;
+static int popt_aalias		   = FALSE;
+static int popt_difficulty_filter  = FALSE;
+static int popt_debug		   = FALSE;
+static int popt_noxrandr	   = FALSE;
 static char *popt_root_menu        = NULL;
-static char *popt_local_activity    = NULL;
-/* </YC> */
+static char *popt_local_activity   = NULL;
+static int popt_administration	   = FALSE;
+static char *popt_database         = NULL;
+static char *popt_logs_database    = NULL;
+static int popt_create_db   	   = FALSE;
+static int popt_reread_menu   	   = FALSE;
+static char *popt_profile	   = NULL;
+static int *popt_profile_list	   = FALSE;
+static char *popt_shared_dir	   = NULL;
+static char *popt_users_dir	   = NULL;
 
 static struct poptOption options[] = {
   {"fullscreen", 'f', POPT_ARG_NONE, &popt_fullscreen, 0,
@@ -107,17 +134,33 @@ static struct poptOption options[] = {
    N_("display debug informations on the console."), NULL},
   {"version", 'v', POPT_ARG_NONE, &popt_version, 0,
    N_("Print the version of " PACKAGE), NULL},
-  {"antialiased", 'a', POPT_ARG_NONE, &popt_aalias, 0,
+  {"antialiased", '\0', POPT_ARG_NONE, &popt_aalias, 0,
    N_("Use the antialiased canvas (slower)."), NULL},
   {"noxrandr", 'x', POPT_ARG_NONE, &popt_noxrandr, 0,
    N_("Disable XRANDR (No screen resolution change)."), NULL},
-/* <YC experimental local only options> */
   {"root-menu", 'l', POPT_ARG_STRING, &popt_root_menu, 0,
-   N_("Run gcompris with local menu (e.g -l /reading will let you play only reading activity directory, -l /boards/connect4 only the connect4 activity)"), NULL},
+   N_("Run gcompris with local menu (e.g -l /reading will let you play only activities in the reading directory, -l /boards/connect4 only the connect4 activity)"), NULL},
   {"local-activity", 'L', POPT_ARG_STRING, &popt_local_activity, 0,
-   N_("Run gcompris with local activity directory added to menu"), NULL},
-/* </YC> */
-#ifndef WIN32
+   N_("Run GCompris with local activity directory added to menu"), NULL},
+  {"administration", 'a', POPT_ARG_NONE, &popt_administration, 0,
+   N_("Run GCompris in administration and user-management mode"), NULL},
+  {"database", 'b', POPT_ARG_STRING, &popt_database, 0,
+   N_("Use alternate database for profiles"), NULL},
+  {"logs", 'j', POPT_ARG_STRING, &popt_logs_database, 0,
+   N_("Use alternate database for logs"), NULL},
+  {"create-db",'\0', POPT_ARG_NONE, &popt_create_db, 0,
+   N_("Create the alternate database for profiles"), NULL},
+  {"reread-menu",'\0', POPT_ARG_NONE, &popt_reread_menu, 0,
+   N_("Re-read XML Menus and store them in the database"), NULL},
+  {"profile",'p', POPT_ARG_STRING, &popt_profile, 0,
+   N_("Set the profile to use. Use 'gcompris -a' to create profiles"), NULL},
+  {"profile-list",'\0', POPT_ARG_NONE, &popt_profile_list, 0,
+   N_("List all available profiles. Use 'gcompris -a' to create profiles"), NULL},
+  {"shared-dir",'\0', POPT_ARG_STRING, &popt_shared_dir, 0,
+   N_("Shared directory location, for profiles and board-configuration data: [$HOME/.gcompris/shared]"), NULL},
+  {"users-dir",'\0', POPT_ARG_STRING, &popt_users_dir, 0,
+   N_("The location of user directories: [$HOME/.gcompris/users]"), NULL},
+#ifndef WIN32	/* Not supported on windows */
   POPT_AUTOHELP
 #endif
   {
@@ -148,11 +191,13 @@ typedef struct
 
 } XRANDRData; 
 
-static SizeID xr_previous_size;
-static XRANDRData   *xrandr;
+static SizeID		 xr_previous_size;
+static gboolean		 xr_previous_size_set = FALSE;
+static XRANDRData	*xrandr = NULL;
 
-static void xrandr_get_config ( XRANDRData *data );
-gboolean xrandr_set_config( XRANDRData  *grandr );
+static void xrandr_init ( XRANDRData *xrandr );
+static void xrandr_get_config ( XRANDRData *xrandr );
+static void xrandr_set_config( XRANDRData  *xrandr );
 #endif
 
 /****************************************************************************/
@@ -169,9 +214,10 @@ static void gcompris_close_all_dialog() {
 
 static gint
 board_widget_key_press_callback (GtkWidget   *widget,
-				GdkEventKey *event,
-				gpointer     client_data)
+				 GdkEventKey *event,
+				 gpointer     client_data)
 {
+  int kv = event->keyval;
 
   if(event->state & GDK_CONTROL_MASK && ((event->keyval == GDK_r)
 					 || (event->keyval == GDK_R))) {
@@ -180,6 +226,25 @@ board_widget_key_press_callback (GtkWidget   *widget,
     return TRUE;
   }
 
+  if(event->state & GDK_CONTROL_MASK && ((event->keyval == GDK_q)
+					 || (event->keyval == GDK_Q))) {
+    gcompris_exit();
+    return TRUE;
+  }
+
+#ifdef WIN32
+  if(event->state & (GDK_CONTROL_MASK | GDK_SHIFT_MASK) && ((event->keyval == GDK_l)
+							  || (event->keyval == GDK_L))) {
+    properties->key="thanks_for_your_help";
+    gcompris_properties_save(properties);
+    gcompris_load_menus();
+
+    gcompris_close_all_dialog();
+
+    board_stop();
+    return TRUE;
+  }
+
   if(event->state & GDK_CONTROL_MASK && ((event->keyval == GDK_p)
 					 || (event->keyval == GDK_P))) {
     properties->key="thanks_for_your_help";
@@ -192,16 +257,16 @@ board_widget_key_press_callback (GtkWidget   *widget,
     return TRUE;
   }
 
-  if(event->state & GDK_CONTROL_MASK && ((event->keyval == GDK_q)
-					 || (event->keyval == GDK_Q))) {
-    gcompris_exit();
-    return TRUE;
-  }
+  if(event->keyval>=GDK_0 && event->keyval<=GDK_9)
+    current_keycode[current_keycode_index++] = event->keyval;
+
+  if((char)event->keyval == '*')
+      current_keycode_index = 0;
+#endif
 
   switch (event->keyval)
     {
     case GDK_Escape:
-
       gcompris_close_all_dialog();
 
       board_stop();
@@ -210,32 +275,112 @@ board_widget_key_press_callback (GtkWidget   *widget,
       g_message("Refreshing the canvas\n");
       gnome_canvas_update_now(canvas);
       return TRUE;
-    case GDK_KP_Enter:
-    case GDK_Return:
-      /* If the board needs to receive key pressed */
-      /* NOTE: If a board receives key press, it must bind the ENTER Keys to OK
-       *       whenever possible
-       */
-      if (get_current_board_plugin()!=NULL && get_current_board_plugin()->key_press)
-	{
-	  return(get_current_board_plugin()->key_press (event->keyval));
-	} 
-      else if (get_current_board_plugin()!=NULL && get_current_board_plugin()->ok)
-	{
-	  /* Else we send the OK signal. */
-	  get_current_board_plugin()->ok ();
-	}
-      return TRUE;
-    default:
-      /* If the board needs to receive key pressed */
-      if (get_current_board_plugin()!=NULL && get_current_board_plugin()->key_press)
-	{
-	  // Removed, Too hard to analyse.
-	  //	  gcompris_log_set_key(get_current_board_plugin(), event->keyval);
 
-	  return(get_current_board_plugin()->key_press (event->keyval));
+    case GDK_KP_Multiply:
+      current_keycode_index = 0;
+      break;
+    case GDK_KP_0:
+    case GDK_KP_Insert:
+      event->keyval=GDK_0;
+      current_keycode[current_keycode_index++] = event->keyval;
+      break;
+    case GDK_KP_1:
+    case GDK_KP_End:
+      event->keyval=GDK_1;
+      current_keycode[current_keycode_index++] = event->keyval;
+      break;
+    case GDK_KP_2:
+    case GDK_KP_Down:
+      event->keyval=GDK_2;
+      current_keycode[current_keycode_index++] = event->keyval;
+      break;
+    case GDK_KP_3:
+    case GDK_KP_Page_Down:
+      event->keyval=GDK_3;
+      current_keycode[current_keycode_index++] = event->keyval;
+      break;
+    case GDK_KP_4:
+    case GDK_KP_Left:
+      event->keyval=GDK_4;
+      current_keycode[current_keycode_index++] = event->keyval;
+      break;
+    case GDK_KP_5:
+    case GDK_KP_Begin:
+      event->keyval=GDK_5;
+      current_keycode[current_keycode_index++] = event->keyval;
+      break;
+    case GDK_KP_6:
+    case GDK_KP_Right:
+      event->keyval=GDK_6;
+      current_keycode[current_keycode_index++] = event->keyval;
+      break;
+    case GDK_KP_7:
+    case GDK_KP_Home:
+      event->keyval=GDK_7;
+      current_keycode[current_keycode_index++] = event->keyval;
+      break;
+    case GDK_KP_8:
+    case GDK_KP_Up:
+      event->keyval=GDK_8;
+      current_keycode[current_keycode_index++] = event->keyval;
+      break;
+    case GDK_KP_9:
+    case GDK_KP_Page_Up:
+      event->keyval=GDK_9;
+      current_keycode[current_keycode_index++] = event->keyval;
+      break;
+    default:
+      break;
+    }
+
+  /* Check keycode */
+#ifdef WIN32
+  if(current_keycode_index == KEYCODE_LENGTH)
+    {
+      int i = 0;
+      current_keycode_index = 0;
+      while(keycode[i++])
+	{
+	  if(strncmp(current_keycode, keycode[i-1], KEYCODE_LENGTH) == 0)
+	    {
+	      properties->key="thanks_for_your_help";
+	      gcompris_properties_save(properties);
+	      gcompris_load_menus();
+
+	      gcompris_close_all_dialog();
+
+	      board_stop();
+	      return TRUE;
+	    }
 	}
     }
+#endif
+
+  /* pass through the IM context */
+  if (get_current_gcompris_board() && (!get_current_gcompris_board()->disable_im_context))
+    {
+      if (gtk_im_context_filter_keypress (properties->context, event))
+	{
+	  g_warning("%d key is handled by context", kv);
+	  return TRUE;
+	}
+    }
+
+  g_warning("%d key is NOT handled by context", kv);
+  /* If the board needs to receive key pressed */
+  /* NOTE: If a board receives key press, it must bind the ENTER Keys to OK
+   *       whenever possible
+   */
+  if (get_current_board_plugin()!=NULL && get_current_board_plugin()->key_press)
+    {
+      return(get_current_board_plugin()->key_press (event->keyval, NULL, NULL));
+    }
+  else if (get_current_board_plugin()!=NULL && get_current_board_plugin()->ok)
+    {
+      /* Else we send the OK signal. */
+      get_current_board_plugin()->ok ();
+      return TRUE;
+    }
 
   /* Event not handled; try parent item */
   return FALSE;
@@ -286,40 +431,28 @@ static void init_background()
   double xratio, yratio, max;
   gint screen_height, screen_width;
   GtkWidget *vbox;
-  int i;
 
 #ifdef XRANDR
-  /* Search the 800x600 Resolution */
+  xrandr = g_new0 (XRANDRData, 1);
+#endif
+
+  gcompris_set_fullscreen(properties->fullscreen);
+
+  screen_height = gdk_screen_height();
+  screen_width  = gdk_screen_width();
+
+#ifdef XRANDR
   if(properties->fullscreen && !properties->noxrandr) {
-    g_warning("XRANDR Is compiled in. Searching a good resolution");
-
-    xrandr = g_new0 (XRANDRData, 1);
-    xrandr_get_config ( xrandr );
-    xr_previous_size = (SizeID)xrandr->xr_current_size;
-
-    for (i = 0; i < xrandr->xr_nsize; i++) {
-      if(xrandr->xr_sizes[i].width == BOARDWIDTH, xrandr->xr_sizes[i].height == BOARDHEIGHT+BARHEIGHT) {
-	xrandr->xr_current_size = (SizeID)i;
-	xrandr_set_config( xrandr );
-	break;
-      }
-    }
     screen_height = xrandr->xr_sizes[xrandr->xr_current_size].height;
     screen_width  = xrandr->xr_sizes[xrandr->xr_current_size].width;
-  } else {
-  screen_height = gdk_screen_height();
-  screen_width  = gdk_screen_width();
   }
-#else
-  screen_height = gdk_screen_height();
-  screen_width  = gdk_screen_width();
 #endif
 
   yratio=screen_height/(float)(BOARDHEIGHT+BARHEIGHT);
   xratio=screen_width/(float)BOARDWIDTH;
-    g_message("The screen_width=%f screen_height=%f\n",
-  	 (double)screen_width, (double)screen_height);
-    g_message("The xratio=%f yratio=%f\n", xratio, yratio);
+  g_message("The screen_width=%f screen_height=%f\n",
+	    (double)screen_width, (double)screen_height);
+  g_message("The xratio=%f yratio=%f\n", xratio, yratio);
 
   yratio=xratio=MIN(xratio, yratio);
 
@@ -339,11 +472,10 @@ static void init_background()
 
   g_message("Calculated x ratio xratio=%f\n", xratio);
   
+
   /* Background area if ratio above 1 */
   if(properties->fullscreen)
     {
-      /* First, Remove the gnome crash dialog because it locks the user when in full screen */
-      signal(SIGSEGV, SIG_DFL);
 
       /* WARNING : I add 30 here for windows. don't know why it's needed. Doesn't hurt the Linux version */
       gnome_canvas_set_scroll_region (canvas_bg,
@@ -479,8 +611,9 @@ void gcompris_set_cursor(guint gdk_cursor_type)
 
 static void setup_window ()
 {
-  GdkPixbuf    *gcompris_icon_pixbuf;
-  GError       *error = NULL;
+  GcomprisBoard *board_to_start;
+  GdkPixbuf     *gcompris_icon_pixbuf;
+  GError        *error = NULL;
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
@@ -489,9 +622,10 @@ static void setup_window ()
    * ------------------------
    */
   if (!g_file_test ((GNOME_ICONDIR"/gcompris.png"), G_FILE_TEST_EXISTS)) {
-      g_warning (_("Couldn't find file %s !"), GNOME_ICONDIR"/gcompris.png" );
+      g_warning ("Couldn't find file %s !", GNOME_ICONDIR"/gcompris.png" );
   }
-  gcompris_icon_pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/gcompris.png", &error);
+  gcompris_icon_pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/gcompris.png",
+						   &error);
   if (!gcompris_icon_pixbuf)
     {
       g_warning ("Failed to load pixbuf file: %s: %s\n",
@@ -518,6 +652,9 @@ static void setup_window ()
   gtk_signal_connect (GTK_OBJECT (window), "delete_event",
 		      GTK_SIGNAL_FUNC (quit_cb), NULL);
 
+  gtk_signal_connect (GTK_OBJECT (window), "map_event",
+		      GTK_SIGNAL_FUNC (map_cb), NULL);
+
   /* For non anti alias canvas */
   gtk_widget_push_visual (gdk_rgb_get_visual ());
   gtk_widget_push_colormap (gdk_rgb_get_cmap ());
@@ -555,6 +692,9 @@ static void setup_window ()
   gtk_signal_connect_after (GTK_OBJECT (canvas_bg), "key_press_event",
 			    GTK_SIGNAL_FUNC (board_widget_key_press_callback), 0);
 
+  gcompris_im_init(window);
+
+
   if(properties->fullscreen)
     gtk_container_add (GTK_CONTAINER (window), GTK_WIDGET(canvas_bg));
 
@@ -564,15 +704,8 @@ static void setup_window ()
 
   gtk_widget_show (GTK_WIDGET(canvas_bg));
 
-  if(properties->fullscreen)
-    {
-      gdk_window_set_decorations (window->window, 0);
-      gdk_window_set_functions (window->window, 0);
-      gtk_widget_set_uposition (window, 0, 0);
-      gtk_window_fullscreen (GTK_WINDOW(window));
-    }
-
   init_plugins();
+  
 
   /* Load all the menu once */
   gcompris_load_menus();
@@ -580,12 +713,53 @@ static void setup_window ()
   /* Load the mime type */
   gcompris_load_mime_types();
 
+  /* Save the root_menu */
+  properties->menu_board = gcompris_get_board_from_section(properties->root_menu);
+
+  /* By default, the menu will be started */
+  board_to_start = properties->menu_board;
+
   /* Get and Run the root menu */
-  gcomprisBoardMenu = gcompris_get_board_from_section(properties->root_menu);
-  if(!gcomprisBoardMenu) {
+  if(properties->administration)
+    {
+      board_to_start = gcompris_get_board_from_section("/administration/administration");
+    }
+  else
+    {
+      /* If we have a profile defined, run the login screen
+       * (the login screen is a board that uppon login completion
+       * starts the menu)
+       */
+      if(properties->profile && properties->profile->group_ids)
+	{
+	  gboolean found = FALSE;
+	  
+	  GList *group_id;
+
+	  for (group_id = properties->profile->group_ids; group_id != NULL; group_id = group_id->next) 
+	    if (g_list_length(gcompris_get_users_from_group( *((int *) group_id->data))) > 0){
+	      found = TRUE;
+	      break;
+	    }
+	    
+	  /* No profile start normally */
+	  if (found)
+	    board_to_start = gcompris_get_board_from_section("/login/login");	
+	  else {
+	    board_to_start = gcompris_get_board_from_section(properties->root_menu);
+	    /* this will set user information to system one */
+	    gcompris_set_current_user(NULL);
+	  }
+	}
+      else
+	/* this will set user information to system one */
+	gcompris_set_current_user(NULL);
+    }
+
+  if(!board_to_start) {
     g_warning("Couldn't find the board menu %s, or plugin execution error", properties->root_menu);
     exit(1);
-  } else if(!board_check_file(gcomprisBoardMenu)) {
+  } else if(!board_check_file(board_to_start)) {
     g_error("Couldn't find the board menu, or plugin execution error");
   } else {
     g_warning("Fine, we got the gcomprisBoardMenu, xml boards parsing went fine");
@@ -593,15 +767,19 @@ static void setup_window ()
   /* Run the bar */
   gcompris_bar_start(canvas_bar);
 
-  board_play (gcomprisBoardMenu);
-
   init_background();
 
+  board_play (board_to_start);
+
 #ifdef WIN32
+#define WIN_ACTIVITY_COUNT   15
+#define TOTAL_ACTIVITY_COUNT 55
   {
     if(strncmp(properties->key, "thanks_for_your_help", 20)!=0) {
+      char *msg = g_strdup_printf(_("GCompris is free software released under the GPL License. In order to support its development, the Windows version provides only %d of the %d activities. You can get the full version for a small fee at\n<http://gcompris.net>\nThe Linux version does not have this restriction. Note that GCompris is being developed to free schools from monopolistic software vendors. If you also believe that we should teach freedom to children, please consider using GNU/Linux. Get more information at FSF:\n<http://www.fsf.org/philosophy>"), WIN_ACTIVITY_COUNT, TOTAL_ACTIVITY_COUNT);
       board_pause();
-      gcompris_dialog(_("GCompris is free software released under the GPL License. In order to support the development, the Windows version provides only 12 of the 45 activities. You can get the full version for a small fee at\nhttp://gcompris.net\nThe Linux version does not have this restriction. Note that gcompris is being developped to free schools from monopolistic software vendors. If you also believe that we should teach freedom to kids, please consider using GNU/Linux. Get more information on\nhttp://www.fsf.org/philosophy"), NULL);
+      gcompris_dialog(msg, NULL);
+      g_free(msg);
     }
   }
 #endif
@@ -611,24 +789,95 @@ void gcompris_end_board()
 {
   if (get_current_gcompris_board()->previous_board == NULL)
     /* We are in the upper menu */
-    board_play (gcomprisBoardMenu);
+    /* board_play (properties->menu_board); */
+    gcompris_exit();
   else
     /* Run the previous board */
     board_play (get_current_gcompris_board()->previous_board);
 }
 
+/** \brief toggle full screen mode
+ *
+ *
+ */
+void gcompris_set_fullscreen(gboolean state)
+{
+
+  if(state)
+    {
+#ifdef XRANDR
+      gint i;
+      /* Search the 800x600 Resolution */
+      if(properties->fullscreen && !properties->noxrandr) {
+	
+	g_warning("XRANDR Is compiled in. Searching a good resolution");
+
+	/* Check if XRANDR is available */
+	if (!properties->noxrandr) {
+	  xrandr_get_config ( xrandr );
+	  xr_previous_size = (SizeID)xrandr->xr_current_size;
+	  for (i = 0; i < xrandr->xr_nsize; i++) {
+	    if(xrandr->xr_sizes[i].width == BOARDWIDTH &&
+	       xrandr->xr_sizes[i].height == BOARDHEIGHT+BARHEIGHT) 
+	      {
+		xrandr->xr_current_size = (SizeID)i;
+		xr_previous_size_set = TRUE;
+		break;
+	      }
+	  }
+	}
+
+	/* Set the Fullscreen now */
+	if(xr_previous_size_set) 
+	  {
+	    if(is_mapped)
+	      xrandr_set_config( xrandr );
+	  }
+      }
+#endif
+      gdk_window_set_decorations (window->window, 0);
+      gdk_window_set_functions (window->window, 0);
+      gtk_widget_set_uposition (window, 0, 0);
+      gtk_window_fullscreen (GTK_WINDOW(window));
+    }
+  else
+    { 
+#ifdef XRANDR
+      /* Set back the original screen size */
+      if(xr_previous_size_set && !properties->noxrandr)
+	{
+	  /* Need to refresh our config or xrandr api will reject us */
+	  if(xrandr)
+	    {
+	      xrandr_get_config ( xrandr );
+	      xrandr->xr_current_size = (SizeID)xr_previous_size;
+	      xrandr_set_config( xrandr );
+	    }
+	}
+      xr_previous_size_set = FALSE;
+#endif
+      /* The hide must be done at least for KDE */
+      gtk_widget_hide (window);
+      gdk_window_set_decorations (window->window, GDK_DECOR_ALL);
+      gtk_widget_show (window);
+      gdk_window_set_functions (window->window, GDK_FUNC_ALL);
+      gtk_widget_set_uposition (window, 0, 0);
+      gtk_window_unfullscreen (GTK_WINDOW(window));
+    }
+
+}
+
 void gcompris_exit()
 {
+  /* Do not loopback in exit */
+  signal(SIGINT,  NULL);
+  signal(SIGSEGV, NULL);
+
   board_stop();
 
-#ifdef XRANDR
-  /* Set back the original screen size */
-  if(properties->fullscreen) {
-    xrandr_get_config ( xrandr );	/* Need to refresh our config or xrandr api will reject us */
-    xrandr->xr_current_size = (SizeID)xr_previous_size;
-    xrandr_set_config( xrandr );
-  }
-#endif
+  gcompris_db_exit();
+
+  gcompris_set_fullscreen(FALSE);
 
   gtk_main_quit ();
 
@@ -645,13 +894,29 @@ static void quit_cb (GtkWidget *widget, gpointer data)
 
 }
 
-/* =====================================================================
+/*
+ * We want GCompris to be set as fullscreen the later possible
+ *
+ */
+static void map_cb (GtkWidget *widget, gpointer data)
+{
+  if(is_mapped == FALSE)
+    {
+      is_mapped = TRUE;
+      gcompris_set_fullscreen(properties->fullscreen);
+    }
+
+  printf("\nEVENT\n============================================================\n\n");
+}
+
+/* 
  * Process the cleanup of the child (no zombies)
- * =====================================================================*/
+ * ---------------------------------------------
+ */
 void gcompris_terminate(int  signum)
 {
 
-  g_warning("gcompris got the SIGINT signal, starting exit procedure");
+  g_warning("gcompris got the %s signal, starting exit procedure", strsignal(signum));
   gcompris_exit();
   
 }
@@ -667,6 +932,16 @@ GcomprisProperties *gcompris_get_properties ()
   return (properties);
 }
 
+/* Return the database file name
+ * Must be called after properties is initialised
+ */
+gchar *gcompris_get_database ()
+{
+  g_assert(properties!=NULL);
+
+  return (properties->database);
+}
+
 /*
  * This returns the locale for which text must be displayed
  *
@@ -719,6 +994,8 @@ void gcompris_set_locale(gchar *locale)
   setlocale(LC_ALL, locale);
 #else
   gcompris_locale = g_strdup(setlocale(LC_MESSAGES, locale));
+  if (!gcompris_locale)
+    gcompris_locale = g_strdup(locale);
 #endif
 
   if(gcompris_locale!=NULL && strcmp(locale, gcompris_locale))
@@ -740,6 +1017,14 @@ void gcompris_set_locale(gchar *locale)
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
+#ifndef WIN32
+  /* Make change known.  */
+  {
+    extern int  _nl_msg_cat_cntr;
+    ++_nl_msg_cat_cntr;
+  }
+#endif
+
 }
 
 void gcompris_log_handler (const gchar *log_domain,
@@ -756,10 +1041,30 @@ void gcompris_log_handler (const gchar *log_domain,
  * ------------
  */
 static void
+xrandr_init ( XRANDRData *data )
+{
+  if(data==NULL)
+    return;
+
+  data->xr_screen_conf = XRRGetScreenInfo (GDK_DISPLAY(), GDK_ROOT_WINDOW());
+
+  if (data->xr_screen_conf == NULL)
+    {
+      g_warning("XRANDR not available");
+      properties->noxrandr = TRUE;
+    }
+  else
+      g_warning("XRANDR support enabled");
+ }
+
+static void
 xrandr_get_config ( XRANDRData *data )
 {
-  data->xr_screen_conf = XRRGetScreenInfo (GDK_DISPLAY(), GDK_ROOT_WINDOW());
-  
+  if(data==NULL)
+    return;
+
+  xrandr_init (data);
+
   data->xr_current_size = XRRConfigCurrentConfiguration (data->xr_screen_conf, 
 							 &data->xr_current_rotation);
 
@@ -769,12 +1074,15 @@ xrandr_get_config ( XRANDRData *data )
 					  &data->xr_current_rotation);
 }
 
-gboolean
+static void
 xrandr_set_config( XRANDRData  *data )
 {
   Status  status = RRSetConfigFailed;
 
-  if (data->xr_lock_updates) return FALSE;
+  if(data==NULL)
+    return;
+
+  if (data->xr_lock_updates) return;
   
   status = XRRSetScreenConfig (GDK_DISPLAY(), 
 			       data->xr_screen_conf, 
@@ -784,9 +1092,10 @@ xrandr_set_config( XRANDRData  *data )
 			       CurrentTime);
 
   if(status) {
-    printf("ERROR: Failed to set back the original resolution XRRSetScreenConfig returned status = %d\n", (int)status);
+    g_error("ERROR: Failed to set back the original resolution XRRSetScreenConfig returned status = %d\n",
+	    (int)status);
   }
-  return TRUE;
+  return;
 
 }
 #endif
@@ -803,6 +1112,10 @@ gcompris_init (int argc, char *argv[])
   int popt_option;
   gchar *str;
 
+  /* First, Remove the gnome crash dialog because it locks the user when in full screen */
+  signal(SIGSEGV, gcompris_terminate);
+  signal(SIGINT, gcompris_terminate);
+
   bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
@@ -810,8 +1123,6 @@ gcompris_init (int argc, char *argv[])
   /* To have some real random behaviour */
   srand (time (NULL));
 
-  signal(SIGINT, gcompris_terminate);
-
   /* Default difficulty filter: non specified */
   popt_difficulty_filter = -1;
 
@@ -909,24 +1220,195 @@ gcompris_init (int argc, char *argv[])
       properties->filter_style      = GCOMPRIS_FILTER_EQUAL;
     }
 
-  if (popt_root_menu){
-    g_warning("Using menu %s as root.", popt_root_menu);
-    properties->root_menu = g_strdup(popt_root_menu);
-  }
-
   if (popt_local_activity){
     g_warning("Adding local activies from %s.", popt_local_activity);
     properties->local_directory = g_strdup(popt_local_activity);
   }
 
+  if (popt_root_menu){
+    if (strcmp(popt_root_menu,"list")==0){
+      /* check the list of possible values for -l, then exit */
+      printf(_("Use -l to access an activity directly.\n"));
+      printf(_("List of available activity is :\n"));
+      properties->root_menu = "/";
+
+      gcompris_db_init();
+
+      gcompris_load_menus();
+
+      GList *list = NULL;
+      GList *menulist = NULL;
+      GList *menu_todo = NULL;
+
+      menu_todo = g_list_append(menu_todo,g_strdup("/"));
+
+      while ( menu_todo != NULL) {
+	menulist = gcompris_get_menulist(menu_todo->data);
+	g_free(menu_todo->data);
+	menu_todo = menu_todo->next;
+
+	for(list = menulist; list != NULL; list = list->next) {
+	  GcomprisBoard *board = list->data;
+	
+	  if (board){
+	    if (strcmp(board->type,"menu")==0)
+	      menu_todo = g_list_prepend(menu_todo, g_strdup_printf("%s/%s",board->section, board->name));
+
+	    printf("%s/%s : %s (%s) \n", board->section, board->name, board->title, board->description );
+	  }
+	}
+      }
+      
+      exit(0);
+    }
+    else {
+    g_warning("Using menu %s as root.", popt_root_menu);
+    properties->root_menu = g_strdup(popt_root_menu);
+    }
+  }
+
+  if (popt_users_dir){
+    if ((!g_file_test(popt_users_dir, G_FILE_TEST_IS_DIR)) || 
+	(access(popt_users_dir, popt_administration? R_OK : W_OK ) == -1)){
+	g_warning("%s does not exists or is not %s ", popt_users_dir,
+		  popt_administration? "readable" : "writable");
+	exit(0);
+    } else {
+      g_warning("Using %s as users directory.", popt_users_dir);
+      properties->users_dir = g_strdup(popt_users_dir);
+    }
+  }
+
+  if (popt_shared_dir){
+    if ((!g_file_test(popt_shared_dir, G_FILE_TEST_IS_DIR)) ||
+	(access(popt_shared_dir, popt_administration? W_OK : R_OK ) == -1)){
+      g_warning("%s does not exists or is not %s", popt_shared_dir,
+		popt_administration? "writable" : "readable"	);
+      exit(0);
+    }
+    else {
+      g_warning("Using %s as shared directory.", popt_shared_dir);
+      properties->shared_dir = g_strdup(popt_shared_dir);
+    }
+  }
+
+  /* shared_dir initialised, now we can set the default */
+  properties->database = get_default_database_name ( properties->shared_dir );
+  g_warning( "Infos:\n   Shared dir '%s'\n   Users dir '%s'\n   Database '%s'\n",
+	     properties->shared_dir, 
+	     properties->users_dir,
+	     properties->database);
+
+  if (popt_database){
+    if (g_file_test(popt_database, G_FILE_TEST_EXISTS)) {
+      if (access(popt_database,R_OK)==-1){
+	g_warning("%s exists but is not readable or writable", popt_database);
+	exit(0);
+      } else {
+	g_warning("Using %s as database", popt_database);
+	properties->database = g_strdup(popt_database);
+      }
+    } else if (popt_create_db) {
+      gchar *dirname = g_path_get_dirname (popt_database);
+      if (access(dirname, W_OK)==-1){
+	g_warning("Cannot create %s : %s is not writable !", popt_database, dirname);
+	exit (0);
+      }
+      g_warning("Using %s as database.", popt_database);
+      properties->database = g_strdup(popt_database);
+    } else {
+      g_warning("Alternate database %s does not exists.\n Use --create-db to force creation !", popt_database); 
+      exit(0);
+    }
+  }
+
+  if (popt_administration){
+    if (popt_database){
+      if (access(popt_database,R_OK|W_OK)==-1){
+	g_warning("%s exists but is not writable", popt_database);
+	exit(0);
+      }
+    }
+    g_warning("Running in administration mode");
+    properties->administration = TRUE;
+    g_warning("Background music disabled");
+    properties->music = FALSE;
+    g_warning("Fullscreen is disabled");
+    properties->fullscreen = FALSE;
+  }
+
+  if (popt_reread_menu){
+    g_warning("Rebuild db from xml files");
+    if (access(properties->database, W_OK)==-1)
+      g_warning("Cannot reread menu when database is read-only !");
+    else
+      properties->reread_menu = TRUE;
+  }
+
+
+  /*
+   * Database init MUST BE after properties
+   * And after a possible alternate database as been provided
+   *
+   */
+  gcompris_db_init();
+  
+  /* An alternate profile is requested, check it does exists */
+  if (popt_profile){
+    properties->profile = gcompris_get_profile_from_name(popt_profile);
+
+    if(properties->profile == NULL)
+      {
+	printf("ERROR: Profile '%s' is not found. Run 'gcompris --profile-list' to list available ones\n",
+	       popt_profile);
+	exit(1);
+      }
+  }
+
+  /* List all available profiles */
+  if (popt_profile_list){
+    GList * profile_list;
+    int i;
+
+    profile_list = gcompris_get_profiles_list();
+
+    printf(_("The list of available profiles is:\n"));
+    for(i=0; i< g_list_length(profile_list); i++)
+      {
+	GcomprisProfile *profile = g_list_nth_data(profile_list, i);
+	printf("   %s\n", profile->name);
+      }
+
+    g_list_free(profile_list);
+
+/*     g_warning("Wordlist test"); */
+
+/*     GcomprisWordlist *wl = gcompris_get_wordlist_from_file("default-fr"); */
+
+/*     GList *lev_list, *words, *list; */
+
+/*     lev_list = wl->levels_words; */
+
+/*     for (list = lev_list; list != NULL; list = list->next){ */
+/*       LevelWordlist *lw = list->data; */
+
+/*       g_warning("Level : %d", lw->level); */
+
+/*       for (words = lw->words; words != NULL; words = words->next) */
+/* 	g_warning("%s", (gchar *)words->data); */
+/*     } */
+
+/*     gcompris_wordlist_free(wl); */
+
+    exit(0);
+  }
 
   poptFreeContext(pctx); 
   /*------------------------------------------------------------*/
 
-
   if(properties->music || properties->fx)
     initSound();
-  
+
   /* Gdk-Pixbuf */
   gdk_rgb_init();
 
@@ -949,7 +1431,6 @@ gcompris_init (int argc, char *argv[])
   return 0;
 }
 
-
 /* Local Variables: */
 /* mode:c */
 /* eval:(load-library "time-stamp") */
