@@ -1,6 +1,6 @@
 /* gcompris - gcompris.h
  *
- * Time-stamp: <2005/04/06 23:30:01 bruno>
+ * Time-stamp: <2005/11/11 12:50:47 bruno>
  *
  * Copyright (C) 2000,2001,2002 Bruno Coudoin
  *
@@ -34,21 +34,30 @@
 #include <glib.h>
 #include <libintl.h>
 
-#include <config.h>
 #include <gmodule.h>
 
 #include "plugin.h"
 #include "gcompris-board.h"
 #include "board.h"
+#include "board_config.h"
 #include "properties.h"
 #include "gameutil.h"
-#include "svgutil.h"
 #include "bonus.h"
 #include "timer.h"
 #include "score.h"
 #include "skin.h"
 #include "anim.h"
 
+#include "profile.h"
+#include "gcompris_db.h"
+#include "gcompris_files.h"
+#include "wordlist.h"
+#include "gcompris_im.h"
+
+#ifdef USE_CAIRO
+#include "gcompris-cairo.h"
+#endif
+
 #ifdef DMALLOC
 #include "dmalloc.h"
 #endif
@@ -57,7 +66,7 @@
 #define BOARDHEIGHT 520
 #define BARHEIGHT   80
 
-#define DEFAULT_SKIN "default"
+#define DEFAULT_SKIN "gartoon"
 
 #define _(String) gettext (String)
 #define gettext_noop(String) String
@@ -132,8 +141,12 @@ void		 gcompris_file_selector_save (GcomprisBoard *gcomprisBoard,
 					      FileSelectorCallBack fscb);
 void		 gcompris_file_selector_stop (void);
 
+void		 gcompris_set_fullscreen(gboolean state);
+
 void		 gcompris_exit();
 
+gchar		*gcompris_get_database();
+
 /* Trace Log */
 #define GCOMPRIS_LOG_STATUS_PASSED    "PASSED"
 #define GCOMPRIS_LOG_STATUS_FAILED    "FAILED"
@@ -153,10 +166,11 @@ void gcompris_log_end (GcomprisBoard *gcomprisBoard, gchar *status);
 /*=========================================================*/
 /* Some global definition to keep a constant look and feel */
 /* Boards coders are invited to use them                   */
-#define COLOR_TITLE		0x0F0FC000
-#define COLOR_TEXT_BUTTON       0x0F0FC000
-#define COLOR_CONTENT		0x0D0DFA00
-#define COLOR_SUBTITLE		0xB0040000
+#define COLOR_TITLE		0x0F0FC0FF
+#define COLOR_TEXT_BUTTON       0x0F0FC0FF
+#define COLOR_CONTENT		0x0D0DFAFF
+#define COLOR_SUBTITLE		0xB00400FF
+#define COLOR_SHADOW		0x000000FF
 
 #define FONT_TITLE		"Sans 20"
 #define FONT_TITLE_FALLBACK	"Sans 12"
