@@ -1,6 +1,6 @@
 /* gcompris - images_selector.c
  *
- * Time-stamp: <2005/04/10 16:44:29 bruno>
+ * Time-stamp: <2005/11/12 19:03:14 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -24,6 +24,8 @@
  *
  */
 
+#include "string.h"
+
 /* libxml includes */
 #include <libxml/tree.h>
 #include <libxml/parser.h>
@@ -42,7 +44,7 @@ static gint		 item_event_scroll(GnomeCanvasItem *item,
 					   GdkEvent *event,
 					   GnomeCanvas *canvas);
 static gboolean		 read_xml_file(gchar *fname);
-static gboolean                 read_dataset_directory(gchar *dataset_dir);
+static gboolean		 read_dataset_directory(gchar *dataset_dir);
 static void		 display_image(gchar *imagename, GnomeCanvasItem *rootitem);
 static void		 free_stuff (GtkObject *obj, GList *data);
 
@@ -50,7 +52,6 @@ static gboolean		 images_selector_displayed = FALSE;
 
 static GnomeCanvasItem	*rootitem = NULL;
 static GnomeCanvasItem	*current_root_set = NULL;
-static GnomeCanvasItem	*item_content = NULL;
 
 static GnomeCanvas	*canvas_list_selector; /* The scrolled left part */
 static GnomeCanvasItem  *list_bg_item;
@@ -286,12 +287,10 @@ void gcompris_images_selector_start (GcomprisBoard *gcomprisBoard, gchar *datase
      -> if dataset is a directory, read all xml file in it.
   */
 
-  g_return_val_if_fail(dataset!=NULL,FALSE);
-
   /* if the file doesn't exist */
   if(g_file_test ((dataset), G_FILE_TEST_IS_DIR) )
     {
-      g_warning(_("dataset %s is a directory. Trying to read xml "), dataset);
+      g_warning("dataset %s is a directory. Trying to read xml", dataset);
 
       read_dataset_directory(dataset);
     }
@@ -349,6 +348,10 @@ static void display_image(gchar *imagename, GnomeCanvasItem *root_item)
 
   pixmap = gcompris_load_pixmap(imagename);
 
+  /* Sad, the image is not found */
+  if(!pixmap)
+    return;
+
   iw = IMAGE_WIDTH;
   ih = IMAGE_HEIGHT;
 
@@ -500,11 +503,11 @@ item_event_imageset_selector(GnomeCanvasItem *item, GdkEvent *event, gpointer da
 
 	  /* We must display the list of images for this set */
 	  image_list = (GList *)g_object_get_data (G_OBJECT (item), "imagelist");
-	  g_return_if_fail (image_list != NULL);
+	  g_return_val_if_fail (image_list != NULL, FALSE);
 
 	  /* We must display the list of images for this set */
 	  rootitem_set = (GnomeCanvasItem *)g_object_get_data (G_OBJECT (item), "rootitem");
-	  g_return_if_fail (rootitem_set != NULL);
+	  g_return_val_if_fail (rootitem_set != NULL, FALSE);
 
 	  imageset_done = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "imageset_done"));
 
@@ -585,7 +588,7 @@ item_event_scroll(GnomeCanvasItem *item, GdkEvent *event, GnomeCanvas *canvas)
 {
   int x, y;
   if(!rootitem)
-    return;
+    return FALSE;
 
   switch (event->type) 
     {
@@ -596,6 +599,8 @@ item_event_scroll(GnomeCanvasItem *item, GdkEvent *event, GnomeCanvas *canvas)
       else if ( event->scroll.direction == GDK_SCROLL_DOWN )
 	gnome_canvas_scroll_to (canvas, x, y + 20);
 
+      break;
+    default:
       break;
     }
   return FALSE;
@@ -609,12 +614,14 @@ item_event_scroll(GnomeCanvasItem *item, GdkEvent *event, GnomeCanvas *canvas)
 void
 parseImage (xmlDocPtr doc, xmlNodePtr cur) {
   gchar *imageSetName = NULL;
-  gchar *filename, *pathname, *absolutepath;;
+  gchar *filename;
+  gchar	*pathname = NULL;
+  gchar *absolutepath;
   GList	*imageList = NULL;	/* List of Images */
-  gboolean havePathName = FALSE, lsdir = FALSE;
+  gboolean havePathName = FALSE;
   gchar *type = NULL;
   GDir *imageset_directory;
-  GError **error;
+  GError **error = NULL;
 
   /* get the filename of this ImageSet */
   imageSetName = xmlGetProp(cur,"filename");
@@ -626,10 +633,9 @@ parseImage (xmlDocPtr doc, xmlNodePtr cur) {
     /* replace '~' by home dir */
     pathname = g_strdup_printf("%s%s",g_get_home_dir(), pathname+1);
     if (!g_file_test ((pathname), G_FILE_TEST_IS_DIR)){
-       g_warning(_("In ImageSet %s, home pathname %s is not found. Skipping ImageSet...\n"), imageSetName, pathname);
+       g_warning("In ImageSet %s, the pathname for the home directory '%s' is not found. Skipping the whole ImageSet.", imageSetName, pathname);
       return;
     }
-    havePathName = TRUE;
   }
 
   if (xmlHasProp(cur,"type")){
@@ -661,7 +667,7 @@ parseImage (xmlDocPtr doc, xmlNodePtr cur) {
   
   if(!g_file_test ((absolutepath), G_FILE_TEST_EXISTS) )
     {
-      g_warning(_("In ImageSet %s, an image is not found. Skipping ImageSet...\n"), absolutepath);
+      g_warning("In ImageSet %s, an image is not found. Skipping ImageSet...", absolutepath);
       return;
     }
 
@@ -687,17 +693,24 @@ parseImage (xmlDocPtr doc, xmlNodePtr cur) {
     /* or all files with a given suffix */
 
     if (!g_file_test ((pathname), G_FILE_TEST_IS_DIR)){
-      g_warning(_("In ImageSet %s, directory %s is not found. Skipping all the ImageSet...\n"), absolutepath, pathname);
-      return;
+      char *tmpdir;
+      tmpdir = g_strdup_printf("%s/%s", PACKAGE_DATA_DIR, pathname);
+      g_free(pathname);
+      pathname = tmpdir;
+      if (!g_file_test ((pathname), G_FILE_TEST_IS_DIR)){
+        g_warning("In ImageSet %s, directory %s is not found. Skipping all the ImageSet...", absolutepath, pathname);
+        return;
+      }
     }
     imageset_directory = g_dir_open (pathname, 0, error);    
-    while (filename = g_dir_read_name(imageset_directory)){
+    const gchar * onefile;
+    while ((onefile = g_dir_read_name(imageset_directory))){
       if ((g_ascii_strcasecmp (type,"lsdir") != 0) && 
-	  (!g_str_has_suffix (filename,type))){
+	  (!g_str_has_suffix (onefile, type))){
 	continue;
       }
-      filename = g_strdup_printf("%s/%s",pathname,filename);
-      if (!g_file_test ((filename), G_FILE_TEST_EXISTS)){
+      filename = g_strdup_printf("%s/%s", pathname, onefile);
+      if (!g_file_test ((filename), G_FILE_TEST_IS_REGULAR)){
 	continue;
       }
       imageList = g_list_append (imageList, filename);
@@ -710,7 +723,11 @@ parseImage (xmlDocPtr doc, xmlNodePtr cur) {
     display_image_set(imageSetName, imageList);
   
   g_free(absolutepath);
-  
+  if(pathname)
+    g_free(pathname);
+  if(type)
+    g_free(type);
+
   return;
 }
 
@@ -751,7 +768,7 @@ read_xml_file(gchar *fname)
   /* if the file doesn't exist */
   if(!g_file_test ((fname), G_FILE_TEST_EXISTS)) 
     {
-      g_warning(_("Couldn't find file %s !"), fname);
+      g_warning("Couldn't find file %s !", fname);
       return FALSE;
     }
 
@@ -788,11 +805,11 @@ read_dataset_directory(gchar *dataset_dir)
 {
 
 
-  GError **error;
+  GError **error = NULL;
   GDir *dataset_directory = g_dir_open (dataset_dir, 0, error);
   gchar *fname, *absolute_fname;
 
-  while (fname = g_dir_read_name(dataset_directory)) {
+  while ((fname = g_dir_read_name(dataset_directory))) {
     /* skip files without ".xml" */
     if (!g_str_has_suffix (fname,".xml")){
       printf("skipping file not in .xml : %s\n", fname);
@@ -802,7 +819,7 @@ read_dataset_directory(gchar *dataset_dir)
     absolute_fname = g_strdup_printf("%s/%s",dataset_dir,fname);
     printf("Reading dataset file %s\n",absolute_fname);
    
-    if (!g_file_test ((absolute_fname), G_FILE_TEST_EXISTS))
+    if (!g_file_test ((absolute_fname), G_FILE_TEST_IS_REGULAR))
       continue;
 
     /* parse the new file and put the result into newdoc */
