@@ -1,6 +1,6 @@
 /* gcompris - plugin.h
  *
- * Time-stamp: <2001/09/12 23:36:45 bruno>
+ * Time-stamp: <2005/09/14 23:30:48 yves>
  *
  * Copyright (C) 2000 Bruno Coudoin
  * 
@@ -21,19 +21,28 @@
 #ifndef PLUGIN_H
 #define PLUGIN_H
 
+#include "profile.h"
+
 /* Forward declaration of GcomprisBoard */
 typedef struct _GcomprisBoard         GcomprisBoard;
 
 /* Return 1 if the board plugin can handle this board */
 typedef	gboolean      (*GcomprisIsOurBoard)   (GcomprisBoard *gcomprisBoard);
 
+typedef void          (*GcomprisInitBoard)    (GcomprisBoard *gcomprisBoard);
 typedef void          (*GcomprisStartBoard)   (GcomprisBoard *gcomprisBoard);
 typedef void          (*GcomprisPauseBoard)   (gboolean pause);
 typedef void          (*GcomprisEndBoard)     (void);
-typedef gint          (*GcomprisKeyPress)     (guint keyval);
+typedef gint          (*GcomprisKeyPress)     (guint keyval, 
+					       gchar *commited_str, 
+					       gchar *preedit_str);
 typedef void          (*GcomprisOK)           (void);
 typedef void          (*GcomprisSetLevel)     (guint level);
-typedef void          (*GcomprisHelp)         ();
+typedef void          (*GcomprisConfig)       ();
+typedef void          (*GcomprisRepeat)       ();
+typedef void          (*GcomprisConfigStart)  (GcomprisBoard *gcomprisBoard,
+					       GcomprisProfile *profile);
+typedef void          (*GcomprisConfigStop)    (void);
 
 typedef struct
 {
@@ -42,7 +51,9 @@ typedef struct
   char *name;			/* The name that describes this board */
   char *description;		/* The description that describes this board */
   char *author;			/* The author of this board */
-  void (*init) (void);		/* Called when the plugin is loaded */
+
+  GcomprisInitBoard    init;	/* Called when the plugin is loaded */
+
   void (*cleanup) (void);      	/* Called when gcompris exit */
   void (*about) (void);		/* Show the about box */
   void (*configure) (void);	/* Show the configuration dialog */
@@ -56,7 +67,11 @@ typedef struct
   GcomprisKeyPress     key_press;
   GcomprisOK           ok;
   GcomprisSetLevel     set_level;
-  GcomprisHelp         help;
+  GcomprisConfig       config;
+  GcomprisRepeat       repeat;
+
+  GcomprisConfigStart  config_start;
+  GcomprisConfigStop   config_stop;
 
 }
 BoardPlugin;
