@@ -1,6 +1,6 @@
 /* gcompris - properties.c
  *
- * Time-stamp: <2005/04/17 16:50:21 bruno>
+ * Time-stamp: <2005/11/05 23:15:45 bruno>
  *
  * Copyright (C) 2000,2003 Bruno Coudoin
  *
@@ -23,17 +23,14 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <unistd.h>
+#include <string.h>
 
 #include "gcompris.h"
 
 /* This should be detected in the configure for good portability */
 #define HAVE_SETENV 1
 
-static GHashTable* boards_hash = NULL;
-
-void read_boards_status();
-void write_boards_status();
-
 #if defined _WIN32 || defined __WIN32__
 # undef WIN32   /* avoid warning on mingw32 */
 # define WIN32
@@ -44,6 +41,8 @@ void write_boards_status();
 # include <windows.h>
 #endif
 
+static gchar *config_file = NULL;
+
 /*
  * return 1 if parsing OK, 0 otherwise
  * the return value is returned in retval
@@ -79,7 +78,7 @@ gchar *scan_get_string(GScanner *scanner) {
  *
  * return 0 if OK, -1 if ERROR
  */
-static int
+int
 create_rootdir (gchar *rootdir)
 {
 
@@ -99,24 +98,69 @@ create_rootdir (gchar *rootdir)
 #endif
 }
 
+/* get the gcompris user directory name */
+/* Architecture dependant: "gcompris" in Win9x, */
+/* "/.gcompris" in POSIX compliant systems */
+
+gchar *get_gcompris_user_root_directory ()
+{
+  G_CONST_RETURN gchar *home_dir = g_get_home_dir();
+
+  if (home_dir == NULL) /* Win9x */
+    return g_strdup("gcompris");
+  else
+    return g_strconcat(home_dir, "/.gcompris", NULL);
+}
+
+/** return the name of the configuration file used
+ *  the name has the full path and is platform dependant
+ *  must not be freed by the caller.
+ * 
+ */
+gchar *get_gcompris_conf_name()
+{
+  if(config_file)
+    return(config_file);
+
+  /* Was never called, mus calculate it */
+  if (g_get_home_dir()==NULL) {
+    config_file = g_strconcat(get_gcompris_user_root_directory(), "/gcompris.cfg", NULL);
+  } else {
+    config_file = g_strconcat(get_gcompris_user_root_directory(), "/gcompris.conf", NULL);
+  }
+
+   return(config_file);
+}
+
+/* get the default database name */
+#define DEFAULT_DATABASE "gcompris_sqlite.db"
+#define PROFILES_ROOT "profiles"
+
+gchar *get_default_database_name (gchar *shared_dir)
+{
+  gchar *dir_base = g_strconcat( shared_dir, "/",  PROFILES_ROOT, NULL);
+  create_rootdir(dir_base);
+  g_free(dir_base);
+  return g_strconcat( shared_dir, "/",  PROFILES_ROOT, "/",  DEFAULT_DATABASE, NULL);
+  
+}
+
 GcomprisProperties *gcompris_properties_new ()
 {
   GcomprisProperties *tmp;
-  G_CONST_RETURN gchar *home_dir;
-  char          *config_file;
-  const gchar   *locale;
-  int            i;
+  char          *config_file = get_gcompris_conf_name();
   GScanner      *scanner;
   int		 filefd;
   gchar         *full_rootdir;
-
-  boards_hash = g_hash_table_new (g_str_hash, g_str_equal);
+  const gchar   *locale;
+  gchar         *gcompris_user_dir;
 
   tmp = (GcomprisProperties *) malloc (sizeof (GcomprisProperties));
   tmp->music		 = 1;
   tmp->fx		 = 1;
   tmp->screensize	 = 1;
   tmp->fullscreen	 = 1;
+  tmp->noxrandr		 = FALSE;
   tmp->timer		 = 1;
   tmp->skin		 = "babytoy";
   tmp->key		 = "default";
@@ -127,47 +171,43 @@ GcomprisProperties *gcompris_properties_new ()
   tmp->root_menu         = "/";
   tmp->local_directory   = NULL;
   tmp->package_data_dir  = PACKAGE_DATA_DIR;
+  tmp->profile           = NULL;
+  tmp->logged_user       = NULL;
 
-  home_dir = g_get_home_dir();
+  tmp->administration    = FALSE;
+  tmp->reread_menu       = FALSE;
 
-  if(home_dir==NULL) {		/* WIN98 */
+  gcompris_user_dir = get_gcompris_user_root_directory() ;
+  create_rootdir( gcompris_user_dir );
 
-    /* On WIN98, No home dir */
-    full_rootdir = g_strdup_printf("%s", "gcompris");
-    create_rootdir(full_rootdir);
-    g_free(full_rootdir);
+  tmp->shared_dir        = g_strconcat(gcompris_user_dir, "/shared", NULL);
+  create_rootdir( tmp->shared_dir );
 
-    full_rootdir = g_strdup_printf("%s", "gcompris/user_data");
-    create_rootdir(full_rootdir);
-    g_free(full_rootdir);
+  tmp->users_dir        = g_strconcat(gcompris_user_dir, "/users", NULL);
+  create_rootdir( tmp->users_dir );
 
-    full_rootdir = g_strdup_printf("%s", "gcompris/user_data/images");
-    create_rootdir(full_rootdir);
-    g_free(full_rootdir);
+  tmp->user_data_dir	= g_strconcat(gcompris_user_dir, "/Plugins/boards", NULL);
+  create_rootdir( tmp->user_data_dir );
 
-    config_file = g_strdup("gcompris/gcompris.cfg");
+  /* Needs to be set after command line parsing */
+  tmp->database          = NULL;
 
-  } else {
+  full_rootdir = g_strconcat(gcompris_user_dir, "/user_data", NULL);
+  create_rootdir(full_rootdir);
+  g_free(full_rootdir);
 
-    full_rootdir = g_strconcat(g_get_home_dir(), "/.gcompris", NULL);
-    create_rootdir(full_rootdir);
-    g_free(full_rootdir);
+  full_rootdir = g_strconcat(gcompris_user_dir, "/user_data/images", NULL);
+  create_rootdir(full_rootdir);
+  g_free(full_rootdir);
 
-    full_rootdir = g_strconcat(g_get_home_dir(), "/.gcompris/user_data", NULL);
-    create_rootdir(full_rootdir);
-    g_free(full_rootdir);
+  full_rootdir = g_strconcat(gcompris_user_dir, "/", PROFILES_ROOT, NULL);
+  create_rootdir(full_rootdir);
+  g_free(full_rootdir);
 
-    full_rootdir = g_strconcat(g_get_home_dir(), "/.gcompris/user_data/images", NULL);
-    create_rootdir(full_rootdir);
-    g_free(full_rootdir);
-
-    config_file = g_strdup_printf("%s/.gcompris/gcompris.conf",home_dir);
-  }
+  g_warning("config_file %s", config_file);
 
   filefd = open(config_file, O_RDONLY);
 
-  g_free(config_file);
-
   if(filefd > 0) {
 
     /* create a new scanner */
@@ -200,6 +240,9 @@ GcomprisProperties *gcompris_properties_new ()
 	} else if(!strcmp(value.v_identifier, "fullscreen")) {
 	  if(!scan_get_int(scanner, &tmp->fullscreen))
 	    g_warning("Config file parsing error on token %s", token);
+	} else if(!strcmp(value.v_identifier, "noxrandr")) {
+	  if(!scan_get_int(scanner, &tmp->noxrandr))
+	    g_warning("Config file parsing error on token %s", token);
 	} else if(!strcmp(value.v_identifier, "timer")) {
 	  if(!scan_get_int(scanner, &tmp->timer))
 	    g_warning("Config file parsing error on token %s", token);
@@ -222,6 +265,11 @@ GcomprisProperties *gcompris_properties_new ()
 	  if(!tmp->key)
 	    g_warning("Config file parsing error on token %s", token);
 	}
+	else if(!strcmp(value.v_identifier, "database")) {
+	  tmp->database = scan_get_string(scanner);
+	  if(!tmp->database)
+	    g_warning("Config file parsing error on token %s", token);
+	}
 	break;
       }
       default:
@@ -266,12 +314,6 @@ GcomprisProperties *gcompris_properties_new ()
     tmp->locale		= "";
   }
 
-  /*
-   * Read the board status
-   * ---------------------
-   */
-  read_boards_status();
-
   return (tmp);
 }
 
@@ -285,18 +327,9 @@ void gcompris_properties_destroy (GcomprisProperties *props)
 
 void gcompris_properties_save (GcomprisProperties *props)
 {
-  G_CONST_RETURN gchar *home_dir;
-  char *config_file;
+  char *config_file = get_gcompris_conf_name();
   FILE *filefd;
 
-  home_dir = g_get_home_dir();
-
-  if(home_dir==NULL) {
-    config_file = g_strdup("gcompris.cfg");
-  } else {
-    config_file = g_strdup_printf("%s/.gcompris/gcompris.conf",home_dir);
-  }
-
   filefd = fopen(config_file, "w+");
 
   if(!filefd) {
@@ -304,160 +337,36 @@ void gcompris_properties_save (GcomprisProperties *props)
       return;
     }
 
-  g_free(config_file);
-
   fprintf(filefd, "%s=%d\n", "music",			props->music);
   fprintf(filefd, "%s=%d\n", "fx",			props->fx);
   fprintf(filefd, "%s=%d\n", "screensize",		props->screensize);
   fprintf(filefd, "%s=%d\n", "fullscreen",		props->fullscreen);
+  /* FIXME: No more persist the noxrandr option until we provide a way to set it back
+   *
+   fprintf(filefd, "%s=%d\n", "noxrandr",		props->noxrandr); */
   fprintf(filefd, "%s=%d\n", "timer",			props->timer);
-  fprintf(filefd, "%s=%d\n", "difficulty_filter",	props->difficulty_filter);
-  fprintf(filefd, "%s=%d\n", "filter_style",		props->filter_style);
-  
+
+  /* No more need to persist these, it's in the base now
+     fprintf(filefd, "%s=%d\n", "difficulty_filter",	props->difficulty_filter);
+     fprintf(filefd, "%s=%d\n", "filter_style",		props->filter_style);
+  */
+
   fprintf(filefd, "%s=\"%s\"\n", "skin",		props->skin);
   fprintf(filefd, "%s=\"%s\"\n", "locale",		props->locale);
   fprintf(filefd, "%s=\"%s\"\n", "key",			props->key);
-  
+
+  fprintf(filefd, "%s=\"%s\"\n", "database",		props->database);
+
   fclose(filefd);
 }
 
 
 
-static void boards_write (gchar       *key,
-			  gpointer     value,
-			  FILE        *filefd)
-{
-  printf("  %s=%d\n", key, GPOINTER_TO_UINT(value));
-  fprintf(filefd, "%s=%d\n", key, GPOINTER_TO_UINT(value));
-}
-
-
-/*
- * Save the board status (enable/disable)
- */
-void gcompris_write_boards_status()
-{
-  G_CONST_RETURN gchar *home_dir;
-  char *config_file;
-  int i;
-  GScanner *scanner;
-  FILE *filefd;
-
-  home_dir = g_get_home_dir();
-
-  if(home_dir==NULL) {
-    config_file = g_strdup("gcompris_boards.cfg");
-  } else {
-    config_file = g_strdup_printf("%s/.gcompris/gcompris_boards.conf",home_dir);
-  }
-
-  filefd = fopen(config_file, "w+");
-
-  if(!filefd) {
-    g_warning("cannot open '%s', configuration file not saved\n",(char *) config_file);
-    return;
-  }
-
-  g_free(config_file);
-
-  g_hash_table_foreach (boards_hash, (GHFunc) boards_write, filefd);
-
-}
-
-void read_boards_status()
-{
-  G_CONST_RETURN gchar *home_dir;
-  char *config_file;
-  int i;
-  GScanner *scanner;
-  int filefd;
-
-  home_dir = g_get_home_dir();
-
-  if(home_dir==NULL) {
-    config_file = g_strdup("gcompris_boards.cfg");
-  } else {
-    config_file = g_strdup_printf("%s/.gcompris/gcompris_boards.conf",home_dir);
-  }
-
-  filefd = open(config_file, O_RDONLY);
-
-  g_free(config_file);
-
-  if(filefd > 0) {
-
-    /* create a new scanner */
-    scanner = g_scanner_new(NULL);
-
-    /* set up the scanner to read from the file */
-    g_scanner_input_file(scanner, filefd);
-
-    /* while the next token is something else other than end of file */
-    while(g_scanner_peek_next_token(scanner) != G_TOKEN_EOF) {
-
-      /* get the next token */
-      GTokenType token = g_scanner_get_next_token(scanner);
-      switch(token) {
-      case G_TOKEN_IDENTIFIER: {
-	guint data;
-	gchar *token;
-	/* if we have a symbol, check it's ours */
-	GTokenValue value = g_scanner_cur_value(scanner);
-	token = g_strdup(value.v_identifier);
-
-	if(!scan_get_int(scanner, &data))
-	  g_warning("Config file parsing error on token %s", token);
-	else {
-	  g_hash_table_insert(boards_hash, token, GUINT_TO_POINTER(data));
-	}
-	break;
-      }
-      default:
-	break;
-      }
-    }
-
-    /* destroy the scanner */
-    g_scanner_destroy(scanner);
-
-    close(filefd);
-
-  }
-}
-
-/*
- * Management of the status of the boards
- */
-void gcompris_properties_enable_board(gchar *boardName)
-{
-  g_hash_table_remove(boards_hash, boardName);
-}
-
-void gcompris_properties_disable_board(gchar *boardName)
-{
-  g_hash_table_insert(boards_hash, boardName, GUINT_TO_POINTER(1));
-}
-
-/*
- * Return TRUE if boardName is available, FALSE otherwise
- *
- */
-gboolean gcompris_properties_get_board_status(gchar *boardName)
-{
-  guint result;
-
-  result = GPOINTER_TO_UINT(g_hash_table_lookup(boards_hash, boardName));
-
-  if(result==1)
-    return FALSE;
-  else
-    return TRUE;
-}
-
-int my_setenv (const char * name, const char * value) {
+int
+my_setenv (const char * name, const char * value) {
+#if defined WIN32
   size_t namelen = strlen(name);
   size_t valuelen = (value==NULL ? 0 : strlen(value));
-#if defined WIN32
   /* On Woe32, each process has two copies of the environment variables,
      one managed by the OS and one managed by the C library. We set
      the value in both locations, so that other software that looks in
