@@ -1,6 +1,6 @@
 /* gcompris - properties.h
  *
- * Time-stamp: <2005/04/10 23:53:34 bruno>
+ * Time-stamp: <2005/11/05 19:18:48 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -22,6 +22,8 @@
 #ifndef _PROPERTIES_H_
 #define _PROPERTIES_H_
 
+#include "profile.h"
+
 typedef struct {
   gint		music;
   gint		fx;
@@ -36,10 +38,22 @@ typedef struct {
   gint		difficulty_max;
   gchar        *root_menu;
   gchar        *local_directory;
+  gchar        *user_data_dir;
   gchar        *package_data_dir;
   gchar	       *locale;
   gchar	       *skin;
   gchar	       *key;
+  GcomprisProfile *profile;
+  GcomprisUser    *logged_user;
+  GcomprisBoard	  *menu_board;
+  gchar	       *database;
+  gint          administration;
+  gint          reread_menu;
+  gchar        *shared_dir;
+  gchar        *users_dir;
+  /* this are set by gcompris_im_init() */
+  GtkIMContext *context;
+  gchar        *default_context;
 } GcomprisProperties;
 
 GcomprisProperties	*gcompris_get_properties (void);
@@ -47,10 +61,9 @@ GcomprisProperties	*gcompris_properties_new (void);
 void			 gcompris_properties_destroy (GcomprisProperties *props);
 void			 gcompris_properties_save (GcomprisProperties *props);
 
-void			 gcompris_properties_enable_board(gchar *boardName);
-void			 gcompris_properties_disable_board(gchar *boardName);
-gboolean		 gcompris_properties_get_board_status(gchar *boardName);
-void			 gcompris_write_boards_status();
+gchar                   *get_default_database_name (gchar *shared_dir);
+int                      create_rootdir (gchar *rootdir);
+int			 my_setenv (const char * name, const char * value);
 
 #endif
 
