@@ -16,18 +16,22 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+
+#include "string.h"
  
 #include "skin.h"
 #include <libxml/tree.h>
 #include <libxml/parser.h>
 
-GHashTable* gcompris_skin_fonts = NULL;
-GHashTable* gcompris_skin_colors = NULL;
+GHashTable* gcompris_skin_fonts   = NULL;
+GHashTable* gcompris_skin_colors  = NULL;
+GHashTable* gcompris_skin_numbers = NULL;
 
 guint32 gcompris_skin_color_title;
 guint32 gcompris_skin_color_text_button;
 guint32 gcompris_skin_color_content;
 guint32 gcompris_skin_color_subtitle;
+guint32 gcompris_skin_color_shadow;
 
 gchar* gcompris_skin_font_title;
 gchar* gcompris_skin_font_subtitle;
@@ -80,7 +84,7 @@ gchar *gcompris_image_to_skin(gchar *pixmapfile)
     return(filename);
   }
 
-  g_warning (_("Couldn't find file %s !"), filename);
+  g_warning ("Couldn't find file %s !", filename);
 
   return(NULL);
 }
@@ -93,7 +97,6 @@ gchar *gcompris_image_to_skin(gchar *pixmapfile)
 GdkPixbuf *gcompris_load_skin_pixmap(char *pixmapfile)
 {
   gchar *filename;
-  GcomprisProperties	*properties = gcompris_get_properties();
   GdkPixbuf *result_pixbuf;
 
   filename = gcompris_image_to_skin(pixmapfile);
@@ -128,6 +131,8 @@ void gcompris_skin_setup_vars(void)
     gcompris_skin_get_color_default("gcompris/content", COLOR_CONTENT);
   gcompris_skin_color_subtitle = 
     gcompris_skin_get_color_default("gcompris/subtitle", COLOR_SUBTITLE);
+  gcompris_skin_color_shadow = 
+    gcompris_skin_get_color_default("gcompris/shadow", COLOR_SHADOW);
   
   gcompris_skin_font_title = 
     gcompris_skin_get_font_default("gcompris/title", FONT_TITLE);
@@ -258,7 +263,7 @@ void gcompris_skin_xml_load (gchar* skin)
   /* if the file doesn't exist */
   if(!g_file_test(xmlfilename, G_FILE_TEST_EXISTS))
     {
-      g_warning(_("Couldn't find file %s !"), xmlfilename);
+      g_warning("Couldn't find file %s !", xmlfilename);
       return;
     }
 
@@ -313,6 +318,17 @@ void gcompris_skin_xml_load (gchar* skin)
 	} else {
 	  if(key!=NULL) g_free(key);
 	  if(data!=NULL) g_free(data);
+	}
+      }
+      else if(g_strcasecmp(node->name,"number")==0){
+	key = xmlGetProp(node, "id");
+	data = xmlGetProp(node, "value");
+	if((key!=NULL)&&(data!=NULL)){
+	  int number = atoi(data);
+	  g_hash_table_insert(gcompris_skin_numbers, key, GUINT_TO_POINTER(number));
+	} else {
+	  if(key!=NULL) g_free(key);
+	  if(data!=NULL) g_free(data);
 	}	
       }
       node = node->next;
@@ -339,8 +355,11 @@ void gcompris_skin_load (gchar* skin)
   gcompris_skin_colors = g_hash_table_new_full(g_str_hash, g_str_equal,
 					      gcompris_skin_free_string,
 					      NULL);
-  gcompris_skin_xml_load("default");
-  if(strcmp(skin,"default")!=0)
+  gcompris_skin_numbers = g_hash_table_new_full(g_str_hash, g_str_equal,
+					      gcompris_skin_free_string,
+					      NULL);
+  gcompris_skin_xml_load(DEFAULT_SKIN);
+  if(strcmp(skin,DEFAULT_SKIN)!=0)
     gcompris_skin_xml_load(skin);
 
   gcompris_skin_setup_vars();
@@ -381,3 +400,15 @@ gchar* gcompris_skin_get_font_default(gchar* id, gchar* def)
     return (gchar*)result;
   return def;
 }
+
+/*
+ * Get the skin 'number' associated to the id
+ */
+guint32 gcompris_skin_get_number_default(gchar* id, guint32 def)
+{
+  gpointer result;
+  result = g_hash_table_lookup(gcompris_skin_numbers, (gpointer)id);
+  if(result!=NULL)
+    return GPOINTER_TO_UINT(result);
+  return def;
+}
